@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeassignment.h"
 #include <stdlib.h>
@@ -51,12 +49,17 @@ ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCod
 	ValaCCodeAssignment * self;
 	g_return_val_if_fail (l == NULL || VALA_IS_CCODE_EXPRESSION (l), NULL);
 	g_return_val_if_fail (r == NULL || VALA_IS_CCODE_EXPRESSION (r), NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "left", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, l), __params_it++);
-	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
 	(__params_it->name = "right", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, r), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_ASSIGNMENT, __params_it - __params, __params);
+	vala_ccode_assignment_set_operator (self, op);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -64,7 +67,7 @@ ValaCCodeAssignment* vala_ccode_assignment_new (ValaCCodeExpression* l, ValaCCod
 static void vala_ccode_assignment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeAssignment * self;
-	self = VALA_CCODE_ASSIGNMENT (base);
+	self = ((ValaCCodeAssignment*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (vala_ccode_assignment_get_left (self) != NULL) {
 		vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_assignment_get_left (self)), writer);
@@ -236,7 +239,7 @@ static void vala_ccode_assignment_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_assignment_get_type ()
+GType vala_ccode_assignment_get_type (void)
 {
 	static GType vala_ccode_assignment_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_assignment_type_id == 0)) {
