@@ -81,7 +81,7 @@ ValaCCodeExpression* vala_ccode_binary_expression_get_left (ValaCCodeBinaryExpre
 void vala_ccode_binary_expression_set_left (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value);
 ValaCCodeExpression* vala_ccode_binary_expression_get_right (ValaCCodeBinaryExpression* self);
 void vala_ccode_binary_expression_set_right (ValaCCodeBinaryExpression* self, ValaCCodeExpression* value);
-GType vala_ccode_binary_expression_get_type ();
+GType vala_ccode_binary_expression_get_type (void);
 
 G_END_DECLS
 
