@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodebreakstatement.h"
 #include <stdlib.h>
@@ -36,7 +34,7 @@ static gpointer vala_ccode_break_statement_parent_class = NULL;
 static void vala_ccode_break_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeBreakStatement * self;
-	self = VALA_CCODE_BREAK_STATEMENT (base);
+	self = ((ValaCCodeBreakStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "break;");
@@ -56,7 +54,7 @@ static void vala_ccode_break_statement_init (ValaCCodeBreakStatement * self)
 }
 
 
-GType vala_ccode_break_statement_get_type ()
+GType vala_ccode_break_statement_get_type (void)
 {
 	static GType vala_ccode_break_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_break_statement_type_id == 0)) {
