@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeconditionalexpression.h"
 #include <stdlib.h>
@@ -59,6 +57,11 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCode
 	(__params_it->name = "true-expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, true_expr), __params_it++);
 	(__params_it->name = "false-expression", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, false_expr), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_CONDITIONAL_EXPRESSION, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -66,7 +69,7 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCode
 static void vala_ccode_conditional_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeConditionalExpression * self;
-	self = VALA_CCODE_CONDITIONAL_EXPRESSION (base);
+	self = ((ValaCCodeConditionalExpression*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_conditional_expression_get_condition (self)), writer);
@@ -197,7 +200,7 @@ static void vala_ccode_conditional_expression_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_conditional_expression_get_type ()
+GType vala_ccode_conditional_expression_get_type (void)
 {
 	static GType vala_ccode_conditional_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_conditional_expression_type_id == 0)) {
