@@ -21,8 +21,6 @@
  * 	Raffaele Sandrini <rasa@gmx.ch>
  *	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodeelementaccess.h"
 #include <stdlib.h>
@@ -38,7 +36,7 @@ struct _ValaCCodeElementAccessPrivate {
 enum  {
 	VALA_CCODE_ELEMENT_ACCESS_DUMMY_PROPERTY,
 	VALA_CCODE_ELEMENT_ACCESS_CONTAINER,
-	VALA_CCODE_ELEMENT_ACCESS_INDEX,
+	VALA_CCODE_ELEMENT_ACCESS_INDEX
 };
 static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_element_access_parent_class = NULL;
@@ -47,20 +45,29 @@ static void vala_ccode_element_access_dispose (GObject * obj);
 
 ValaCCodeElementAccess* vala_ccode_element_access_new (ValaCCodeExpression* cont, ValaCCodeExpression* i)
 {
+	GParameter * __params;
+	GParameter * __params_it;
+	ValaCCodeElementAccess * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cont), NULL);
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (i), NULL);
-	GParameter * __params = g_new0 (GParameter, 2);
-	GParameter * __params_it = __params;
+	__params = g_new0 (GParameter, 2);
+	__params_it = __params;
 	(__params_it->name = "container", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cont), __params_it++);
 	(__params_it->name = "index", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, i), __params_it++);
-	ValaCCodeElementAccess * self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_ELEMENT_ACCESS, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
 static void vala_ccode_element_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
-	ValaCCodeElementAccess * self = VALA_CCODE_ELEMENT_ACCESS (base);
+	ValaCCodeElementAccess * self;
+	self = ((ValaCCodeElementAccess*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_element_access_get_container (self)), writer);
 	vala_ccode_writer_write_string (writer, "[");
@@ -78,8 +85,9 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp1;
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
-	ValaCCodeExpression* __temp1 = NULL;
+	__temp1 = NULL;
 	self->priv->_container = (__temp1 = g_object_ref (value), (self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL))), __temp1);
 }
 
@@ -93,15 +101,17 @@ ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess
 
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value)
 {
+	ValaCCodeExpression* __temp3;
 	g_return_if_fail (VALA_IS_CCODE_ELEMENT_ACCESS (self));
-	ValaCCodeExpression* __temp3 = NULL;
+	__temp3 = NULL;
 	self->priv->_index = (__temp3 = g_object_ref (value), (self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL))), __temp3);
 }
 
 
 static void vala_ccode_element_access_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeElementAccess * self = VALA_CCODE_ELEMENT_ACCESS (object);
+	ValaCCodeElementAccess * self;
+	self = VALA_CCODE_ELEMENT_ACCESS (object);
 	switch (property_id) {
 		case VALA_CCODE_ELEMENT_ACCESS_CONTAINER:
 		g_value_set_object (value, vala_ccode_element_access_get_container (self));
@@ -115,7 +125,8 @@ static void vala_ccode_element_access_get_property (GObject * object, guint prop
 
 static void vala_ccode_element_access_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
 {
-	ValaCCodeElementAccess * self = VALA_CCODE_ELEMENT_ACCESS (object);
+	ValaCCodeElementAccess * self;
+	self = VALA_CCODE_ELEMENT_ACCESS (object);
 	switch (property_id) {
 		case VALA_CCODE_ELEMENT_ACCESS_CONTAINER:
 		vala_ccode_element_access_set_container (self, g_value_get_object (value));
@@ -148,18 +159,19 @@ static void vala_ccode_element_access_init (ValaCCodeElementAccess * self)
 
 static void vala_ccode_element_access_dispose (GObject * obj)
 {
-	ValaCCodeElementAccess * self = VALA_CCODE_ELEMENT_ACCESS (obj);
-	(self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL)));
-	(self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL)));
+	ValaCCodeElementAccess * self;
 	ValaCCodeElementAccessClass * klass;
 	GObjectClass * parent_class;
+	self = VALA_CCODE_ELEMENT_ACCESS (obj);
+	(self->priv->_container == NULL ? NULL : (self->priv->_container = (g_object_unref (self->priv->_container), NULL)));
+	(self->priv->_index == NULL ? NULL : (self->priv->_index = (g_object_unref (self->priv->_index), NULL)));
 	klass = VALA_CCODE_ELEMENT_ACCESS_CLASS (g_type_class_peek (VALA_TYPE_CCODE_ELEMENT_ACCESS));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_element_access_get_type ()
+GType vala_ccode_element_access_get_type (void)
 {
 	static GType vala_ccode_element_access_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_element_access_type_id == 0)) {
