@@ -24,9 +24,6 @@
 
 #ifndef __VALACCODEELEMENTACCESS_H__
 #define __VALACCODEELEMENTACCESS_H__
-typedef struct _ValaCCodeElementAccess ValaCCodeElementAccess;
-typedef struct _ValaCCodeElementAccessClass ValaCCodeElementAccessClass;
-typedef struct _ValaCCodeElementAccessPrivate ValaCCodeElementAccessPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,6 +40,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_ELEMENT_ACCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_ELEMENT_ACCESS))
 #define VALA_CCODE_ELEMENT_ACCESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_ELEMENT_ACCESS, ValaCCodeElementAccessClass))
 
+typedef struct _ValaCCodeElementAccess ValaCCodeElementAccess;
+typedef struct _ValaCCodeElementAccessClass ValaCCodeElementAccessClass;
+typedef struct _ValaCCodeElementAccessPrivate ValaCCodeElementAccessPrivate;
 
 /**
  * Represents an access to an array member in the C code.
@@ -60,7 +60,7 @@ ValaCCodeExpression* vala_ccode_element_access_get_container (ValaCCodeElementAc
 void vala_ccode_element_access_set_container (ValaCCodeElementAccess* self, ValaCCodeExpression* value);
 ValaCCodeExpression* vala_ccode_element_access_get_index (ValaCCodeElementAccess* self);
 void vala_ccode_element_access_set_index (ValaCCodeElementAccess* self, ValaCCodeExpression* value);
-GType vala_ccode_element_access_get_type ();
+GType vala_ccode_element_access_get_type (void);
 
 G_END_DECLS
 
