@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODEEXPRESSIONSTATEMENT_H__
 #define __VALACCODEEXPRESSIONSTATEMENT_H__
-typedef struct _ValaCCodeExpressionStatement ValaCCodeExpressionStatement;
-typedef struct _ValaCCodeExpressionStatementClass ValaCCodeExpressionStatementClass;
-typedef struct _ValaCCodeExpressionStatementPrivate ValaCCodeExpressionStatementPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -42,6 +39,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_EXPRESSION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_EXPRESSION_STATEMENT))
 #define VALA_CCODE_EXPRESSION_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_EXPRESSION_STATEMENT, ValaCCodeExpressionStatementClass))
 
+typedef struct _ValaCCodeExpressionStatement ValaCCodeExpressionStatement;
+typedef struct _ValaCCodeExpressionStatementClass ValaCCodeExpressionStatementClass;
+typedef struct _ValaCCodeExpressionStatementPrivate ValaCCodeExpressionStatementPrivate;
 
 /**
  * Represents a C code statement that evaluates a given expression.
@@ -57,7 +57,7 @@ struct _ValaCCodeExpressionStatementClass {
 ValaCCodeExpressionStatement* vala_ccode_expression_statement_new (ValaCCodeExpression* expr);
 ValaCCodeExpression* vala_ccode_expression_statement_get_expression (ValaCCodeExpressionStatement* self);
 void vala_ccode_expression_statement_set_expression (ValaCCodeExpressionStatement* self, ValaCCodeExpression* value);
-GType vala_ccode_expression_statement_get_type ();
+GType vala_ccode_expression_statement_get_type (void);
 
 G_END_DECLS
 
