@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODEFORMALPARAMETER_H__
 #define __VALACCODEFORMALPARAMETER_H__
-typedef struct _ValaCCodeFormalParameter ValaCCodeFormalParameter;
-typedef struct _ValaCCodeFormalParameterClass ValaCCodeFormalParameterClass;
-typedef struct _ValaCCodeFormalParameterPrivate ValaCCodeFormalParameterPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,6 +40,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_FORMAL_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_FORMAL_PARAMETER))
 #define VALA_CCODE_FORMAL_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_FORMAL_PARAMETER, ValaCCodeFormalParameterClass))
 
+typedef struct _ValaCCodeFormalParameter ValaCCodeFormalParameter;
+typedef struct _ValaCCodeFormalParameterClass ValaCCodeFormalParameterClass;
+typedef struct _ValaCCodeFormalParameterPrivate ValaCCodeFormalParameterPrivate;
 
 /**
  * Represents a formal parameter in a C method signature.
@@ -60,7 +60,7 @@ char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self);
 void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const char* value);
 char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter* self);
 void vala_ccode_formal_parameter_set_type_name (ValaCCodeFormalParameter* self, const char* value);
-GType vala_ccode_formal_parameter_get_type ();
+GType vala_ccode_formal_parameter_get_type (void);
 
 G_END_DECLS
 
