@@ -19,14 +19,15 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodefragment.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <ccode/valaccodefragment.h>
 
 struct _ValaCCodeFragmentPrivate {
-	GList* children;
+	GeeList* children;
 };
 #define VALA_CCODE_FRAGMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FRAGMENT, ValaCCodeFragmentPrivate))
 enum  {
@@ -34,6 +35,7 @@ enum  {
 };
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_fragment_parent_class = NULL;
 static void vala_ccode_fragment_dispose (GObject * obj);
 
@@ -47,7 +49,7 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node)
 {
 	g_return_if_fail (VALA_IS_CCODE_FRAGMENT (self));
 	g_return_if_fail (VALA_IS_CCODE_NODE (node));
-	self->priv->children = g_list_append (self->priv->children, g_object_ref (node));
+	gee_collection_add (GEE_COLLECTION (self->priv->children), node);
 }
 
 
@@ -56,30 +58,32 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node)
  *
  * @return children list
  */
-GList* vala_ccode_fragment_get_children (ValaCCodeFragment* self)
+GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self)
 {
 	g_return_val_if_fail (VALA_IS_CCODE_FRAGMENT (self), NULL);
-	return g_list_copy (self->priv->children);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->children)));
 }
 
 
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeFragment * self;
-	self = VALA_CCODE_FRAGMENT (base);
+	self = ((ValaCCodeFragment*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
-		GList* __temp1;
-		GList* node_it;
-		__temp1 = NULL;
-		__temp1 = self->priv->children;
-		for (node_it = __temp1; node_it != NULL; node_it = node_it->next) {
+		GeeList* node_collection;
+		GeeIterator* node_it;
+		node_collection = self->priv->children;
+		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
+		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = node_it->data;
+			node = gee_iterator_get (node_it);
 			{
 				vala_ccode_node_write (node, writer);
+				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
+		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -87,20 +91,45 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeFragment * self;
-	self = VALA_CCODE_FRAGMENT (base);
+	self = ((ValaCCodeFragment*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
-		GList* __temp2;
-		GList* node_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->children;
-		for (node_it = __temp2; node_it != NULL; node_it = node_it->next) {
+		GeeList* node_collection;
+		GeeIterator* node_it;
+		node_collection = self->priv->children;
+		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
+		while (gee_iterator_next (node_it)) {
 			ValaCCodeNode* node;
-			node = node_it->data;
+			node = gee_iterator_get (node_it);
 			{
 				vala_ccode_node_write_declaration (node, writer);
+				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
+		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
+	}
+}
+
+
+static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer)
+{
+	ValaCCodeFragment * self;
+	self = ((ValaCCodeFragment*) base);
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	{
+		GeeList* node_collection;
+		GeeIterator* node_it;
+		node_collection = self->priv->children;
+		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
+		while (gee_iterator_next (node_it)) {
+			ValaCCodeNode* node;
+			node = gee_iterator_get (node_it);
+			{
+				vala_ccode_node_write_combined (node, writer);
+				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
+			}
+		}
+		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -112,12 +141,14 @@ static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_ccode_fragment_dispose;
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_fragment_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_fragment_real_write_declaration;
+	VALA_CCODE_NODE_CLASS (klass)->write_combined = vala_ccode_fragment_real_write_combined;
 }
 
 
 static void vala_ccode_fragment_init (ValaCCodeFragment * self)
 {
 	self->priv = VALA_CCODE_FRAGMENT_GET_PRIVATE (self);
+	self->priv->children = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -127,14 +158,14 @@ static void vala_ccode_fragment_dispose (GObject * obj)
 	ValaCCodeFragmentClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_CCODE_FRAGMENT (obj);
-	(self->priv->children == NULL ? NULL : (self->priv->children = (g_list_foreach (self->priv->children, (GFunc) g_object_unref, NULL), g_list_free (self->priv->children), NULL)));
+	(self->priv->children == NULL ? NULL : (self->priv->children = (g_object_unref (self->priv->children), NULL)));
 	klass = VALA_CCODE_FRAGMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_FRAGMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_ccode_fragment_get_type ()
+GType vala_ccode_fragment_get_type (void)
 {
 	static GType vala_ccode_fragment_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_fragment_type_id == 0)) {
