@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodelabel.h"
 #include <ccode/valaccodelabel.h>
@@ -48,6 +46,11 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name)
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_LABEL, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -55,7 +58,7 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name)
 static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeLabel * self;
-	self = VALA_CCODE_LABEL (base);
+	self = ((ValaCCodeLabel*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, vala_ccode_label_get_name (self));
@@ -135,7 +138,7 @@ static void vala_ccode_label_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_label_get_type ()
+GType vala_ccode_label_get_type (void)
 {
 	static GType vala_ccode_label_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_label_type_id == 0)) {
