@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodemacroreplacement.h"
 #include <ccode/valaccodemacroreplacement.h>
@@ -52,6 +50,11 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, cons
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, n), __params_it++);
 	(__params_it->name = "replacement", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, replace), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_MACRO_REPLACEMENT, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -59,7 +62,7 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* n, cons
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeMacroReplacement * self;
-	self = VALA_CCODE_MACRO_REPLACEMENT (base);
+	self = ((ValaCCodeMacroReplacement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "#define ");
@@ -165,7 +168,7 @@ static void vala_ccode_macro_replacement_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_macro_replacement_get_type ()
+GType vala_ccode_macro_replacement_get_type (void)
 {
 	static GType vala_ccode_macro_replacement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
