@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodememberaccess.h"
 #include <ccode/valaccodememberaccess.h>
@@ -50,12 +48,17 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new (ValaCCodeExpression* contai
 	ValaCCodeMemberAccess * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
 	g_return_val_if_fail (member != NULL, NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, container), __params_it++);
 	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
-	(__params_it->name = "is-pointer", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, pointer), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
+	vala_ccode_member_access_set_is_pointer (self, pointer);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -67,12 +70,17 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 	ValaCCodeMemberAccess * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (container), NULL);
 	g_return_val_if_fail (member != NULL, NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, container), __params_it++);
 	(__params_it->name = "member-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, member), __params_it++);
-	(__params_it->name = "is-pointer", g_value_init (&__params_it->value, G_TYPE_BOOLEAN), g_value_set_boolean (&__params_it->value, TRUE), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_MEMBER_ACCESS, __params_it - __params, __params);
+	vala_ccode_member_access_set_is_pointer (self, TRUE);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -80,7 +88,7 @@ ValaCCodeMemberAccess* vala_ccode_member_access_new_pointer (ValaCCodeExpression
 static void vala_ccode_member_access_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeMemberAccess * self;
-	self = VALA_CCODE_MEMBER_ACCESS (base);
+	self = ((ValaCCodeMemberAccess*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_member_access_get_inner (self)), writer);
 	if (vala_ccode_member_access_get_is_pointer (self)) {
@@ -208,7 +216,7 @@ static void vala_ccode_member_access_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_member_access_get_type ()
+GType vala_ccode_member_access_get_type (void)
 {
 	static GType vala_ccode_member_access_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_member_access_type_id == 0)) {
