@@ -57,7 +57,7 @@ struct _ValaCCodeReturnStatementClass {
 ValaCCodeReturnStatement* vala_ccode_return_statement_new (ValaCCodeExpression* expr);
 ValaCCodeExpression* vala_ccode_return_statement_get_return_expression (ValaCCodeReturnStatement* self);
 void vala_ccode_return_statement_set_return_expression (ValaCCodeReturnStatement* self, ValaCCodeExpression* value);
-GType vala_ccode_return_statement_get_type ();
+GType vala_ccode_return_statement_get_type (void);
 
 G_END_DECLS
 
