@@ -1,6 +1,6 @@
 /* valaccodeswitchstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,9 +22,6 @@
 
 #ifndef __VALACCODESWITCHSTATEMENT_H__
 #define __VALACCODESWITCHSTATEMENT_H__
-typedef struct _ValaCCodeSwitchStatement ValaCCodeSwitchStatement;
-typedef struct _ValaCCodeSwitchStatementClass ValaCCodeSwitchStatementClass;
-typedef struct _ValaCCodeSwitchStatementPrivate ValaCCodeSwitchStatementPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -43,6 +40,9 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_SWITCH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_SWITCH_STATEMENT))
 #define VALA_CCODE_SWITCH_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_SWITCH_STATEMENT, ValaCCodeSwitchStatementClass))
 
+typedef struct _ValaCCodeSwitchStatement ValaCCodeSwitchStatement;
+typedef struct _ValaCCodeSwitchStatementClass ValaCCodeSwitchStatementClass;
+typedef struct _ValaCCodeSwitchStatementPrivate ValaCCodeSwitchStatementPrivate;
 
 /**
  * Represents a switch selection statement in the C code.
@@ -55,11 +55,11 @@ struct _ValaCCodeSwitchStatementClass {
 	ValaCCodeStatementClass parent;
 };
 
-ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expr);
+ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression);
 void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaCCodeCaseStatement* case_stmt);
 ValaCCodeExpression* vala_ccode_switch_statement_get_expression (ValaCCodeSwitchStatement* self);
 void vala_ccode_switch_statement_set_expression (ValaCCodeSwitchStatement* self, ValaCCodeExpression* value);
-GType vala_ccode_switch_statement_get_type ();
+GType vala_ccode_switch_statement_get_type (void);
 
 G_END_DECLS
 
