@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodewhilestatement.h"
 #include <stdlib.h>
@@ -50,11 +48,16 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 	ValaCCodeWhileStatement * self;
 	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
-	__params = g_new0 (GParameter, 2);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_CCODE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_CCODE_STATEMENT), g_value_set_object (&__params_it->value, stmt), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_WHILE_STATEMENT, __params_it - __params, __params);
+	vala_ccode_while_statement_set_body (self, stmt);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -62,7 +65,7 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
 {
 	ValaCCodeWhileStatement * self;
-	self = VALA_CCODE_WHILE_STATEMENT (base);
+	self = ((ValaCCodeWhileStatement*) base);
 	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer);
 	vala_ccode_writer_write_string (writer, "while (");
@@ -169,7 +172,7 @@ static void vala_ccode_while_statement_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_while_statement_get_type ()
+GType vala_ccode_while_statement_get_type (void)
 {
 	static GType vala_ccode_while_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_while_statement_type_id == 0)) {
