@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodewriter.h"
 #include <stdio.h>
@@ -55,6 +53,11 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
 	__params_it = __params;
 	(__params_it->name = "filename", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _filename), __params_it++);
 	self = g_object_newv (VALA_TYPE_CCODE_WRITER, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -64,37 +67,67 @@ ValaCCodeWriter* vala_ccode_writer_new (const char* _filename)
  */
 void vala_ccode_writer_close (ValaCCodeWriter* self)
 {
+	GError * inner_error;
 	FILE* __temp0;
 	g_return_if_fail (VALA_IS_CCODE_WRITER (self));
+	inner_error = NULL;
 	__temp0 = NULL;
 	self->priv->stream = (__temp0 = NULL, (self->priv->stream == NULL ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL))), __temp0);
 	if (self->priv->file_exists) {
 		gboolean changed;
-		GMappedFile* old_file;
-		GMappedFile* new_file;
-		glong len;
-		GMappedFile* __temp1;
-		GMappedFile* __temp2;
 		changed = TRUE;
-		old_file = g_mapped_file_new (self->priv->_filename, FALSE, NULL);
-		new_file = g_mapped_file_new (self->priv->temp_filename, FALSE, NULL);
-		len = g_mapped_file_get_length (old_file);
-		if (len == g_mapped_file_get_length (new_file)) {
-			if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), len) == 0) {
-				changed = FALSE;
+		{
+			GMappedFile* old_file;
+			GMappedFile* new_file;
+			glong len;
+			GMappedFile* __temp1;
+			GMappedFile* __temp2;
+			old_file = g_mapped_file_new (self->priv->_filename, FALSE, &inner_error);
+			if (inner_error != NULL) {
+				if (inner_error->domain == G_FILE_ERROR) {
+					goto __catch0_g_file_error;
+				}
+				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+				g_clear_error (&inner_error);
+			}
+			new_file = g_mapped_file_new (self->priv->temp_filename, FALSE, &inner_error);
+			if (inner_error != NULL) {
+				if (inner_error->domain == G_FILE_ERROR) {
+					goto __catch0_g_file_error;
+				}
+				g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
+				g_clear_error (&inner_error);
+			}
+			len = g_mapped_file_get_length (old_file);
+			if (len == g_mapped_file_get_length (new_file)) {
+				if (memcmp (g_mapped_file_get_contents (old_file), g_mapped_file_get_contents (new_file), len) == 0) {
+					changed = FALSE;
+				}
+			}
+			__temp1 = NULL;
+			old_file = (__temp1 = NULL, (old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL))), __temp1);
+			__temp2 = NULL;
+			new_file = (__temp2 = NULL, (new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL))), __temp2);
+			(old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)));
+			(new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)));
+		}
+		goto __finally0;
+		__catch0_g_file_error:
+		{
+			GError * e;
+			e = inner_error;
+			inner_error = NULL;
+			{
 			}
 		}
-		__temp1 = NULL;
-		old_file = (__temp1 = NULL, (old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL))), __temp1);
-		__temp2 = NULL;
-		new_file = (__temp2 = NULL, (new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL))), __temp2);
+		__finally0:
+		;
+		/* assume changed if mmap comparison doesn't work*/
 		if (changed) {
 			g_rename (self->priv->temp_filename, self->priv->_filename);
 		} else {
 			g_unlink (self->priv->temp_filename);
 		}
-		(old_file == NULL ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)));
-		(new_file == NULL ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)));
 	}
 }
 
@@ -192,13 +225,14 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 	__temp3 = NULL;
 	lines = (__temp3 = g_strsplit (text, "\n", 0), lines_length1 = -1, __temp3);
 	{
-		char** __temp4;
+		char** line_collection;
 		int line_it;
-		__temp4 = NULL;
-		__temp4 = lines;
-		for (line_it = 0; (lines_length1 != -1 && line_it < lines_length1) || (lines_length1 == -1 && __temp4[line_it] != NULL); line_it = line_it + 1) {
+		line_collection = lines;
+		for (line_it = 0; (lines_length1 != -1 && line_it < lines_length1) || (lines_length1 == -1 && line_collection[line_it] != NULL); line_it = line_it + 1) {
+			const char* __temp4;
 			char* line;
-			line = __temp4[line_it];
+			__temp4 = NULL;
+			line = (__temp4 = line_collection[line_it], (__temp4 == NULL ? NULL : g_strdup (__temp4)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_indent (self);
@@ -206,12 +240,13 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text)
 					first = FALSE;
 				}
 				fprintf (self->priv->stream, "%s", line);
+				(line = (g_free (line), NULL));
 			}
 		}
 	}
 	fprintf (self->priv->stream, "*/");
 	vala_ccode_writer_write_newline (self);
-	(lines = (g_free (lines), NULL));
+	(lines = (g_strfreev (lines), NULL));
 }
 
 
@@ -314,7 +349,7 @@ static void vala_ccode_writer_dispose (GObject * obj)
 }
 
 
-GType vala_ccode_writer_get_type ()
+GType vala_ccode_writer_get_type (void)
 {
 	static GType vala_ccode_writer_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_writer_type_id == 0)) {
