@@ -19,14 +19,11 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaccodecompiler.h"
-#include <stdlib.h>
-#include <string.h>
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
+#include <gee/collection.h>
 #include <vala/valasourcefile.h>
 #include <glib/gstdio.h>
 
@@ -36,14 +33,10 @@ enum  {
 static gpointer vala_ccode_compiler_parent_class = NULL;
 
 
-ValaCCodeCompiler* vala_ccode_compiler_new ()
+ValaCCodeCompiler* vala_ccode_compiler_new (void)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCCodeCompiler * self;
-	__params = g_new0 (GParameter, 0);
-	__params_it = __params;
-	self = g_object_newv (VALA_TYPE_CCODE_COMPILER, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CCODE_COMPILER, 0, NULL);
 	return self;
 }
 
@@ -54,19 +47,20 @@ ValaCCodeCompiler* vala_ccode_compiler_new ()
  *
  * @param context a code context
  */
-void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context)
+void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context, const char* cc_command, char** cc_options)
 {
 	GError * inner_error;
 	char* pc;
 	char* __temp1;
 	char* pkgflags;
 	gint exit_status;
+	const char* __temp6;
 	char* cmdline;
 	char* __temp9;
 	char* __temp8;
 	char* __temp15;
 	char* __temp14;
-	GList* source_files;
+	GeeCollection* source_files;
 	g_return_if_fail (VALA_IS_CCODE_COMPILER (self));
 	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	inner_error = NULL;
@@ -84,13 +78,13 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		pc = (__temp2 = g_strconcat (pc, (" gthread-2.0"), NULL), (pc = (g_free (pc), NULL)), __temp2);
 	}
 	{
-		GList* __temp5;
-		GList* pkg_it;
-		__temp5 = NULL;
-		__temp5 = vala_code_context_get_packages (context);
-		for (pkg_it = __temp5; pkg_it != NULL; pkg_it = pkg_it->next) {
+		GeeCollection* pkg_collection;
+		GeeIterator* pkg_it;
+		pkg_collection = vala_code_context_get_packages (context);
+		pkg_it = gee_iterable_iterator (GEE_ITERABLE (pkg_collection));
+		while (gee_iterator_next (pkg_it)) {
 			char* pkg;
-			pkg = pkg_it->data;
+			pkg = gee_iterator_get (pkg_it);
 			{
 				char* __temp4;
 				char* __temp3;
@@ -98,9 +92,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 				__temp3 = NULL;
 				pc = (__temp4 = g_strconcat (pc, (__temp3 = (g_strconcat (" ", pkg, NULL))), NULL), (pc = (g_free (pc), NULL)), __temp4);
 				(__temp3 = (g_free (__temp3), NULL));
+				(pkg = (g_free (pkg), NULL));
 			}
 		}
-		(__temp5 == NULL ? NULL : (__temp5 = (g_list_free (__temp5), NULL)));
+		(pkg_collection == NULL ? NULL : (pkg_collection = (g_object_unref (pkg_collection), NULL)));
+		(pkg_it == NULL ? NULL : (pkg_it = (g_object_unref (pkg_it), NULL)));
 	}
 	pkgflags = NULL;
 	exit_status = 0;
@@ -114,10 +110,10 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			g_clear_error (&inner_error);
 		}
 		if (exit_status != 0) {
-			char* __temp6;
-			__temp6 = NULL;
-			vala_report_error (NULL, (__temp6 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
-			(__temp6 = (g_free (__temp6), NULL));
+			char* __temp5;
+			__temp5 = NULL;
+			vala_report_error (NULL, (__temp5 = g_strdup_printf ("pkg-config exited with status %d", exit_status)));
+			(__temp5 = (g_free (__temp5), NULL));
 			(pc = (g_free (pc), NULL));
 			(pkgflags = (g_free (pkgflags), NULL));
 			return;
@@ -139,7 +135,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	__finally0:
 	;
 	/* TODO compile the C code files in parallel*/
-	cmdline = g_strdup ("cc");
+	if (cc_command == NULL) {
+		cc_command = "cc";
+	}
+	__temp6 = NULL;
+	cmdline = (__temp6 = cc_command, (__temp6 == NULL ? NULL : g_strdup (__temp6)));
 	if (vala_code_context_get_debug (context)) {
 		char* __temp7;
 		__temp7 = NULL;
@@ -170,34 +170,58 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	__temp14 = NULL;
 	cmdline = (__temp15 = g_strconcat (cmdline, (__temp14 = (g_strconcat (" ", pkgflags, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp15);
 	(__temp14 = (g_free (__temp14), NULL));
-	/* we're only interested in non-pkg source files */
-	source_files = vala_code_context_get_source_files (context);
-	{
-		GList* __temp20;
-		GList* file_it;
-		__temp20 = NULL;
-		__temp20 = source_files;
-		for (file_it = __temp20; file_it != NULL; file_it = file_it->next) {
-			ValaSourceFile* file;
-			file = file_it->data;
-			{
-				if (!vala_source_file_get_pkg (file)) {
-					char* __temp19;
-					char* __temp18;
+	if (cc_options != NULL) {
+		{
+			char** cc_option_collection;
+			char** cc_option_it;
+			cc_option_collection = cc_options;
+			for (cc_option_it = cc_option_collection; *cc_option_it != NULL; cc_option_it = cc_option_it + 1) {
+				const char* __temp18;
+				char* cc_option;
+				__temp18 = NULL;
+				cc_option = (__temp18 = *cc_option_it, (__temp18 == NULL ? NULL : g_strdup (__temp18)));
+				{
 					char* __temp17;
 					char* __temp16;
-					__temp19 = NULL;
-					__temp18 = NULL;
 					__temp17 = NULL;
 					__temp16 = NULL;
-					cmdline = (__temp19 = g_strconcat (cmdline, (__temp18 = (g_strconcat (" ", (__temp17 = g_shell_quote ((__temp16 = vala_source_file_get_csource_filename (file)))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp19);
-					(__temp18 = (g_free (__temp18), NULL));
-					(__temp17 = (g_free (__temp17), NULL));
+					cmdline = (__temp17 = g_strconcat (cmdline, (__temp16 = (g_strconcat (" ", cc_option, NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp17);
 					(__temp16 = (g_free (__temp16), NULL));
+					(cc_option = (g_free (cc_option), NULL));
 				}
 			}
 		}
 	}
+	/* we're only interested in non-pkg source files */
+	source_files = vala_code_context_get_source_files (context);
+	{
+		GeeCollection* file_collection;
+		GeeIterator* file_it;
+		file_collection = source_files;
+		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
+		while (gee_iterator_next (file_it)) {
+			ValaSourceFile* file;
+			file = gee_iterator_get (file_it);
+			{
+				if (!vala_source_file_get_pkg (file)) {
+					char* __temp22;
+					char* __temp21;
+					char* __temp20;
+					char* __temp19;
+					__temp22 = NULL;
+					__temp21 = NULL;
+					__temp20 = NULL;
+					__temp19 = NULL;
+					cmdline = (__temp22 = g_strconcat (cmdline, (__temp21 = (g_strconcat (" ", (__temp20 = g_shell_quote ((__temp19 = vala_source_file_get_csource_filename (file)))), NULL))), NULL), (cmdline = (g_free (cmdline), NULL)), __temp22);
+					(__temp21 = (g_free (__temp21), NULL));
+					(__temp20 = (g_free (__temp20), NULL));
+					(__temp19 = (g_free (__temp19), NULL));
+				}
+				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
+			}
+		}
+		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
+	}
 	{
 		g_spawn_command_line_sync (cmdline, NULL, NULL, &exit_status, &inner_error);
 		if (inner_error != NULL) {
@@ -208,10 +232,10 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			g_clear_error (&inner_error);
 		}
 		if (exit_status != 0) {
-			char* __temp21;
-			__temp21 = NULL;
-			vala_report_error (NULL, (__temp21 = g_strdup_printf ("cc exited with status %d", exit_status)));
-			(__temp21 = (g_free (__temp21), NULL));
+			char* __temp23;
+			__temp23 = NULL;
+			vala_report_error (NULL, (__temp23 = g_strdup_printf ("cc exited with status %d", exit_status)));
+			(__temp23 = (g_free (__temp23), NULL));
 		}
 	}
 	goto __finally1;
@@ -227,32 +251,34 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	__finally1:
 	;
 	{
-		GList* __temp24;
-		GList* file_it;
-		__temp24 = NULL;
-		__temp24 = source_files;
-		for (file_it = __temp24; file_it != NULL; file_it = file_it->next) {
+		GeeCollection* file_collection;
+		GeeIterator* file_it;
+		file_collection = source_files;
+		file_it = gee_iterable_iterator (GEE_ITERABLE (file_collection));
+		while (gee_iterator_next (file_it)) {
 			ValaSourceFile* file;
-			file = file_it->data;
+			file = gee_iterator_get (file_it);
 			{
 				/* remove generated C source and header files */
 				if (!vala_source_file_get_pkg (file)) {
-					char* __temp22;
-					char* __temp23;
-					__temp22 = NULL;
-					g_unlink ((__temp22 = vala_source_file_get_csource_filename (file)));
-					(__temp22 = (g_free (__temp22), NULL));
-					__temp23 = NULL;
-					g_unlink ((__temp23 = vala_source_file_get_cheader_filename (file)));
-					(__temp23 = (g_free (__temp23), NULL));
+					char* __temp24;
+					char* __temp25;
+					__temp24 = NULL;
+					g_unlink ((__temp24 = vala_source_file_get_csource_filename (file)));
+					(__temp24 = (g_free (__temp24), NULL));
+					__temp25 = NULL;
+					g_unlink ((__temp25 = vala_source_file_get_cheader_filename (file)));
+					(__temp25 = (g_free (__temp25), NULL));
 				}
+				(file == NULL ? NULL : (file = (g_object_unref (file), NULL)));
 			}
 		}
+		(file_it == NULL ? NULL : (file_it = (g_object_unref (file_it), NULL)));
 	}
 	(pc = (g_free (pc), NULL));
 	(pkgflags = (g_free (pkgflags), NULL));
 	(cmdline = (g_free (cmdline), NULL));
-	(source_files == NULL ? NULL : (source_files = (g_list_free (source_files), NULL)));
+	(source_files == NULL ? NULL : (source_files = (g_object_unref (source_files), NULL)));
 }
 
 
@@ -267,7 +293,7 @@ static void vala_ccode_compiler_init (ValaCCodeCompiler * self)
 }
 
 
-GType vala_ccode_compiler_get_type ()
+GType vala_ccode_compiler_get_type (void)
 {
 	static GType vala_ccode_compiler_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_compiler_type_id == 0)) {
