@@ -20,10 +20,9 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valainterfaceregisterfunction.h"
+#include <vala/valasymbol.h>
 #include <vala/valatypereference.h>
 #include <ccode/valaccodefunctioncall.h>
 #include <ccode/valaccodeidentifier.h>
@@ -54,14 +53,10 @@ static void vala_interface_register_function_dispose (GObject * obj);
 
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaInterfaceRegisterFunction * self;
 	g_return_val_if_fail (VALA_IS_INTERFACE (iface), NULL);
-	__params = g_new0 (GParameter, 1);
-	__params_it = __params;
-	(__params_it->name = "interface-reference", g_value_init (&__params_it->value, VALA_TYPE_INTERFACE), g_value_set_object (&__params_it->value, iface), __params_it++);
-	self = g_object_newv (VALA_TYPE_INTERFACE_REGISTER_FUNCTION, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_INTERFACE_REGISTER_FUNCTION, 0, NULL);
+	vala_interface_register_function_set_interface_reference (self, iface);
 	return self;
 }
 
@@ -69,7 +64,7 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterfa
 static ValaDataType* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return VALA_DATA_TYPE (g_object_ref (vala_interface_register_function_get_interface_reference (self)));
 }
 
@@ -77,7 +72,7 @@ static ValaDataType* vala_interface_register_function_real_get_type_declaration
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return vala_interface_get_type_cname (vala_interface_register_function_get_interface_reference (self));
 }
 
@@ -87,17 +82,17 @@ static char* vala_interface_register_function_real_get_base_init_func_name (Vala
 	ValaInterfaceRegisterFunction * self;
 	char* __temp2;
 	char* __temp3;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	__temp2 = NULL;
 	__temp3 = NULL;
-	return (__temp3 = g_strdup_printf ("%s_base_init", (__temp2 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (vala_interface_register_function_get_interface_reference (self)), NULL))), (__temp2 = (g_free (__temp2), NULL)), __temp3);
+	return (__temp3 = g_strdup_printf ("%s_base_init", (__temp2 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))), (__temp2 = (g_free (__temp2), NULL)), __temp3);
 }
 
 
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return g_strdup ("NULL");
 }
 
@@ -105,7 +100,7 @@ static char* vala_interface_register_function_real_get_class_init_func_name (Val
 static char* vala_interface_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return g_strdup ("0");
 }
 
@@ -113,7 +108,7 @@ static char* vala_interface_register_function_real_get_instance_struct_size (Val
 static char* vala_interface_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return g_strdup ("NULL");
 }
 
@@ -121,7 +116,7 @@ static char* vala_interface_register_function_real_get_instance_init_func_name (
 static char* vala_interface_register_function_real_get_parent_type_name (ValaTypeRegisterFunction* base)
 {
 	ValaInterfaceRegisterFunction * self;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	return g_strdup ("G_TYPE_INTERFACE");
 }
 
@@ -130,44 +125,56 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 {
 	ValaInterfaceRegisterFunction * self;
 	ValaCCodeFragment* frag;
-	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
+	self = ((ValaInterfaceRegisterFunction*) base);
 	frag = g_object_new (VALA_TYPE_CCODE_FRAGMENT, NULL);
 	{
-		GList* __temp14;
-		GList* prereq_ref_it;
-		__temp14 = NULL;
-		__temp14 = vala_interface_get_prerequisites (vala_interface_register_function_get_interface_reference (self));
-		for (prereq_ref_it = __temp14; prereq_ref_it != NULL; prereq_ref_it = prereq_ref_it->next) {
+		GeeCollection* prereq_ref_collection;
+		GeeIterator* prereq_ref_it;
+		prereq_ref_collection = vala_interface_get_prerequisites (vala_interface_register_function_get_interface_reference (self));
+		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
+		while (gee_iterator_next (prereq_ref_it)) {
 			ValaTypeReference* prereq_ref;
-			prereq_ref = prereq_ref_it->data;
+			prereq_ref = gee_iterator_get (prereq_ref_it);
 			{
 				ValaDataType* __temp9;
 				ValaDataType* prereq;
+				ValaCCodeIdentifier* __temp10;
+				ValaCCodeFunctionCall* __temp11;
 				ValaCCodeFunctionCall* func;
-				ValaCCodeIdentifier* __temp11;
-				char* __temp10;
-				ValaCCodeIdentifier* __temp12;
-				ValaCCodeExpressionStatement* __temp13;
+				ValaCCodeIdentifier* __temp14;
+				char* __temp13;
+				char* __temp12;
+				ValaCCodeIdentifier* __temp16;
+				char* __temp15;
+				ValaCCodeExpressionStatement* __temp17;
 				/* register all prerequisites */
 				__temp9 = NULL;
 				prereq = (__temp9 = vala_type_reference_get_data_type (prereq_ref), (__temp9 == NULL ? NULL : g_object_ref (__temp9)));
-				func = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION (vala_ccode_identifier_new ("g_type_interface_add_prerequisite")));
-				__temp11 = NULL;
 				__temp10 = NULL;
-				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((__temp11 = vala_ccode_identifier_new (g_strdup_printf ("%s_type_id", (__temp10 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (vala_interface_register_function_get_interface_reference (self)), NULL)))))));
-				(__temp11 == NULL ? NULL : (__temp11 = (g_object_unref (__temp11), NULL)));
-				(__temp10 = (g_free (__temp10), NULL));
-				__temp12 = NULL;
-				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((__temp12 = vala_ccode_identifier_new (vala_data_type_get_type_id (prereq)))));
-				(__temp12 == NULL ? NULL : (__temp12 = (g_object_unref (__temp12), NULL)));
+				__temp11 = NULL;
+				func = (__temp11 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((__temp10 = vala_ccode_identifier_new ("g_type_interface_add_prerequisite")))), (__temp10 == NULL ? NULL : (__temp10 = (g_object_unref (__temp10), NULL))), __temp11);
+				__temp14 = NULL;
 				__temp13 = NULL;
-				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((__temp13 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (func)))));
-				(__temp13 == NULL ? NULL : (__temp13 = (g_object_unref (__temp13), NULL)));
+				__temp12 = NULL;
+				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((__temp14 = vala_ccode_identifier_new ((__temp13 = g_strdup_printf ("%s_type_id", (__temp12 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (vala_interface_register_function_get_interface_reference (self)), NULL))))))));
+				(__temp14 == NULL ? NULL : (__temp14 = (g_object_unref (__temp14), NULL)));
+				(__temp13 = (g_free (__temp13), NULL));
+				(__temp12 = (g_free (__temp12), NULL));
+				__temp16 = NULL;
+				__temp15 = NULL;
+				vala_ccode_function_call_add_argument (func, VALA_CCODE_EXPRESSION ((__temp16 = vala_ccode_identifier_new ((__temp15 = vala_data_type_get_type_id (prereq))))));
+				(__temp16 == NULL ? NULL : (__temp16 = (g_object_unref (__temp16), NULL)));
+				(__temp15 = (g_free (__temp15), NULL));
+				__temp17 = NULL;
+				vala_ccode_fragment_append (frag, VALA_CCODE_NODE ((__temp17 = vala_ccode_expression_statement_new (VALA_CCODE_EXPRESSION (func)))));
+				(__temp17 == NULL ? NULL : (__temp17 = (g_object_unref (__temp17), NULL)));
+				(prereq_ref == NULL ? NULL : (prereq_ref = (g_object_unref (prereq_ref), NULL)));
 				(prereq == NULL ? NULL : (prereq = (g_object_unref (prereq), NULL)));
 				(func == NULL ? NULL : (func = (g_object_unref (func), NULL)));
 			}
 		}
-		(__temp14 == NULL ? NULL : (__temp14 = (g_list_free (__temp14), NULL)));
+		(prereq_ref_collection == NULL ? NULL : (prereq_ref_collection = (g_object_unref (prereq_ref_collection), NULL)));
+		(prereq_ref_it == NULL ? NULL : (prereq_ref_it = (g_object_unref (prereq_ref_it), NULL)));
 	}
 	return frag;
 	(frag == NULL ? NULL : (frag = (g_object_unref (frag), NULL)));
@@ -183,10 +190,8 @@ ValaInterface* vala_interface_register_function_get_interface_reference (ValaInt
 
 void vala_interface_register_function_set_interface_reference (ValaInterfaceRegisterFunction* self, ValaInterface* value)
 {
-	ValaInterface* __temp17;
 	g_return_if_fail (VALA_IS_INTERFACE_REGISTER_FUNCTION (self));
-	__temp17 = NULL;
-	self->priv->_interface_reference = (__temp17 = g_object_ref (value), (self->priv->_interface_reference == NULL ? NULL : (self->priv->_interface_reference = (g_object_unref (self->priv->_interface_reference), NULL))), __temp17);
+	self->priv->_interface_reference = value;
 }
 
 
@@ -229,7 +234,7 @@ static void vala_interface_register_function_class_init (ValaInterfaceRegisterFu
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_instance_init_func_name = vala_interface_register_function_real_get_instance_init_func_name;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_parent_type_name = vala_interface_register_function_real_get_parent_type_name;
 	VALA_TYPE_REGISTER_FUNCTION_CLASS (klass)->get_type_interface_init_statements = vala_interface_register_function_real_get_type_interface_init_statements;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE, g_param_spec_object ("interface-reference", "foo", "bar", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE, g_param_spec_object ("interface-reference", "foo", "bar", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -245,14 +250,13 @@ static void vala_interface_register_function_dispose (GObject * obj)
 	ValaInterfaceRegisterFunctionClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (obj);
-	(self->priv->_interface_reference == NULL ? NULL : (self->priv->_interface_reference = (g_object_unref (self->priv->_interface_reference), NULL)));
 	klass = VALA_INTERFACE_REGISTER_FUNCTION_CLASS (g_type_class_peek (VALA_TYPE_INTERFACE_REGISTER_FUNCTION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_interface_register_function_get_type ()
+GType vala_interface_register_function_get_type (void)
 {
 	static GType vala_interface_register_function_type_id = 0;
 	if (G_UNLIKELY (vala_interface_register_function_type_id == 0)) {
