@@ -61,7 +61,7 @@ struct _ValaInterfaceRegisterFunctionClass {
 ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterface* iface);
 ValaInterface* vala_interface_register_function_get_interface_reference (ValaInterfaceRegisterFunction* self);
 void vala_interface_register_function_set_interface_reference (ValaInterfaceRegisterFunction* self, ValaInterface* value);
-GType vala_interface_register_function_get_type ();
+GType vala_interface_register_function_get_type (void);
 
 G_END_DECLS
 
