@@ -20,17 +20,25 @@
  * 	Raffaele Sandrini <rasa@gmx.ch>
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaarray.h"
 #include <vala/valatypeparameter.h>
 #include <vala/valaarraylengthfield.h>
 #include <vala/valaarrayresizemethod.h>
+#include <vala/valaarraymovemethod.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaarray.h>
-#include <vala/valareport.h>
+#include <vala/valafield.h>
+#include <vala/valamemberaccessibility.h>
+#include <vala/valasourcefile.h>
+#include <vala/valacodecontext.h>
+#include <vala/valanamespace.h>
+#include <vala/valatypereference.h>
 #include <vala/valasymbol.h>
+#include <vala/valascope.h>
+#include <vala/valamethod.h>
+#include <vala/valaformalparameter.h>
+#include <vala/valareport.h>
 
 struct _ValaArrayPrivate {
 	ValaDataType* _element_type;
@@ -39,6 +47,7 @@ struct _ValaArrayPrivate {
 	char* cname;
 	ValaArrayLengthField* length_field;
 	ValaArrayResizeMethod* resize_method;
+	ValaArrayMoveMethod* move_method;
 };
 #define VALA_ARRAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY, ValaArrayPrivate))
 enum  {
@@ -50,9 +59,9 @@ enum  {
 static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type);
 static gboolean vala_array_real_is_reference_type (ValaDataType* base);
 static char* vala_array_real_get_upper_case_cname (ValaDataType* base, const char* infix);
-static char* vala_array_real_get_lower_case_cname (ValaDataType* base, const char* infix);
+static char* vala_array_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static char* vala_array_real_get_free_function (ValaDataType* base);
-static GList* vala_array_real_get_cheader_filenames (ValaDataType* base);
+static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base);
 static char* vala_array_real_get_marshaller_type_name (ValaDataType* base);
 static char* vala_array_real_get_get_value_function (ValaDataType* base);
 static char* vala_array_real_get_set_value_function (ValaDataType* base);
@@ -67,13 +76,18 @@ ValaArray* vala_array_new (ValaDataType* _element_type, gint _rank, ValaSourceRe
 	GParameter * __params_it;
 	ValaArray * self;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (_element_type), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (_source_reference), NULL);
-	__params = g_new0 (GParameter, 3);
+	g_return_val_if_fail (_source_reference == NULL || VALA_IS_SOURCE_REFERENCE (_source_reference), NULL);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "rank", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _rank), __params_it++);
 	(__params_it->name = "element-type", g_value_init (&__params_it->value, VALA_TYPE_DATA_TYPE), g_value_set_object (&__params_it->value, _element_type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, _source_reference), __params_it++);
 	self = g_object_newv (VALA_TYPE_ARRAY, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), _source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -84,27 +98,27 @@ ValaArray* vala_array_new_with_type_parameter (ValaTypeParameter* _element_type_
 	GParameter * __params_it;
 	ValaArray * self;
 	g_return_val_if_fail (VALA_IS_TYPE_PARAMETER (_element_type_parameter), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (_source_reference), NULL);
-	__params = g_new0 (GParameter, 3);
+	g_return_val_if_fail (_source_reference == NULL || VALA_IS_SOURCE_REFERENCE (_source_reference), NULL);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "rank", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _rank), __params_it++);
 	(__params_it->name = "element-type-parameter", g_value_init (&__params_it->value, VALA_TYPE_TYPE_PARAMETER), g_value_set_object (&__params_it->value, _element_type_parameter), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, _source_reference), __params_it++);
 	self = g_object_newv (VALA_TYPE_ARRAY, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), _source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
 
-/**
- * Returns the name of this data type as it is used in C code.
- *
- * @return the name to be used in C code
- */
 static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaArray * self;
 	const char* __temp4;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	if (self->priv->cname == NULL) {
 		if (vala_array_get_element_type (self) != NULL) {
 			if (vala_data_type_is_reference_type (vala_array_get_element_type (self))) {
@@ -130,84 +144,46 @@ static char* vala_array_real_get_cname (ValaDataType* base, gboolean const_type)
 }
 
 
-/**
- * Checks whether this data type has value or reference type semantics.
- *
- * @return true if this data type has reference type semantics
- */
 static gboolean vala_array_real_is_reference_type (ValaDataType* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return TRUE;
 }
 
 
-/**
- * Returns the C name of this data type in upper case. Words are
- * separated by underscores. The upper case C name of the namespace is
- * prefix of the result.
- *
- * @param infix a string to be placed between namespace and data type
- *              name or null
- * @return      the upper case name to be used in C code
- */
 static char* vala_array_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return NULL;
 }
 
 
-/**
- * Returns the C name of this data type in lower case. Words are
- * separated by underscores. The lower case C name of the namespace is
- * prefix of the result.
- *
- * @param infix a string to be placed between namespace and data type
- *              name or null
- * @return      the lower case name to be used in C code
- */
-static char* vala_array_real_get_lower_case_cname (ValaDataType* base, const char* infix)
+static char* vala_array_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return NULL;
 }
 
 
-/**
- * Returns the C function name that frees instances of this data type.
- * This is only valid for data types with reference type semantics that
- * do not support reference counting. The specified C function must
- * accept one argument pointing to the instance to be freed.
- *
- * @return the name of the C function or null if this data type is not a
- *         reference type or if it supports reference counting
- */
 static char* vala_array_real_get_free_function (ValaDataType* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return g_strdup ("g_free");
 }
 
 
-/**
- * Returns a list of C header filenames users of this data type must
- * include.
- *
- * @return list of C header filenames for this data type
- */
-static GList* vala_array_real_get_cheader_filenames (ValaDataType* base)
+static GeeCollection* vala_array_real_get_cheader_filenames (ValaSymbol* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	if (vala_array_get_element_type (self) != NULL) {
-		return vala_data_type_get_cheader_filenames (vala_array_get_element_type (self));
+		return vala_symbol_get_cheader_filenames (VALA_SYMBOL (vala_array_get_element_type (self)));
 	} else {
-		return NULL;
+		return VALA_SYMBOL_CLASS (vala_array_parent_class)->get_cheader_filenames (VALA_SYMBOL (VALA_DATA_TYPE (self)));
 	}
 }
 
@@ -215,7 +191,7 @@ static GList* vala_array_real_get_cheader_filenames (ValaDataType* base)
 static char* vala_array_real_get_marshaller_type_name (ValaDataType* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return g_strdup ("POINTER");
 }
 
@@ -223,7 +199,7 @@ static char* vala_array_real_get_marshaller_type_name (ValaDataType* base)
 static char* vala_array_real_get_get_value_function (ValaDataType* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return g_strdup ("g_value_get_pointer");
 }
 
@@ -231,26 +207,111 @@ static char* vala_array_real_get_get_value_function (ValaDataType* base)
 static char* vala_array_real_get_set_value_function (ValaDataType* base)
 {
 	ValaArray * self;
-	self = VALA_ARRAY (base);
+	self = ((ValaArray*) base);
 	return g_strdup ("g_value_set_pointer");
 }
 
 
 ValaArrayLengthField* vala_array_get_length_field (ValaArray* self)
 {
-	ValaArrayLengthField* __temp15;
+	ValaArrayLengthField* __temp18;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
-	__temp15 = NULL;
-	return (__temp15 = self->priv->length_field, (__temp15 == NULL ? NULL : g_object_ref (__temp15)));
+	if (self->priv->length_field == NULL) {
+		ValaArrayLengthField* __temp15;
+		ValaNamespace* root_symbol;
+		ValaTypeReference* __temp16;
+		ValaDataType* __temp17;
+		__temp15 = NULL;
+		self->priv->length_field = (__temp15 = vala_array_length_field_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), __temp15);
+		((ValaField*) self->priv->length_field)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		__temp16 = NULL;
+		vala_field_set_type_reference (VALA_FIELD (self->priv->length_field), (__temp16 = vala_type_reference_new ()));
+		(__temp16 == NULL ? NULL : (__temp16 = (g_object_unref (__temp16), NULL)));
+		__temp17 = NULL;
+		vala_type_reference_set_data_type (vala_field_get_type_reference (((ValaField*) self->priv->length_field)), (__temp17 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(__temp17 == NULL ? NULL : (__temp17 = (g_object_unref (__temp17), NULL)));
+		(root_symbol = (g_object_unref (root_symbol), NULL));
+	}
+	__temp18 = NULL;
+	return (__temp18 = self->priv->length_field, (__temp18 == NULL ? NULL : g_object_ref (__temp18)));
 }
 
 
 ValaArrayResizeMethod* vala_array_get_resize_method (ValaArray* self)
 {
-	ValaArrayResizeMethod* __temp17;
+	ValaArrayResizeMethod* __temp24;
 	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
-	__temp17 = NULL;
-	return (__temp17 = self->priv->resize_method, (__temp17 == NULL ? NULL : g_object_ref (__temp17)));
+	if (self->priv->resize_method == NULL) {
+		ValaArrayResizeMethod* __temp20;
+		ValaTypeReference* __temp21;
+		ValaNamespace* root_symbol;
+		ValaTypeReference* int_type;
+		ValaDataType* __temp22;
+		ValaFormalParameter* __temp23;
+		__temp20 = NULL;
+		self->priv->resize_method = (__temp20 = vala_array_resize_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), __temp20);
+		__temp21 = NULL;
+		vala_method_set_return_type (VALA_METHOD (self->priv->resize_method), (__temp21 = vala_type_reference_new ()));
+		(__temp21 == NULL ? NULL : (__temp21 = (g_object_unref (__temp21), NULL)));
+		((ValaMethod*) self->priv->resize_method)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		vala_method_set_cname (VALA_METHOD (self->priv->resize_method), "g_renew");
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		int_type = vala_type_reference_new ();
+		__temp22 = NULL;
+		vala_type_reference_set_data_type (int_type, (__temp22 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(__temp22 == NULL ? NULL : (__temp22 = (g_object_unref (__temp22), NULL)));
+		__temp23 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->resize_method), (__temp23 = vala_formal_parameter_new ("length", int_type, NULL)));
+		(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
+		vala_method_set_returns_modified_pointer (VALA_METHOD (self->priv->resize_method), TRUE);
+		(root_symbol = (g_object_unref (root_symbol), NULL));
+		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
+	}
+	__temp24 = NULL;
+	return (__temp24 = self->priv->resize_method, (__temp24 == NULL ? NULL : g_object_ref (__temp24)));
+}
+
+
+ValaArrayMoveMethod* vala_array_get_move_method (ValaArray* self)
+{
+	ValaArrayMoveMethod* __temp32;
+	g_return_val_if_fail (VALA_IS_ARRAY (self), NULL);
+	if (self->priv->move_method == NULL) {
+		ValaArrayMoveMethod* __temp26;
+		ValaTypeReference* __temp27;
+		ValaNamespace* root_symbol;
+		ValaTypeReference* int_type;
+		ValaDataType* __temp28;
+		ValaFormalParameter* __temp29;
+		ValaFormalParameter* __temp30;
+		ValaFormalParameter* __temp31;
+		__temp26 = NULL;
+		self->priv->move_method = (__temp26 = vala_array_move_method_new (vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL))), __temp26);
+		__temp27 = NULL;
+		vala_method_set_return_type (VALA_METHOD (self->priv->move_method), (__temp27 = vala_type_reference_new ()));
+		(__temp27 == NULL ? NULL : (__temp27 = (g_object_unref (__temp27), NULL)));
+		((ValaMethod*) self->priv->move_method)->access = VALA_MEMBER_ACCESSIBILITY_PUBLIC;
+		vala_method_set_cname (VALA_METHOD (self->priv->move_method), "_vala_array_move");
+		root_symbol = g_object_ref (vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+		int_type = vala_type_reference_new ();
+		__temp28 = NULL;
+		vala_type_reference_set_data_type (int_type, (__temp28 = VALA_DATA_TYPE (vala_scope_lookup (vala_symbol_get_scope (((ValaSymbol*) root_symbol)), "int"))));
+		(__temp28 == NULL ? NULL : (__temp28 = (g_object_unref (__temp28), NULL)));
+		__temp29 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp29 = vala_formal_parameter_new ("src", int_type, NULL)));
+		(__temp29 == NULL ? NULL : (__temp29 = (g_object_unref (__temp29), NULL)));
+		__temp30 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp30 = vala_formal_parameter_new ("dest", int_type, NULL)));
+		(__temp30 == NULL ? NULL : (__temp30 = (g_object_unref (__temp30), NULL)));
+		__temp31 = NULL;
+		vala_method_add_parameter (VALA_METHOD (self->priv->move_method), (__temp31 = vala_formal_parameter_new ("length", int_type, NULL)));
+		(__temp31 == NULL ? NULL : (__temp31 = (g_object_unref (__temp31), NULL)));
+		(root_symbol = (g_object_unref (root_symbol), NULL));
+		(int_type == NULL ? NULL : (int_type = (g_object_unref (int_type), NULL)));
+	}
+	__temp32 = NULL;
+	return (__temp32 = self->priv->move_method, (__temp32 == NULL ? NULL : g_object_ref (__temp32)));
 }
 
 
@@ -263,12 +324,8 @@ ValaDataType* vala_array_get_element_type (ValaArray* self)
 
 void vala_array_set_element_type (ValaArray* self, ValaDataType* value)
 {
-	ValaDataType* __temp21;
-	ValaDataType* __temp20;
 	g_return_if_fail (VALA_IS_ARRAY (self));
-	__temp21 = NULL;
-	__temp20 = NULL;
-	self->priv->_element_type = (__temp21 = (__temp20 = value, (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), __temp21);
+	self->priv->_element_type = value;
 }
 
 
@@ -281,12 +338,8 @@ ValaTypeParameter* vala_array_get_element_type_parameter (ValaArray* self)
 
 void vala_array_set_element_type_parameter (ValaArray* self, ValaTypeParameter* value)
 {
-	ValaTypeParameter* __temp24;
-	ValaTypeParameter* __temp23;
 	g_return_if_fail (VALA_IS_ARRAY (self));
-	__temp24 = NULL;
-	__temp23 = NULL;
-	self->priv->_element_type_parameter = (__temp24 = (__temp23 = value, (__temp23 == NULL ? NULL : g_object_ref (__temp23))), (self->priv->_element_type_parameter == NULL ? NULL : (self->priv->_element_type_parameter = (g_object_unref (self->priv->_element_type_parameter), NULL))), __temp24);
+	self->priv->_element_type_parameter = value;
 }
 
 
@@ -316,11 +369,7 @@ static GObject * vala_array_constructor (GType type, guint n_construct_propertie
 	self = VALA_ARRAY (obj);
 	{
 		gint i;
-		char* __temp29;
-		ValaArrayLengthField* __temp30;
-		ValaSymbol* __temp31;
-		ValaArrayResizeMethod* __temp32;
-		ValaSymbol* __temp33;
+		char* __temp40;
 		/* FIXME: this implementation reveals compiler bugs 
 		string commas = "";
 		int i = rank - 1;
@@ -336,36 +385,26 @@ static GObject * vala_array_constructor (GType type, guint n_construct_propertie
 		}
 		i = vala_array_get_rank (self) - 1;
 		if (vala_array_get_element_type (self) != NULL) {
-			char* __temp26;
-			__temp26 = NULL;
-			(vala_data_type_set_name (VALA_DATA_TYPE (self), (__temp26 = g_strdup_printf ("%s[", vala_data_type_get_name (vala_array_get_element_type (self))))), vala_data_type_get_name (VALA_DATA_TYPE (self)));
-			(__temp26 = (g_free (__temp26), NULL));
+			char* __temp37;
+			__temp37 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (__temp37 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type (self))))));
+			(__temp37 = (g_free (__temp37), NULL));
 		} else {
-			char* __temp27;
-			__temp27 = NULL;
-			(vala_data_type_set_name (VALA_DATA_TYPE (self), (__temp27 = g_strdup_printf ("%s[", vala_type_parameter_get_name (vala_array_get_element_type_parameter (self))))), vala_data_type_get_name (VALA_DATA_TYPE (self)));
-			(__temp27 = (g_free (__temp27), NULL));
+			char* __temp38;
+			__temp38 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (__temp38 = g_strdup_printf ("%s[", vala_symbol_get_name (((ValaSymbol*) vala_array_get_element_type_parameter (self))))));
+			(__temp38 = (g_free (__temp38), NULL));
 		}
 		while (i > 0) {
-			char* __temp28;
-			__temp28 = NULL;
-			(vala_data_type_set_name (VALA_DATA_TYPE (self), (__temp28 = g_strdup_printf ("%s,", vala_data_type_get_name (VALA_DATA_TYPE (self))))), vala_data_type_get_name (VALA_DATA_TYPE (self)));
-			(__temp28 = (g_free (__temp28), NULL));
+			char* __temp39;
+			__temp39 = NULL;
+			vala_symbol_set_name (VALA_SYMBOL (self), (__temp39 = g_strdup_printf ("%s,", vala_symbol_get_name (((ValaSymbol*) self)))));
+			(__temp39 = (g_free (__temp39), NULL));
 			i--;
 		}
-		__temp29 = NULL;
-		(vala_data_type_set_name (VALA_DATA_TYPE (self), (__temp29 = g_strdup_printf ("%s]", vala_data_type_get_name (VALA_DATA_TYPE (self))))), vala_data_type_get_name (VALA_DATA_TYPE (self)));
-		(__temp29 = (g_free (__temp29), NULL));
-		__temp30 = NULL;
-		self->priv->length_field = (__temp30 = vala_array_length_field_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL))), __temp30);
-		__temp31 = NULL;
-		(vala_code_node_set_symbol (VALA_CODE_NODE (self->priv->length_field), (__temp31 = vala_symbol_new (VALA_CODE_NODE (self->priv->length_field)))), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->length_field)));
-		(__temp31 == NULL ? NULL : (__temp31 = (g_object_unref (__temp31), NULL)));
-		__temp32 = NULL;
-		self->priv->resize_method = (__temp32 = vala_array_resize_method_new (vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL))), __temp32);
-		__temp33 = NULL;
-		(vala_code_node_set_symbol (VALA_CODE_NODE (self->priv->resize_method), (__temp33 = vala_symbol_new (VALA_CODE_NODE (self->priv->resize_method)))), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->resize_method)));
-		(__temp33 == NULL ? NULL : (__temp33 = (g_object_unref (__temp33), NULL)));
+		__temp40 = NULL;
+		vala_symbol_set_name (VALA_SYMBOL (self), (__temp40 = g_strdup_printf ("%s]", vala_symbol_get_name (((ValaSymbol*) self)))));
+		(__temp40 = (g_free (__temp40), NULL));
 	}
 	return obj;
 }
@@ -418,9 +457,9 @@ static void vala_array_class_init (ValaArrayClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_array_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_type = vala_array_real_is_reference_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_upper_case_cname = vala_array_real_get_upper_case_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_array_real_get_lower_case_cname;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_array_real_get_lower_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_free_function = vala_array_real_get_free_function;
-	VALA_DATA_TYPE_CLASS (klass)->get_cheader_filenames = vala_array_real_get_cheader_filenames;
+	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_array_real_get_cheader_filenames;
 	VALA_DATA_TYPE_CLASS (klass)->get_marshaller_type_name = vala_array_real_get_marshaller_type_name;
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_array_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_array_real_get_set_value_function;
@@ -442,18 +481,17 @@ static void vala_array_dispose (GObject * obj)
 	ValaArrayClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_ARRAY (obj);
-	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
-	(self->priv->_element_type_parameter == NULL ? NULL : (self->priv->_element_type_parameter = (g_object_unref (self->priv->_element_type_parameter), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->length_field == NULL ? NULL : (self->priv->length_field = (g_object_unref (self->priv->length_field), NULL)));
 	(self->priv->resize_method == NULL ? NULL : (self->priv->resize_method = (g_object_unref (self->priv->resize_method), NULL)));
+	(self->priv->move_method == NULL ? NULL : (self->priv->move_method = (g_object_unref (self->priv->move_method), NULL)));
 	klass = VALA_ARRAY_CLASS (g_type_class_peek (VALA_TYPE_ARRAY));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_array_get_type ()
+GType vala_array_get_type (void)
 {
 	static GType vala_array_type_id = 0;
 	if (G_UNLIKELY (vala_array_type_id == 0)) {
