@@ -20,10 +20,11 @@
  * 	Raffaele Sandrini <rasa@gmx.ch>
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaarraycreationexpression.h"
+#include <gee/arraylist.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valatypereference.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaarraycreationexpression.h>
@@ -33,7 +34,7 @@
 struct _ValaArrayCreationExpressionPrivate {
 	ValaTypeReference* _element_type;
 	gint _rank;
-	GList* sizes;
+	GeeList* sizes;
 	ValaInitializerList* _initializer_list;
 };
 #define VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionPrivate))
@@ -55,35 +56,40 @@ void vala_array_creation_expression_append_size (ValaArrayCreationExpression* se
 {
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (size));
-	self->priv->sizes = g_list_append (self->priv->sizes, g_object_ref (size));
+	gee_collection_add (GEE_COLLECTION (self->priv->sizes), size);
 }
 
 
 /**
  * Get the sizes for all dimensions ascending from left to right.
  */
-GList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self)
+GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self)
 {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
-	return g_list_copy (self->priv->sizes);
+	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, self->priv->sizes));
 }
 
 
-ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* _element_type, gint _rank, ValaInitializerList* _initializer, ValaSourceReference* source)
+ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReference* element_type, gint rank, ValaInitializerList* initializer_list, ValaSourceReference* source_reference)
 {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArrayCreationExpression * self;
-	g_return_val_if_fail (_element_type == NULL || VALA_IS_TYPE_REFERENCE (_element_type), NULL);
-	g_return_val_if_fail (_initializer == NULL || VALA_IS_INITIALIZER_LIST (_initializer), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 4);
+	g_return_val_if_fail (element_type == NULL || VALA_IS_TYPE_REFERENCE (element_type), NULL);
+	g_return_val_if_fail (initializer_list == NULL || VALA_IS_INITIALIZER_LIST (initializer_list), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
-	(__params_it->name = "element-type", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, _element_type), __params_it++);
-	(__params_it->name = "rank", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, _rank), __params_it++);
-	(__params_it->name = "initializer-list", g_value_init (&__params_it->value, VALA_TYPE_INITIALIZER_LIST), g_value_set_object (&__params_it->value, _initializer), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
+	(__params_it->name = "element-type", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, element_type), __params_it++);
+	(__params_it->name = "rank", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, rank), __params_it++);
+	(__params_it->name = "initializer-list", g_value_init (&__params_it->value, VALA_TYPE_INITIALIZER_LIST), g_value_set_object (&__params_it->value, initializer_list), __params_it++);
 	self = g_object_newv (VALA_TYPE_ARRAY_CREATION_EXPRESSION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -91,24 +97,26 @@ ValaArrayCreationExpression* vala_array_creation_expression_new (ValaTypeReferen
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaArrayCreationExpression * self;
-	self = VALA_ARRAY_CREATION_EXPRESSION (base);
+	self = ((ValaArrayCreationExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_array_creation_expression_get_element_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_array_creation_expression_get_element_type (self)), visitor);
 	}
 	if (self->priv->sizes != NULL) {
 		{
-			GList* __temp1;
-			GList* e_it;
-			__temp1 = NULL;
-			__temp1 = self->priv->sizes;
-			for (e_it = __temp1; e_it != NULL; e_it = e_it->next) {
+			GeeList* e_collection;
+			GeeIterator* e_it;
+			e_collection = self->priv->sizes;
+			e_it = gee_iterable_iterator (GEE_ITERABLE (e_collection));
+			while (gee_iterator_next (e_it)) {
 				ValaExpression* e;
-				e = e_it->data;
+				e = gee_iterator_get (e_it);
 				{
 					vala_code_node_accept (VALA_CODE_NODE (e), visitor);
+					(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
 				}
 			}
+			(e_it == NULL ? NULL : (e_it = (g_object_unref (e_it), NULL)));
 		}
 	}
 	vala_code_visitor_visit_begin_array_creation_expression (visitor, self);
@@ -128,12 +136,12 @@ ValaTypeReference* vala_array_creation_expression_get_element_type (ValaArrayCre
 
 void vala_array_creation_expression_set_element_type (ValaArrayCreationExpression* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp4;
 	ValaTypeReference* __temp3;
+	ValaTypeReference* __temp2;
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
-	__temp4 = NULL;
 	__temp3 = NULL;
-	self->priv->_element_type = (__temp4 = (__temp3 = value, (__temp3 == NULL ? NULL : g_object_ref (__temp3))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), __temp4);
+	__temp2 = NULL;
+	self->priv->_element_type = (__temp3 = (__temp2 = value, (__temp2 == NULL ? NULL : g_object_ref (__temp2))), (self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL))), __temp3);
 }
 
 
@@ -160,12 +168,12 @@ ValaInitializerList* vala_array_creation_expression_get_initializer_list (ValaAr
 
 void vala_array_creation_expression_set_initializer_list (ValaArrayCreationExpression* self, ValaInitializerList* value)
 {
-	ValaInitializerList* __temp8;
 	ValaInitializerList* __temp7;
+	ValaInitializerList* __temp6;
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
-	__temp8 = NULL;
 	__temp7 = NULL;
-	self->priv->_initializer_list = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL))), __temp8);
+	__temp6 = NULL;
+	self->priv->_initializer_list = (__temp7 = (__temp6 = value, (__temp6 == NULL ? NULL : g_object_ref (__temp6))), (self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL))), __temp7);
 }
 
 
@@ -222,6 +230,7 @@ static void vala_array_creation_expression_class_init (ValaArrayCreationExpressi
 static void vala_array_creation_expression_init (ValaArrayCreationExpression * self)
 {
 	self->priv = VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE (self);
+	self->priv->sizes = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -232,7 +241,7 @@ static void vala_array_creation_expression_dispose (GObject * obj)
 	GObjectClass * parent_class;
 	self = VALA_ARRAY_CREATION_EXPRESSION (obj);
 	(self->priv->_element_type == NULL ? NULL : (self->priv->_element_type = (g_object_unref (self->priv->_element_type), NULL)));
-	(self->priv->sizes == NULL ? NULL : (self->priv->sizes = (g_list_foreach (self->priv->sizes, (GFunc) g_object_unref, NULL), g_list_free (self->priv->sizes), NULL)));
+	(self->priv->sizes == NULL ? NULL : (self->priv->sizes = (g_object_unref (self->priv->sizes), NULL)));
 	(self->priv->_initializer_list == NULL ? NULL : (self->priv->_initializer_list = (g_object_unref (self->priv->_initializer_list), NULL)));
 	klass = VALA_ARRAY_CREATION_EXPRESSION_CLASS (g_type_class_peek (VALA_TYPE_ARRAY_CREATION_EXPRESSION));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
@@ -240,7 +249,7 @@ static void vala_array_creation_expression_dispose (GObject * obj)
 }
 
 
-GType vala_array_creation_expression_get_type ()
+GType vala_array_creation_expression_get_type (void)
 {
 	static GType vala_array_creation_expression_type_id = 0;
 	if (G_UNLIKELY (vala_array_creation_expression_type_id == 0)) {
