@@ -22,7 +22,6 @@
 
 #ifndef __VALAASSIGNMENT_H__
 #define __VALAASSIGNMENT_H__
-typedef struct _ValaAssignmentPrivate ValaAssignmentPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,6 +39,7 @@ G_BEGIN_DECLS
 #define VALA_IS_ASSIGNMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ASSIGNMENT))
 #define VALA_ASSIGNMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ASSIGNMENT, ValaAssignmentClass))
 
+typedef struct _ValaAssignmentPrivate ValaAssignmentPrivate;
 
 /**
  * Represents an assignment expression in the source code.
@@ -74,7 +74,7 @@ ValaAssignmentOperator vala_assignment_get_operator (ValaAssignment* self);
 void vala_assignment_set_operator (ValaAssignment* self, ValaAssignmentOperator value);
 ValaExpression* vala_assignment_get_right (ValaAssignment* self);
 void vala_assignment_set_right (ValaAssignment* self, ValaExpression* value);
-GType vala_assignment_get_type ();
+GType vala_assignment_get_type (void);
 
 G_END_DECLS
 
