@@ -20,8 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaattributeprocessor.h"
 #include <vala/valaattributeprocessor.h>
@@ -35,7 +33,6 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
-static void vala_attribute_processor_real_visit_flags (ValaCodeVisitor* base, ValaFlags* fl);
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop);
@@ -61,7 +58,7 @@ void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeCon
 static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
 	vala_source_file_accept_children (source_file, VALA_CODE_VISITOR (self));
 }
@@ -70,17 +67,32 @@ static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* ba
 static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base, ValaNamespace* ns)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 	vala_namespace_process_attributes (ns);
-	vala_code_node_accept_children (VALA_CODE_NODE (ns), VALA_CODE_VISITOR (self));
+	{
+		GeeCollection* ns_collection;
+		GeeIterator* ns_it;
+		ns_collection = vala_namespace_get_namespaces (ns);
+		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
+		while (gee_iterator_next (ns_it)) {
+			ValaNamespace* ns;
+			ns = gee_iterator_get (ns_it);
+			{
+				vala_code_node_accept (VALA_CODE_NODE (ns), VALA_CODE_VISITOR (self));
+				(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
+			}
+		}
+		(ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL)));
+		(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
+	}
 }
 
 
 static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, ValaClass* cl)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_CLASS (cl));
 	vala_class_process_attributes (cl);
 	vala_code_node_accept_children (VALA_CODE_NODE (cl), VALA_CODE_VISITOR (self));
@@ -90,7 +102,7 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_STRUCT (st));
 	vala_struct_process_attributes (st);
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
@@ -100,7 +112,7 @@ static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	vala_interface_process_attributes (iface);
 	vala_code_node_accept_children (VALA_CODE_NODE (iface), VALA_CODE_VISITOR (self));
@@ -110,25 +122,16 @@ static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_ENUM (en));
 	vala_enum_process_attributes (en);
 }
 
 
-static void vala_attribute_processor_real_visit_flags (ValaCodeVisitor* base, ValaFlags* fl)
-{
-	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (VALA_IS_FLAGS (fl));
-	vala_flags_process_attributes (fl);
-}
-
-
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_METHOD (m));
 	vala_method_process_attributes (m);
 }
@@ -137,7 +140,7 @@ static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 	vala_method_process_attributes (VALA_METHOD (m));
 }
@@ -146,7 +149,7 @@ static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	vala_property_process_attributes (prop);
 }
@@ -155,7 +158,7 @@ static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base,
 static void vala_attribute_processor_real_visit_callback (ValaCodeVisitor* base, ValaCallback* cb)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_CALLBACK (cb));
 	vala_callback_process_attributes (cb);
 }
@@ -164,7 +167,7 @@ static void vala_attribute_processor_real_visit_callback (ValaCodeVisitor* base,
 static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, ValaField* f)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_FIELD (f));
 	vala_field_process_attributes (f);
 }
@@ -173,7 +176,7 @@ static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig)
 {
 	ValaAttributeProcessor * self;
-	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	self = ((ValaAttributeProcessor*) base);
 	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	vala_signal_process_attributes (sig);
 }
@@ -188,7 +191,6 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_attribute_processor_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_attribute_processor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_attribute_processor_real_visit_enum;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_flags = vala_attribute_processor_real_visit_flags;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_attribute_processor_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_attribute_processor_real_visit_creation_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_property = vala_attribute_processor_real_visit_property;
@@ -203,7 +205,7 @@ static void vala_attribute_processor_init (ValaAttributeProcessor * self)
 }
 
 
-GType vala_attribute_processor_get_type ()
+GType vala_attribute_processor_get_type (void)
 {
 	static GType vala_attribute_processor_type_id = 0;
 	if (G_UNLIKELY (vala_attribute_processor_type_id == 0)) {
