@@ -22,7 +22,6 @@
 
 #ifndef __VALACASTEXPRESSION_H__
 #define __VALACASTEXPRESSION_H__
-typedef struct _ValaCastExpressionPrivate ValaCastExpressionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_CAST_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CAST_EXPRESSION))
 #define VALA_CAST_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionClass))
 
+typedef struct _ValaCastExpressionPrivate ValaCastExpressionPrivate;
 
 /**
  * Represents a type cast in the source code.
@@ -56,7 +56,7 @@ ValaExpression* vala_cast_expression_get_inner (ValaCastExpression* self);
 void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* value);
 ValaTypeReference* vala_cast_expression_get_type_reference (ValaCastExpression* self);
 void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaTypeReference* value);
-GType vala_cast_expression_get_type ();
+GType vala_cast_expression_get_type (void);
 
 G_END_DECLS
 
