@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacatchclause.h"
 #include <vala/valatypereference.h>
@@ -61,19 +59,15 @@ static void vala_catch_clause_dispose (GObject * obj);
  */
 ValaCatchClause* vala_catch_clause_new (ValaTypeReference* type_reference, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCatchClause * self;
 	g_return_val_if_fail (type_reference == NULL || VALA_IS_TYPE_REFERENCE (type_reference), NULL);
 	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 4);
-	__params_it = __params;
-	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type_reference), __params_it++);
-	(__params_it->name = "variable-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, variable_name), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_BLOCK), g_value_set_object (&__params_it->value, body), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	self = g_object_newv (VALA_TYPE_CATCH_CLAUSE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CATCH_CLAUSE, 0, NULL);
+	vala_catch_clause_set_type_reference (self, type_reference);
+	vala_catch_clause_set_variable_name (self, variable_name);
+	vala_catch_clause_set_body (self, body);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -81,7 +75,7 @@ ValaCatchClause* vala_catch_clause_new (ValaTypeReference* type_reference, const
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaCatchClause * self;
-	self = VALA_CATCH_CLAUSE (base);
+	self = ((ValaCatchClause*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_catch_clause (visitor, self);
 }
@@ -90,7 +84,7 @@ static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaCatchClause * self;
-	self = VALA_CATCH_CLAUSE (base);
+	self = ((ValaCatchClause*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_catch_clause_get_type_reference (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_catch_clause_get_body (self)), visitor);
@@ -249,7 +243,7 @@ static void vala_catch_clause_dispose (GObject * obj)
 }
 
 
-GType vala_catch_clause_get_type ()
+GType vala_catch_clause_get_type (void)
 {
 	static GType vala_catch_clause_type_id = 0;
 	if (G_UNLIKELY (vala_catch_clause_type_id == 0)) {
