@@ -22,12 +22,12 @@
 
 #ifndef __VALACLASS_H__
 #define __VALACLASS_H__
-typedef struct _ValaClassPrivate ValaClassPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
+#include <gee/collection.h>
 #include <vala/valadatatype.h>
 #include <vala/valacodenode.h>
 
@@ -41,6 +41,7 @@ G_BEGIN_DECLS
 #define VALA_IS_CLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CLASS))
 #define VALA_CLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CLASS, ValaClassClass))
 
+typedef struct _ValaClassPrivate ValaClassPrivate;
 
 /**
  * Represents a class declaration in the source code.
@@ -53,20 +54,22 @@ struct _ValaClassClass {
 	ValaDataTypeClass parent;
 };
 
-ValaClass* vala_class_new (const char* _name, ValaSourceReference* source);
+ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference);
 void vala_class_add_base_type (ValaClass* self, ValaTypeReference* type);
-GList* vala_class_get_base_types (ValaClass* self);
+GeeCollection* vala_class_get_base_types (ValaClass* self);
 void vala_class_add_type_parameter (ValaClass* self, ValaTypeParameter* p);
-GList* vala_class_get_type_parameters (ValaClass* self);
+GeeCollection* vala_class_get_type_parameters (ValaClass* self);
 void vala_class_add_constant (ValaClass* self, ValaConstant* c);
 void vala_class_add_field (ValaClass* self, ValaField* f);
-GList* vala_class_get_fields (ValaClass* self);
+GeeCollection* vala_class_get_fields (ValaClass* self);
 void vala_class_add_method (ValaClass* self, ValaMethod* m);
-GList* vala_class_get_methods (ValaClass* self);
+GeeCollection* vala_class_get_methods (ValaClass* self);
 void vala_class_add_property (ValaClass* self, ValaProperty* prop, gboolean no_field);
-GList* vala_class_get_properties (ValaClass* self);
+GeeCollection* vala_class_get_properties (ValaClass* self);
 void vala_class_add_signal (ValaClass* self, ValaSignal* sig);
-GList* vala_class_get_signals (ValaClass* self);
+GeeCollection* vala_class_get_signals (ValaClass* self);
+void vala_class_add_class (ValaClass* self, ValaClass* cl);
+void vala_class_add_struct (ValaClass* self, ValaStruct* st);
 void vala_class_set_cname (ValaClass* self, const char* cname);
 void vala_class_process_attributes (ValaClass* self);
 ValaClass* vala_class_get_base_class (ValaClass* self);
@@ -82,7 +85,7 @@ ValaConstructor* vala_class_get_constructor (ValaClass* self);
 void vala_class_set_constructor (ValaClass* self, ValaConstructor* value);
 ValaDestructor* vala_class_get_destructor (ValaClass* self);
 void vala_class_set_destructor (ValaClass* self, ValaDestructor* value);
-GType vala_class_get_type ();
+GType vala_class_get_type (void);
 
 G_END_DECLS
 
