@@ -25,6 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <stdlib.h>
 #include <string.h>
 #include <vala/valacodenode.h>
@@ -52,16 +53,37 @@ struct _ValaCodeContextClass {
 	GObjectClass parent;
 };
 
-ValaSymbol* vala_code_context_get_root (ValaCodeContext* self);
-GList* vala_code_context_get_source_files (ValaCodeContext* self);
+GeeCollection* vala_code_context_get_source_files (ValaCodeContext* self);
 void vala_code_context_add_source_file (ValaCodeContext* self, ValaSourceFile* file);
+GeeCollection* vala_code_context_get_packages (ValaCodeContext* self);
+gboolean vala_code_context_has_package (ValaCodeContext* self, const char* pkg);
+void vala_code_context_add_package (ValaCodeContext* self, const char* pkg);
 void vala_code_context_accept (ValaCodeContext* self, ValaCodeVisitor* visitor);
 void vala_code_context_find_header_cycles (ValaCodeContext* self);
 char* vala_code_context_get_library (ValaCodeContext* self);
 void vala_code_context_set_library (ValaCodeContext* self, const char* value);
+gboolean vala_code_context_get_memory_management (ValaCodeContext* self);
+void vala_code_context_set_memory_management (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_assert (ValaCodeContext* self);
+void vala_code_context_set_assert (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_checking (ValaCodeContext* self);
+void vala_code_context_set_checking (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_ccode_only (ValaCodeContext* self);
+void vala_code_context_set_ccode_only (ValaCodeContext* self, gboolean value);
+gboolean vala_code_context_get_compile_only (ValaCodeContext* self);
+void vala_code_context_set_compile_only (ValaCodeContext* self, gboolean value);
+char* vala_code_context_get_output (ValaCodeContext* self);
+void vala_code_context_set_output (ValaCodeContext* self, const char* value);
+gboolean vala_code_context_get_debug (ValaCodeContext* self);
+void vala_code_context_set_debug (ValaCodeContext* self, gboolean value);
+gint vala_code_context_get_optlevel (ValaCodeContext* self);
+void vala_code_context_set_optlevel (ValaCodeContext* self, gint value);
+gboolean vala_code_context_get_thread (ValaCodeContext* self);
+void vala_code_context_set_thread (ValaCodeContext* self, gboolean value);
 ValaMethod* vala_code_context_get_module_init_method (ValaCodeContext* self);
 void vala_code_context_set_module_init_method (ValaCodeContext* self, ValaMethod* value);
-GType vala_code_context_get_type ();
+ValaNamespace* vala_code_context_get_root (ValaCodeContext* self);
+GType vala_code_context_get_type (void);
 
 G_END_DECLS
 
