@@ -20,8 +20,6 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacodevisitor.h"
 #include <vala/valasourcefile.h>
@@ -31,8 +29,6 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
-#include <vala/valaflags.h>
-#include <vala/valaflagsvalue.h>
 #include <vala/valacallback.h>
 #include <vala/valamember.h>
 #include <vala/valaconstant.h>
@@ -110,8 +106,6 @@ static void vala_code_visitor_real_visit_struct (ValaCodeVisitor* self, ValaStru
 static void vala_code_visitor_real_visit_interface (ValaCodeVisitor* self, ValaInterface* iface);
 static void vala_code_visitor_real_visit_enum (ValaCodeVisitor* self, ValaEnum* en);
 static void vala_code_visitor_real_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* ev);
-static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl);
-static void vala_code_visitor_real_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv);
 static void vala_code_visitor_real_visit_callback (ValaCodeVisitor* self, ValaCallback* cb);
 static void vala_code_visitor_real_visit_member (ValaCodeVisitor* self, ValaMember* m);
 static void vala_code_visitor_real_visit_constant (ValaCodeVisitor* self, ValaConstant* c);
@@ -316,42 +310,6 @@ void vala_code_visitor_visit_enum_value (ValaCodeVisitor* self, ValaEnumValue* e
 }
 
 
-/**
- * Visit operation called for flags.
- *
- * @param fl a flags
- */
-static void vala_code_visitor_real_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_FLAGS (fl));
-}
-
-
-void vala_code_visitor_visit_flags (ValaCodeVisitor* self, ValaFlags* fl)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_flags (self, fl);
-}
-
-
-/**
- * Visit operation called for flags values.
- *
- * @param fv an flags value
- */
-static void vala_code_visitor_real_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv)
-{
-	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
-	g_return_if_fail (VALA_IS_FLAGS_VALUE (fv));
-}
-
-
-void vala_code_visitor_visit_flags_value (ValaCodeVisitor* self, ValaFlagsValue* fv)
-{
-	VALA_CODE_VISITOR_GET_CLASS (self)->visit_flags_value (self, fv);
-}
-
-
 /**
  * Visit operation called for callbacks.
  *
@@ -1713,8 +1671,6 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass)
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_code_visitor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_code_visitor_real_visit_enum;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_code_visitor_real_visit_enum_value;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_flags = vala_code_visitor_real_visit_flags;
-	VALA_CODE_VISITOR_CLASS (klass)->visit_flags_value = vala_code_visitor_real_visit_flags_value;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_callback = vala_code_visitor_real_visit_callback;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_member = vala_code_visitor_real_visit_member;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_constant = vala_code_visitor_real_visit_constant;
@@ -1798,7 +1754,7 @@ static void vala_code_visitor_init (ValaCodeVisitor * self)
 }
 
 
-GType vala_code_visitor_get_type ()
+GType vala_code_visitor_get_type (void)
 {
 	static GType vala_code_visitor_type_id = 0;
 	if (G_UNLIKELY (vala_code_visitor_type_id == 0)) {
