@@ -22,7 +22,6 @@
 
 #ifndef __VALACONDITIONALEXPRESSION_H__
 #define __VALACONDITIONALEXPRESSION_H__
-typedef struct _ValaConditionalExpressionPrivate ValaConditionalExpressionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_CONDITIONAL_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CONDITIONAL_EXPRESSION))
 #define VALA_CONDITIONAL_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CONDITIONAL_EXPRESSION, ValaConditionalExpressionClass))
 
+typedef struct _ValaConditionalExpressionPrivate ValaConditionalExpressionPrivate;
 
 /**
  * Represents a conditional expression in the source code.
@@ -58,7 +58,7 @@ ValaExpression* vala_conditional_expression_get_true_expression (ValaConditional
 void vala_conditional_expression_set_true_expression (ValaConditionalExpression* self, ValaExpression* value);
 ValaExpression* vala_conditional_expression_get_false_expression (ValaConditionalExpression* self);
 void vala_conditional_expression_set_false_expression (ValaConditionalExpression* self, ValaExpression* value);
-GType vala_conditional_expression_get_type ();
+GType vala_conditional_expression_get_type (void);
 
 G_END_DECLS
 
