@@ -19,16 +19,14 @@
  * Author:
  * 	Raffaele Sandrini <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valacreationmethod.h"
 #include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valacreationmethod.h>
 #include <vala/valaformalparameter.h>
 #include <vala/valablock.h>
-#include <vala/valasymbol.h>
 #include <vala/valadatatype.h>
 
 struct _ValaCreationMethodPrivate {
@@ -55,15 +53,11 @@ static void vala_creation_method_dispose (GObject * obj);
  */
 ValaCreationMethod* vala_creation_method_new (const char* name, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaCreationMethod * self;
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	self = g_object_newv (VALA_TYPE_CREATION_METHOD, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_CREATION_METHOD, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -71,7 +65,7 @@ ValaCreationMethod* vala_creation_method_new (const char* name, ValaSourceRefere
 static void vala_creation_method_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaCreationMethod * self;
-	self = VALA_CREATION_METHOD (base);
+	self = ((ValaCreationMethod*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_creation_method (visitor, self);
 }
@@ -80,24 +74,26 @@ static void vala_creation_method_real_accept (ValaCodeNode* base, ValaCodeVisito
 static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaCreationMethod * self;
-	self = VALA_CREATION_METHOD (base);
+	self = ((ValaCreationMethod*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp0;
-		GList* param_it;
-		__temp0 = NULL;
-		__temp0 = vala_invokable_get_parameters (VALA_INVOKABLE (self));
-		for (param_it = __temp0; param_it != NULL; param_it = param_it->next) {
+		GeeCollection* param_collection;
+		GeeIterator* param_it;
+		param_collection = vala_invokable_get_parameters (VALA_INVOKABLE (self));
+		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
+		while (gee_iterator_next (param_it)) {
 			ValaFormalParameter* param;
-			param = param_it->data;
+			param = gee_iterator_get (param_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(__temp0 == NULL ? NULL : (__temp0 = (g_list_free (__temp0), NULL)));
+		(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
+		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
-	if (vala_method_get_body (VALA_METHOD (self)) != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (VALA_METHOD (self))), visitor);
+	if (vala_method_get_body (((ValaMethod*) self)) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (((ValaMethod*) self))), visitor);
 	}
 }
 
@@ -105,28 +101,28 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 static char* vala_creation_method_real_get_default_cname (ValaMethod* base)
 {
 	ValaCreationMethod * self;
-	ValaCodeNode* __temp1;
-	ValaCodeNode* parent;
-	self = VALA_CREATION_METHOD (base);
-	__temp1 = NULL;
-	parent = (__temp1 = vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self)))), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
+	ValaSymbol* __temp0;
+	ValaSymbol* parent;
+	self = ((ValaCreationMethod*) base);
+	__temp0 = NULL;
+	parent = (__temp0 = vala_symbol_get_parent_symbol (((ValaSymbol*) self)), (__temp0 == NULL ? NULL : g_object_ref (__temp0)));
 	g_assert (VALA_IS_DATA_TYPE (parent));
-	if (vala_method_get_name (VALA_METHOD (self)) == NULL) {
+	if (vala_symbol_get_name (((ValaSymbol*) self)) == NULL) {
+		char* __temp1;
 		char* __temp2;
 		char* __temp3;
-		char* __temp4;
+		__temp1 = NULL;
 		__temp2 = NULL;
 		__temp3 = NULL;
-		__temp4 = NULL;
-		return (__temp4 = (__temp3 = g_strdup_printf ("%snew", (__temp2 = vala_data_type_get_lower_case_cprefix ((VALA_DATA_TYPE (parent))))), (__temp2 = (g_free (__temp2), NULL)), __temp3), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp4);
+		return (__temp3 = (__temp2 = g_strdup_printf ("%snew", (__temp1 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent)))))), (__temp1 = (g_free (__temp1), NULL)), __temp2), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp3);
 	} else {
+		char* __temp4;
 		char* __temp5;
 		char* __temp6;
-		char* __temp7;
+		__temp4 = NULL;
 		__temp5 = NULL;
 		__temp6 = NULL;
-		__temp7 = NULL;
-		return (__temp7 = (__temp6 = g_strdup_printf ("%snew_%s", (__temp5 = vala_data_type_get_lower_case_cprefix ((VALA_DATA_TYPE (parent)))), vala_method_get_name (VALA_METHOD (self))), (__temp5 = (g_free (__temp5), NULL)), __temp6), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp7);
+		return (__temp6 = (__temp5 = g_strdup_printf ("%snew_%s", (__temp4 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL ((VALA_DATA_TYPE (parent))))), vala_symbol_get_name (((ValaSymbol*) self))), (__temp4 = (g_free (__temp4), NULL)), __temp5), (parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL))), __temp6);
 	}
 	(parent == NULL ? NULL : (parent = (g_object_unref (parent), NULL)));
 }
@@ -202,7 +198,7 @@ static void vala_creation_method_dispose (GObject * obj)
 }
 
 
-GType vala_creation_method_get_type ()
+GType vala_creation_method_get_type (void)
 {
 	static GType vala_creation_method_type_id = 0;
 	if (G_UNLIKELY (vala_creation_method_type_id == 0)) {
