@@ -20,29 +20,28 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valadatatype.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/map.h>
+#include <gee/readonlycollection.h>
+#include <gee/hashmap.h>
 #include <vala/valapointer.h>
 #include <vala/valadatatype.h>
-#include <vala/valanamespace.h>
 #include <vala/valasourcereference.h>
-#include <vala/valasymbol.h>
+#include <vala/valasourcefile.h>
+#include <vala/valascope.h>
 #include <vala/valaarray.h>
-#include <vala/valafield.h>
-#include <vala/valamethod.h>
 
 struct _ValaDataTypePrivate {
-	char* _name;
-	GList* cheader_filenames;
+	GeeList* cheader_filenames;
 	ValaPointer* pointer_type;
-	GHashTable* array_types;
+	GeeMap* array_types;
 };
 #define VALA_DATA_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DATA_TYPE, ValaDataTypePrivate))
 enum  {
-	VALA_DATA_TYPE_DUMMY_PROPERTY,
-	VALA_DATA_TYPE_NAME
+	VALA_DATA_TYPE_DUMMY_PROPERTY
 };
 static gboolean vala_data_type_real_is_reference_type (ValaDataType* self);
 static char* vala_data_type_real_get_dup_function (ValaDataType* self);
@@ -55,10 +54,8 @@ static char* vala_data_type_real_get_marshaller_type_name (ValaDataType* self);
 static char* vala_data_type_real_get_get_value_function (ValaDataType* self);
 static char* vala_data_type_real_get_set_value_function (ValaDataType* self);
 static char* vala_data_type_real_get_upper_case_cname (ValaDataType* self, const char* infix);
-static char* vala_data_type_real_get_lower_case_cname (ValaDataType* self, const char* infix);
-static char* vala_data_type_real_get_lower_case_cprefix (ValaDataType* self);
 static char* vala_data_type_real_get_default_value (ValaDataType* self);
-static GList* vala_data_type_real_get_cheader_filenames (ValaDataType* self);
+static GeeCollection* vala_data_type_real_get_cheader_filenames (ValaSymbol* base);
 static gboolean vala_data_type_real_is_subtype_of (ValaDataType* self, ValaDataType* t);
 static gint vala_data_type_real_get_type_parameter_index (ValaDataType* self, const char* name);
 static gpointer vala_data_type_parent_class = NULL;
@@ -288,47 +285,6 @@ char* vala_data_type_get_upper_case_cname (ValaDataType* self, const char* infix
 }
 
 
-/**
- * Returns the C name of this data type in lower case. Words are
- * separated by underscores. The lower case C name of the namespace is
- * prefix of the result.
- *
- * @param infix a string to be placed between namespace and data type
- *              name or null
- * @return      the lower case name to be used in C code
- */
-static char* vala_data_type_real_get_lower_case_cname (ValaDataType* self, const char* infix)
-{
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	return NULL;
-}
-
-
-char* vala_data_type_get_lower_case_cname (ValaDataType* self, const char* infix)
-{
-	return VALA_DATA_TYPE_GET_CLASS (self)->get_lower_case_cname (self, infix);
-}
-
-
-/**
- * Returns the string to be prefixed to members of this data type in
- * lower case when used in C code.
- *
- * @return      the lower case prefix to be used in C code
- */
-static char* vala_data_type_real_get_lower_case_cprefix (ValaDataType* self)
-{
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	return NULL;
-}
-
-
-char* vala_data_type_get_lower_case_cprefix (ValaDataType* self)
-{
-	return VALA_DATA_TYPE_GET_CLASS (self)->get_lower_case_cprefix (self);
-}
-
-
 /**
  * Returns the default value for the given type. Returning null means
  * there is no default value (i.e. not that the default name is NULL).
@@ -348,39 +304,37 @@ char* vala_data_type_get_default_value (ValaDataType* self)
 }
 
 
-/**
- * Returns a list of C header filenames users of this data type must
- * include.
- *
- * @return list of C header filenames for this data type
- */
-static GList* vala_data_type_real_get_cheader_filenames (ValaDataType* self)
+static GeeCollection* vala_data_type_real_get_cheader_filenames (ValaSymbol* base)
 {
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	if (self->priv->cheader_filenames == NULL) {
+	ValaDataType * self;
+	self = ((ValaDataType*) base);
+	if (gee_collection_get_size (((GeeCollection*) self->priv->cheader_filenames)) == 0) {
 		{
-			GList* __temp14;
-			GList* filename_it;
-			__temp14 = NULL;
-			__temp14 = vala_namespace_get_cheader_filenames (self->namespace);
-			for (filename_it = __temp14; filename_it != NULL; filename_it = filename_it->next) {
+			GeeCollection* filename_collection;
+			GeeIterator* filename_it;
+			filename_collection = vala_symbol_get_cheader_filenames (vala_symbol_get_parent_symbol (((ValaSymbol*) self)));
+			filename_it = gee_iterable_iterator (GEE_ITERABLE (filename_collection));
+			while (gee_iterator_next (filename_it)) {
 				char* filename;
-				filename = filename_it->data;
+				filename = gee_iterator_get (filename_it);
 				{
 					/* default to header filenames of the namespace */
 					vala_data_type_add_cheader_filename (self, filename);
+					(filename = (g_free (filename), NULL));
 				}
 			}
-			(__temp14 == NULL ? NULL : (__temp14 = (g_list_free (__temp14), NULL)));
+			(filename_collection == NULL ? NULL : (filename_collection = (g_object_unref (filename_collection), NULL)));
+			(filename_it == NULL ? NULL : (filename_it = (g_object_unref (filename_it), NULL)));
+		}
+		if (gee_collection_get_size (((GeeCollection*) self->priv->cheader_filenames)) == 0 && vala_code_node_get_source_reference (((ValaCodeNode*) self)) != NULL && !vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))) {
+			char* __temp12;
+			/* don't add default include directives for VAPI files*/
+			__temp12 = NULL;
+			gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), (__temp12 = vala_source_file_get_cinclude_filename (vala_source_reference_get_file (vala_code_node_get_source_reference (((ValaCodeNode*) self))))));
+			(__temp12 = (g_free (__temp12), NULL));
 		}
 	}
-	return g_list_copy (self->priv->cheader_filenames);
-}
-
-
-GList* vala_data_type_get_cheader_filenames (ValaDataType* self)
-{
-	return VALA_DATA_TYPE_GET_CLASS (self)->get_cheader_filenames (self);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_strdup, g_free, GEE_COLLECTION (self->priv->cheader_filenames)));
 }
 
 
@@ -394,7 +348,7 @@ void vala_data_type_add_cheader_filename (ValaDataType* self, const char* filena
 {
 	g_return_if_fail (VALA_IS_DATA_TYPE (self));
 	g_return_if_fail (filename != NULL);
-	self->priv->cheader_filenames = g_list_append (self->priv->cheader_filenames, g_strdup (filename));
+	gee_collection_add (GEE_COLLECTION (self->priv->cheader_filenames), filename);
 }
 
 
@@ -405,23 +359,19 @@ void vala_data_type_add_cheader_filename (ValaDataType* self, const char* filena
  */
 ValaPointer* vala_data_type_get_pointer (ValaDataType* self)
 {
-	ValaPointer* __temp18;
+	ValaPointer* __temp15;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
 	if (self->priv->pointer_type == NULL) {
-		ValaPointer* __temp16;
-		ValaSymbol* __temp17;
-		__temp16 = NULL;
-		self->priv->pointer_type = (__temp16 = vala_pointer_new (self, vala_code_node_get_source_reference (VALA_CODE_NODE (self))), (self->priv->pointer_type == NULL ? NULL : (self->priv->pointer_type = (g_object_unref (self->priv->pointer_type), NULL))), __temp16);
+		ValaPointer* __temp14;
+		__temp14 = NULL;
+		self->priv->pointer_type = (__temp14 = vala_pointer_new (self, vala_code_node_get_source_reference (((ValaCodeNode*) self))), (self->priv->pointer_type == NULL ? NULL : (self->priv->pointer_type = (g_object_unref (self->priv->pointer_type), NULL))), __temp14);
 		/* create a new Symbol */
-		__temp17 = NULL;
-		(vala_code_node_set_symbol (VALA_CODE_NODE (self->priv->pointer_type), (__temp17 = vala_symbol_new (VALA_CODE_NODE (self->priv->pointer_type)))), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->pointer_type)));
-		(__temp17 == NULL ? NULL : (__temp17 = (g_object_unref (__temp17), NULL)));
-		vala_symbol_add (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))), vala_data_type_get_name (VALA_DATA_TYPE (self->priv->pointer_type)), vala_code_node_get_symbol (VALA_CODE_NODE (self->priv->pointer_type)));
+		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (((ValaSymbol*) self))), vala_symbol_get_name (((ValaSymbol*) self->priv->pointer_type)), VALA_SYMBOL (self->priv->pointer_type));
 		/* link the namespace */
-		VALA_DATA_TYPE (self->priv->pointer_type)->namespace = self->namespace;
+		vala_symbol_set_owner (VALA_SYMBOL (self->priv->pointer_type), vala_symbol_get_scope (vala_symbol_get_parent_symbol (((ValaSymbol*) self))));
 	}
-	__temp18 = NULL;
-	return (__temp18 = self->priv->pointer_type, (__temp18 == NULL ? NULL : g_object_ref (__temp18)));
+	__temp15 = NULL;
+	return (__temp15 = self->priv->pointer_type, (__temp15 == NULL ? NULL : g_object_ref (__temp15)));
 }
 
 
@@ -433,52 +383,55 @@ ValaPointer* vala_data_type_get_pointer (ValaDataType* self)
  */
 ValaArray* vala_data_type_get_array (ValaDataType* self, gint rank)
 {
-	ValaArray* __temp21;
-	char* __temp20;
-	ValaArray* __temp22;
 	ValaArray* array_type;
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	__temp21 = NULL;
-	__temp20 = NULL;
-	__temp22 = NULL;
-	array_type = (__temp22 = (__temp21 = VALA_ARRAY (g_hash_table_lookup (self->priv->array_types, (__temp20 = g_strdup_printf ("%i", rank)))), (__temp21 == NULL ? NULL : g_object_ref (__temp21))), (__temp20 = (g_free (__temp20), NULL)), __temp22);
+	array_type = NULL;
+	if (self->priv->array_types != NULL) {
+		ValaArray* __temp17;
+		__temp17 = NULL;
+		array_type = (__temp17 = gee_map_get (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank)), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp17);
+	}
 	if (array_type == NULL) {
 		ValaArray* new_array_type;
-		ValaSymbol* __temp23;
-		ValaArrayLengthField* __temp25;
-		ValaArrayLengthField* __temp24;
-		ValaArrayResizeMethod* __temp27;
-		ValaArrayResizeMethod* __temp26;
-		ValaArray* __temp28;
-		ValaArray* __temp30;
-		ValaArray* __temp29;
-		new_array_type = vala_array_new (self, rank, vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-		/* create a new Symbol */
-		__temp23 = NULL;
-		(vala_code_node_set_symbol (VALA_CODE_NODE (new_array_type), (__temp23 = vala_symbol_new (VALA_CODE_NODE (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)));
-		(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
-		vala_symbol_add (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self))), vala_data_type_get_name (VALA_DATA_TYPE (new_array_type)), vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)));
+		ValaArrayLengthField* __temp20;
+		ValaArrayLengthField* __temp19;
+		ValaArrayResizeMethod* __temp22;
+		ValaArrayResizeMethod* __temp21;
+		ValaArrayMoveMethod* __temp24;
+		ValaArrayMoveMethod* __temp23;
+		ValaArray* __temp26;
+		ValaArray* __temp25;
+		if (self->priv->array_types == NULL) {
+			GeeMap* __temp18;
+			__temp18 = NULL;
+			self->priv->array_types = (__temp18 = GEE_MAP (gee_hash_map_new (NULL, NULL, g_object_ref, g_object_unref, g_direct_hash, g_direct_equal, g_direct_equal)), (self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL))), __temp18);
+		}
+		new_array_type = vala_array_new (self, rank, vala_code_node_get_source_reference (((ValaCodeNode*) self)));
+		vala_scope_add (vala_symbol_get_scope (vala_symbol_get_parent_symbol (((ValaSymbol*) self))), vala_symbol_get_name (((ValaSymbol*) new_array_type)), VALA_SYMBOL (new_array_type));
 		/* add internal length field */
-		__temp25 = NULL;
-		__temp24 = NULL;
-		vala_symbol_add (vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)), vala_field_get_name (VALA_FIELD ((__temp24 = vala_array_get_length_field (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE ((__temp25 = vala_array_get_length_field (new_array_type)))));
-		(__temp25 == NULL ? NULL : (__temp25 = (g_object_unref (__temp25), NULL)));
-		(__temp24 == NULL ? NULL : (__temp24 = (g_object_unref (__temp24), NULL)));
+		__temp20 = NULL;
+		__temp19 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp19 = vala_array_get_length_field (new_array_type)))), VALA_SYMBOL ((__temp20 = vala_array_get_length_field (new_array_type))));
+		(__temp20 == NULL ? NULL : (__temp20 = (g_object_unref (__temp20), NULL)));
+		(__temp19 == NULL ? NULL : (__temp19 = (g_object_unref (__temp19), NULL)));
 		/* add internal resize method */
-		__temp27 = NULL;
-		__temp26 = NULL;
-		vala_symbol_add (vala_code_node_get_symbol (VALA_CODE_NODE (new_array_type)), vala_method_get_name (VALA_METHOD ((__temp26 = vala_array_get_resize_method (new_array_type)))), vala_code_node_get_symbol (VALA_CODE_NODE ((__temp27 = vala_array_get_resize_method (new_array_type)))));
-		(__temp27 == NULL ? NULL : (__temp27 = (g_object_unref (__temp27), NULL)));
-		(__temp26 == NULL ? NULL : (__temp26 = (g_object_unref (__temp26), NULL)));
+		__temp22 = NULL;
+		__temp21 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp21 = vala_array_get_resize_method (new_array_type)))), VALA_SYMBOL ((__temp22 = vala_array_get_resize_method (new_array_type))));
+		(__temp22 == NULL ? NULL : (__temp22 = (g_object_unref (__temp22), NULL)));
+		(__temp21 == NULL ? NULL : (__temp21 = (g_object_unref (__temp21), NULL)));
+		/* add internal move method */
+		__temp24 = NULL;
+		__temp23 = NULL;
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) new_array_type)), vala_symbol_get_name (((ValaSymbol*) (__temp23 = vala_array_get_move_method (new_array_type)))), VALA_SYMBOL ((__temp24 = vala_array_get_move_method (new_array_type))));
+		(__temp24 == NULL ? NULL : (__temp24 = (g_object_unref (__temp24), NULL)));
+		(__temp23 == NULL ? NULL : (__temp23 = (g_object_unref (__temp23), NULL)));
 		/* link the array type to the same source as the container type */
-		(vala_code_node_set_source_reference (VALA_CODE_NODE (new_array_type), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), vala_code_node_get_source_reference (VALA_CODE_NODE (new_array_type)));
-		/* link the namespace */
-		VALA_DATA_TYPE (new_array_type)->namespace = self->namespace;
-		__temp28 = NULL;
-		g_hash_table_insert (self->priv->array_types, g_strdup_printf ("%i", rank), (__temp28 = new_array_type, (__temp28 == NULL ? NULL : g_object_ref (__temp28))));
-		__temp30 = NULL;
-		__temp29 = NULL;
-		array_type = (__temp30 = (__temp29 = new_array_type, (__temp29 == NULL ? NULL : g_object_ref (__temp29))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp30);
+		vala_code_node_set_source_reference (VALA_CODE_NODE (new_array_type), vala_code_node_get_source_reference (((ValaCodeNode*) self)));
+		gee_map_set (((GeeMap*) self->priv->array_types), GINT_TO_POINTER (rank), new_array_type);
+		__temp26 = NULL;
+		__temp25 = NULL;
+		array_type = (__temp26 = (__temp25 = new_array_type, (__temp25 == NULL ? NULL : g_object_ref (__temp25))), (array_type == NULL ? NULL : (array_type = (g_object_unref (array_type), NULL))), __temp26);
 		(new_array_type == NULL ? NULL : (new_array_type = (g_object_unref (new_array_type), NULL)));
 	}
 	return array_type;
@@ -524,54 +477,10 @@ gint vala_data_type_get_type_parameter_index (ValaDataType* self, const char* na
 }
 
 
-char* vala_data_type_get_name (ValaDataType* self)
-{
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_data_type_set_name (ValaDataType* self, const char* value)
-{
-	char* __temp36;
-	const char* __temp35;
-	g_return_if_fail (VALA_IS_DATA_TYPE (self));
-	__temp36 = NULL;
-	__temp35 = NULL;
-	self->priv->_name = (__temp36 = (__temp35 = value, (__temp35 == NULL ? NULL : g_strdup (__temp35))), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp36);
-}
-
-
-static void vala_data_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
-	ValaDataType * self;
-	self = VALA_DATA_TYPE (object);
-	switch (property_id) {
-		case VALA_DATA_TYPE_NAME:
-		g_value_set_string (value, vala_data_type_get_name (self));
-		break;
-	}
-}
-
-
-static void vala_data_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
-	ValaDataType * self;
-	self = VALA_DATA_TYPE (object);
-	switch (property_id) {
-		case VALA_DATA_TYPE_NAME:
-		vala_data_type_set_name (self, g_value_get_string (value));
-		break;
-	}
-}
-
-
 static void vala_data_type_class_init (ValaDataTypeClass * klass)
 {
 	vala_data_type_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaDataTypePrivate));
-	G_OBJECT_CLASS (klass)->get_property = vala_data_type_get_property;
-	G_OBJECT_CLASS (klass)->set_property = vala_data_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_data_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_type = vala_data_type_real_is_reference_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_dup_function = vala_data_type_real_get_dup_function;
@@ -584,20 +493,17 @@ static void vala_data_type_class_init (ValaDataTypeClass * klass)
 	VALA_DATA_TYPE_CLASS (klass)->get_get_value_function = vala_data_type_real_get_get_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_set_value_function = vala_data_type_real_get_set_value_function;
 	VALA_DATA_TYPE_CLASS (klass)->get_upper_case_cname = vala_data_type_real_get_upper_case_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_data_type_real_get_lower_case_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cprefix = vala_data_type_real_get_lower_case_cprefix;
 	VALA_DATA_TYPE_CLASS (klass)->get_default_value = vala_data_type_real_get_default_value;
-	VALA_DATA_TYPE_CLASS (klass)->get_cheader_filenames = vala_data_type_real_get_cheader_filenames;
+	VALA_SYMBOL_CLASS (klass)->get_cheader_filenames = vala_data_type_real_get_cheader_filenames;
 	VALA_DATA_TYPE_CLASS (klass)->is_subtype_of = vala_data_type_real_is_subtype_of;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_parameter_index = vala_data_type_real_get_type_parameter_index;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DATA_TYPE_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
 static void vala_data_type_init (ValaDataType * self)
 {
 	self->priv = VALA_DATA_TYPE_GET_PRIVATE (self);
-	self->priv->array_types = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
+	self->priv->cheader_filenames = GEE_LIST (gee_array_list_new (g_strdup, g_free, g_direct_equal));
 }
 
 
@@ -607,22 +513,21 @@ static void vala_data_type_dispose (GObject * obj)
 	ValaDataTypeClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_DATA_TYPE (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_list_foreach (self->priv->cheader_filenames, (GFunc) g_free, NULL), g_list_free (self->priv->cheader_filenames), NULL)));
+	(self->priv->cheader_filenames == NULL ? NULL : (self->priv->cheader_filenames = (g_object_unref (self->priv->cheader_filenames), NULL)));
 	(self->priv->pointer_type == NULL ? NULL : (self->priv->pointer_type = (g_object_unref (self->priv->pointer_type), NULL)));
-	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_hash_table_unref (self->priv->array_types), NULL)));
+	(self->priv->array_types == NULL ? NULL : (self->priv->array_types = (g_object_unref (self->priv->array_types), NULL)));
 	klass = VALA_DATA_TYPE_CLASS (g_type_class_peek (VALA_TYPE_DATA_TYPE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_data_type_get_type ()
+GType vala_data_type_get_type (void)
 {
 	static GType vala_data_type_type_id = 0;
 	if (G_UNLIKELY (vala_data_type_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaDataTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_data_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDataType), 0, (GInstanceInitFunc) vala_data_type_init };
-		vala_data_type_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDataType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
+		vala_data_type_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDataType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_data_type_type_id;
 }
