@@ -26,6 +26,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -53,11 +54,11 @@ struct _ValaElementAccessClass {
 };
 
 void vala_element_access_append_index (ValaElementAccess* self, ValaExpression* index);
-GList* vala_element_access_get_indices (ValaElementAccess* self);
-ValaElementAccess* vala_element_access_new (ValaExpression* _container, ValaSourceReference* source);
+GeeList* vala_element_access_get_indices (ValaElementAccess* self);
+ValaElementAccess* vala_element_access_new (ValaExpression* container, ValaSourceReference* source_reference);
 ValaExpression* vala_element_access_get_container (ValaElementAccess* self);
 void vala_element_access_set_container (ValaElementAccess* self, ValaExpression* value);
-GType vala_element_access_get_type ();
+GType vala_element_access_get_type (void);
 
 G_END_DECLS
 
