@@ -19,22 +19,28 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaenum.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
 #include <vala/valaenumvalue.h>
 #include <vala/valaenum.h>
+#include <vala/valascope.h>
 #include <vala/valamethod.h>
+#include <vala/valacreationmethod.h>
+#include <vala/valareport.h>
+#include <vala/valaformalparameter.h>
+#include <vala/valatypereference.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valanamespace.h>
 #include <vala/valaattribute.h>
 
 struct _ValaEnumPrivate {
 	gboolean _error_domain;
-	GList* values;
-	GList* methods;
+	GeeList* values;
+	GeeList* methods;
 	char* cname;
 	char* cprefix;
 	char* lower_case_cprefix;
@@ -48,9 +54,9 @@ enum  {
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type);
-static char* vala_enum_real_get_lower_case_cprefix (ValaDataType* base);
+static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_enum_get_lower_case_csuffix (ValaEnum* self);
-static char* vala_enum_real_get_lower_case_cname (ValaDataType* base, const char* infix);
+static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static char* vala_enum_real_get_upper_case_cname (ValaDataType* base, const char* infix);
 static gboolean vala_enum_real_is_reference_type (ValaDataType* base);
 static void vala_enum_set_cname (ValaEnum* self, const char* cname);
@@ -73,16 +79,12 @@ static void vala_enum_dispose (GObject * obj);
  */
 ValaEnum* vala_enum_new (const char* name, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaEnum * self;
 	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, name), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
-	self = g_object_newv (VALA_TYPE_ENUM, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_ENUM, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -96,7 +98,8 @@ void vala_enum_add_value (ValaEnum* self, ValaEnumValue* value)
 {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	g_return_if_fail (VALA_IS_ENUM_VALUE (value));
-	self->priv->values = g_list_append (self->priv->values, g_object_ref (value));
+	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) value)), VALA_SYMBOL (value));
 }
 
 
@@ -109,7 +112,24 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m)
 {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
-	self->priv->methods = g_list_append (self->priv->methods, g_object_ref (m));
+	if (VALA_IS_CREATION_METHOD (m)) {
+		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) m)), "construction methods may only be declared within classes and structs");
+		vala_code_node_set_error (VALA_CODE_NODE (m), TRUE);
+		return;
+	}
+	if (vala_method_get_instance (m)) {
+		ValaFormalParameter* __temp1;
+		ValaTypeReference* __temp0;
+		__temp1 = NULL;
+		__temp0 = NULL;
+		vala_method_set_this_parameter (m, (__temp1 = vala_formal_parameter_new ("this", (__temp0 = vala_type_reference_new ()), NULL)));
+		(__temp1 == NULL ? NULL : (__temp1 = (g_object_unref (__temp1), NULL)));
+		(__temp0 == NULL ? NULL : (__temp0 = (g_object_unref (__temp0), NULL)));
+		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
+	}
+	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) m)), VALA_SYMBOL (m));
 }
 
 
@@ -118,17 +138,17 @@ void vala_enum_add_method (ValaEnum* self, ValaMethod* m)
  *
  * @return list of methods
  */
-GList* vala_enum_get_methods (ValaEnum* self)
+GeeCollection* vala_enum_get_methods (ValaEnum* self)
 {
 	g_return_val_if_fail (VALA_IS_ENUM (self), NULL);
-	return g_list_copy (self->priv->methods);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->methods)));
 }
 
 
 static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_enum (visitor, self);
 }
@@ -137,33 +157,37 @@ static void vala_enum_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 static void vala_enum_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp1;
-		GList* value_it;
-		__temp1 = NULL;
-		__temp1 = self->priv->values;
-		for (value_it = __temp1; value_it != NULL; value_it = value_it->next) {
+		GeeList* value_collection;
+		GeeIterator* value_it;
+		value_collection = self->priv->values;
+		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
+		while (gee_iterator_next (value_it)) {
 			ValaEnumValue* value;
-			value = value_it->data;
+			value = gee_iterator_get (value_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (value), visitor);
+				(value == NULL ? NULL : (value = (g_object_unref (value), NULL)));
 			}
 		}
+		(value_it == NULL ? NULL : (value_it = (g_object_unref (value_it), NULL)));
 	}
 	{
-		GList* __temp2;
-		GList* m_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->methods;
-		for (m_it = __temp2; m_it != NULL; m_it = m_it->next) {
+		GeeList* m_collection;
+		GeeIterator* m_it;
+		m_collection = self->priv->methods;
+		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
+		while (gee_iterator_next (m_it)) {
 			ValaMethod* m;
-			m = m_it->data;
+			m = gee_iterator_get (m_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
+				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 			}
 		}
+		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
 	}
 }
 
@@ -172,13 +196,13 @@ static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaEnum * self;
 	const char* __temp5;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	if (self->priv->cname == NULL) {
 		char* __temp4;
 		char* __temp3;
 		__temp4 = NULL;
 		__temp3 = NULL;
-		self->priv->cname = (__temp4 = g_strdup_printf ("%s%s", (__temp3 = vala_namespace_get_cprefix (VALA_DATA_TYPE (self)->namespace)), vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp4);
+		self->priv->cname = (__temp4 = g_strdup_printf ("%s%s", (__temp3 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp4);
 		(__temp3 = (g_free (__temp3), NULL));
 	}
 	__temp5 = NULL;
@@ -186,17 +210,17 @@ static char* vala_enum_real_get_cname (ValaDataType* base, gboolean const_type)
 }
 
 
-static char* vala_enum_real_get_lower_case_cprefix (ValaDataType* base)
+static char* vala_enum_real_get_lower_case_cprefix (ValaSymbol* base)
 {
 	ValaEnum * self;
 	const char* __temp9;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	if (self->priv->lower_case_cprefix == NULL) {
 		char* __temp8;
 		char* __temp7;
 		__temp8 = NULL;
 		__temp7 = NULL;
-		self->priv->lower_case_cprefix = (__temp8 = g_strdup_printf ("%s_", (__temp7 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp8);
+		self->priv->lower_case_cprefix = (__temp8 = g_strdup_printf ("%s_", (__temp7 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp8);
 		(__temp7 = (g_free (__temp7), NULL));
 	}
 	__temp9 = NULL;
@@ -211,27 +235,27 @@ static char* vala_enum_get_lower_case_csuffix (ValaEnum* self)
 	if (self->priv->lower_case_csuffix == NULL) {
 		char* __temp11;
 		__temp11 = NULL;
-		self->priv->lower_case_csuffix = (__temp11 = vala_namespace_camel_case_to_lower_case (vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp11);
+		self->priv->lower_case_csuffix = (__temp11 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp11);
 	}
 	__temp12 = NULL;
 	return (__temp12 = self->priv->lower_case_csuffix, (__temp12 == NULL ? NULL : g_strdup (__temp12)));
 }
 
 
-static char* vala_enum_real_get_lower_case_cname (ValaDataType* base, const char* infix)
+static char* vala_enum_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
 {
 	ValaEnum * self;
 	char* __temp15;
 	char* __temp14;
 	char* __temp16;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	if (infix == NULL) {
 		infix = "";
 	}
 	__temp15 = NULL;
 	__temp14 = NULL;
 	__temp16 = NULL;
-	return (__temp16 = g_strdup_printf ("%s%s%s", (__temp14 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp15 = vala_enum_get_lower_case_csuffix (self))), (__temp15 = (g_free (__temp15), NULL)), (__temp14 = (g_free (__temp14), NULL)), __temp16);
+	return (__temp16 = g_strdup_printf ("%s%s%s", (__temp14 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (__temp15 = vala_enum_get_lower_case_csuffix (self))), (__temp15 = (g_free (__temp15), NULL)), (__temp14 = (g_free (__temp14), NULL)), __temp16);
 }
 
 
@@ -242,19 +266,19 @@ static char* vala_enum_real_get_upper_case_cname (ValaDataType* base, const char
 	char* __temp19;
 	char* __temp18;
 	char* __temp21;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	__temp20 = NULL;
 	__temp19 = NULL;
 	__temp18 = NULL;
 	__temp21 = NULL;
-	return (__temp21 = g_utf8_strup ((__temp20 = g_strdup_printf ("%s%s", (__temp18 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), (__temp19 = vala_namespace_camel_case_to_lower_case (vala_data_type_get_name (VALA_DATA_TYPE (self)))))), -1), (__temp20 = (g_free (__temp20), NULL)), (__temp19 = (g_free (__temp19), NULL)), (__temp18 = (g_free (__temp18), NULL)), __temp21);
+	return (__temp21 = g_utf8_strup ((__temp20 = g_strdup_printf ("%s%s", (__temp18 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), (__temp19 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self)))))), -1), (__temp20 = (g_free (__temp20), NULL)), (__temp19 = (g_free (__temp19), NULL)), (__temp18 = (g_free (__temp18), NULL)), __temp21);
 }
 
 
 static gboolean vala_enum_real_is_reference_type (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return FALSE;
 }
 
@@ -328,18 +352,20 @@ static void vala_enum_process_ccode_attribute (ValaEnum* self, ValaAttribute* a)
 		char* val;
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
-			char** __temp32;
+			char** filename_collection;
 			char** filename_it;
-			__temp32 = NULL;
-			__temp32 = g_strsplit (val, ",", 0);
-			for (filename_it = __temp32; *filename_it != NULL; filename_it = filename_it + 1) {
+			filename_collection = g_strsplit (val, ",", 0);
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* __temp32;
 				char* filename;
-				filename = *filename_it;
+				__temp32 = NULL;
+				filename = (__temp32 = *filename_it, (__temp32 == NULL ? NULL : g_strdup (__temp32)));
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
+					(filename = (g_free (filename), NULL));
 				}
 			}
-			(__temp32 = (g_free (__temp32), NULL));
+			(filename_collection = (g_strfreev (filename_collection), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
@@ -353,21 +379,23 @@ void vala_enum_process_attributes (ValaEnum* self)
 {
 	g_return_if_fail (VALA_IS_ENUM (self));
 	{
-		GList* __temp33;
+		GList* a_collection;
 		GList* a_it;
-		__temp33 = NULL;
-		__temp33 = VALA_CODE_NODE (self)->attributes;
-		for (a_it = __temp33; a_it != NULL; a_it = a_it->next) {
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp33;
 			ValaAttribute* a;
-			a = a_it->data;
+			__temp33 = NULL;
+			a = (__temp33 = a_it->data, (__temp33 == NULL ? NULL : g_object_ref (__temp33)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_enum_process_ccode_attribute (self, a);
 				} else {
 					if (g_utf8_collate (vala_attribute_get_name (a), "ErrorDomain") == 0) {
-						(vala_enum_set_error_domain (self, TRUE), vala_enum_get_error_domain (self));
+						vala_enum_set_error_domain (self, TRUE);
 					}
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -377,7 +405,7 @@ void vala_enum_process_attributes (ValaEnum* self)
 static char* vala_enum_real_get_type_id (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return g_strdup ("G_TYPE_INT");
 }
 
@@ -386,7 +414,7 @@ static char* vala_enum_real_get_type_id (ValaDataType* base)
 static char* vala_enum_real_get_marshaller_type_name (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return g_strdup ("ENUM");
 }
 
@@ -394,7 +422,7 @@ static char* vala_enum_real_get_marshaller_type_name (ValaDataType* base)
 static char* vala_enum_real_get_get_value_function (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return g_strdup ("g_value_get_enum");
 }
 
@@ -402,7 +430,7 @@ static char* vala_enum_real_get_get_value_function (ValaDataType* base)
 static char* vala_enum_real_get_set_value_function (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return g_strdup ("g_value_set_enum");
 }
 
@@ -410,7 +438,7 @@ static char* vala_enum_real_get_set_value_function (ValaDataType* base)
 static char* vala_enum_real_get_default_value (ValaDataType* base)
 {
 	ValaEnum * self;
-	self = VALA_ENUM (base);
+	self = ((ValaEnum*) base);
 	return g_strdup ("0");
 }
 
@@ -463,8 +491,8 @@ static void vala_enum_class_init (ValaEnumClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_enum_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_enum_real_accept_children;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_enum_real_get_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cprefix = vala_enum_real_get_lower_case_cprefix;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_enum_real_get_lower_case_cname;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_enum_real_get_lower_case_cprefix;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_enum_real_get_lower_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_upper_case_cname = vala_enum_real_get_upper_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_type = vala_enum_real_is_reference_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_enum_real_get_type_id;
@@ -479,6 +507,8 @@ static void vala_enum_class_init (ValaEnumClass * klass)
 static void vala_enum_init (ValaEnum * self)
 {
 	self->priv = VALA_ENUM_GET_PRIVATE (self);
+	self->priv->values = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -488,8 +518,8 @@ static void vala_enum_dispose (GObject * obj)
 	ValaEnumClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_ENUM (obj);
-	(self->priv->values == NULL ? NULL : (self->priv->values = (g_list_foreach (self->priv->values, (GFunc) g_object_unref, NULL), g_list_free (self->priv->values), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_list_foreach (self->priv->methods, (GFunc) g_object_unref, NULL), g_list_free (self->priv->methods), NULL)));
+	(self->priv->values == NULL ? NULL : (self->priv->values = (g_object_unref (self->priv->values), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->cprefix = (g_free (self->priv->cprefix), NULL));
 	(self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL));
@@ -500,7 +530,7 @@ static void vala_enum_dispose (GObject * obj)
 }
 
 
-GType vala_enum_get_type ()
+GType vala_enum_get_type (void)
 {
 	static GType vala_enum_type_id = 0;
 	if (G_UNLIKELY (vala_enum_type_id == 0)) {
