@@ -22,10 +22,10 @@
 
 #ifndef __VALAEXPRESSION_H__
 #define __VALAEXPRESSION_H__
-typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/arraylist.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -38,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION))
 #define VALA_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION, ValaExpressionClass))
 
+typedef struct _ValaExpressionPrivate ValaExpressionPrivate;
 
 /**
  * Base class for all code nodes that might be used as an expression.
@@ -45,7 +46,7 @@ G_BEGIN_DECLS
 struct _ValaExpression {
 	ValaCodeNode parent;
 	ValaExpressionPrivate * priv;
-	GList* temp_vars;
+	GeeArrayList* temp_vars;
 };
 struct _ValaExpressionClass {
 	ValaCodeNodeClass parent;
@@ -63,7 +64,9 @@ gboolean vala_expression_get_ref_missing (ValaExpression* self);
 void vala_expression_set_ref_missing (ValaExpression* self, gboolean value);
 gboolean vala_expression_get_ref_sink (ValaExpression* self);
 void vala_expression_set_ref_sink (ValaExpression* self, gboolean value);
-GType vala_expression_get_type ();
+gboolean vala_expression_get_can_fail (ValaExpression* self);
+void vala_expression_set_can_fail (ValaExpression* self, gboolean value);
+GType vala_expression_get_type (void);
 
 G_END_DECLS
 
