@@ -1,6 +1,6 @@
 /* valaexpressionstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,12 +22,11 @@
 
 #ifndef __VALAEXPRESSIONSTATEMENT_H__
 #define __VALAEXPRESSIONSTATEMENT_H__
-typedef struct _ValaExpressionStatementPrivate ValaExpressionStatementPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -39,23 +38,25 @@ G_BEGIN_DECLS
 #define VALA_IS_EXPRESSION_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_EXPRESSION_STATEMENT))
 #define VALA_EXPRESSION_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatementClass))
 
+typedef struct _ValaExpressionStatementPrivate ValaExpressionStatementPrivate;
 
 /**
  * A code statement that evaluates a given expression. The value computed by the
  * expression, if any, is discarded.
  */
 struct _ValaExpressionStatement {
-	ValaStatement parent;
+	ValaCodeNode parent;
 	ValaExpressionStatementPrivate * priv;
 };
 struct _ValaExpressionStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent;
 };
 
-ValaExpressionStatement* vala_expression_statement_new (ValaExpression* expr, ValaSourceReference* source);
+ValaExpressionStatement* vala_expression_statement_new (ValaExpression* expression, ValaSourceReference* source_reference);
+ValaProperty* vala_expression_statement_assigned_property (ValaExpressionStatement* self);
 ValaExpression* vala_expression_statement_get_expression (ValaExpressionStatement* self);
 void vala_expression_statement_set_expression (ValaExpressionStatement* self, ValaExpression* value);
-GType vala_expression_statement_get_type ();
+GType vala_expression_statement_get_type (void);
 
 G_END_DECLS
 
