@@ -1,6 +1,6 @@
 /* valaforeachstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,13 +22,12 @@
 
 #ifndef __VALAFOREACHSTATEMENT_H__
 #define __VALAFOREACHSTATEMENT_H__
-typedef struct _ValaForeachStatementPrivate ValaForeachStatementPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valastatement.h>
+#include <vala/valablock.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -41,31 +40,36 @@ G_BEGIN_DECLS
 #define VALA_IS_FOREACH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FOREACH_STATEMENT))
 #define VALA_FOREACH_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FOREACH_STATEMENT, ValaForeachStatementClass))
 
+typedef struct _ValaForeachStatementPrivate ValaForeachStatementPrivate;
 
 /**
  * Represents a foreach statement in the source code. Foreach statements iterate
  * over the elements of a collection.
  */
 struct _ValaForeachStatement {
-	ValaStatement parent;
+	ValaBlock parent;
 	ValaForeachStatementPrivate * priv;
 };
 struct _ValaForeachStatementClass {
-	ValaStatementClass parent;
+	ValaBlockClass parent;
 };
 
-ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type, const char* id, ValaExpression* col, ValaStatement* _body, ValaSourceReference* source);
+ValaForeachStatement* vala_foreach_statement_new (ValaTypeReference* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
 ValaTypeReference* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
 void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaTypeReference* value);
 char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self);
 void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const char* value);
 ValaExpression* vala_foreach_statement_get_collection (ValaForeachStatement* self);
 void vala_foreach_statement_set_collection (ValaForeachStatement* self, ValaExpression* value);
-ValaStatement* vala_foreach_statement_get_body (ValaForeachStatement* self);
-void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaStatement* value);
+ValaBlock* vala_foreach_statement_get_body (ValaForeachStatement* self);
+void vala_foreach_statement_set_body (ValaForeachStatement* self, ValaBlock* value);
 ValaVariableDeclarator* vala_foreach_statement_get_variable_declarator (ValaForeachStatement* self);
 void vala_foreach_statement_set_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
-GType vala_foreach_statement_get_type ();
+ValaVariableDeclarator* vala_foreach_statement_get_collection_variable_declarator (ValaForeachStatement* self);
+void vala_foreach_statement_set_collection_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
+ValaVariableDeclarator* vala_foreach_statement_get_iterator_variable_declarator (ValaForeachStatement* self);
+void vala_foreach_statement_set_iterator_variable_declarator (ValaForeachStatement* self, ValaVariableDeclarator* value);
+GType vala_foreach_statement_get_type (void);
 
 G_END_DECLS
 
