@@ -23,14 +23,15 @@
 
 #ifndef __VALAFORMALPARAMETER_H__
 #define __VALAFORMALPARAMETER_H__
-typedef struct _ValaFormalParameterPrivate ValaFormalParameterPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <vala/valacodenode.h>
+#include <gee/collection.h>
+#include <vala/valasymbol.h>
 #include <vala/valainvokable.h>
+#include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
 
@@ -42,22 +43,21 @@ G_BEGIN_DECLS
 #define VALA_IS_FORMAL_PARAMETER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FORMAL_PARAMETER))
 #define VALA_FORMAL_PARAMETER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterClass))
 
+typedef struct _ValaFormalParameterPrivate ValaFormalParameterPrivate;
 
 /**
  * Represents a formal parameter in method and callback signatures.
  */
 struct _ValaFormalParameter {
-	ValaCodeNode parent;
+	ValaSymbol parent;
 	ValaFormalParameterPrivate * priv;
 };
 struct _ValaFormalParameterClass {
-	ValaCodeNodeClass parent;
+	ValaSymbolClass parent;
 };
 
 ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaTypeReference* type, ValaSourceReference* source);
 ValaFormalParameter* vala_formal_parameter_new_with_ellipsis (ValaSourceReference* source);
-char* vala_formal_parameter_get_name (ValaFormalParameter* self);
-void vala_formal_parameter_set_name (ValaFormalParameter* self, const char* value);
 ValaTypeReference* vala_formal_parameter_get_type_reference (ValaFormalParameter* self);
 void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaTypeReference* value);
 gboolean vala_formal_parameter_get_ellipsis (ValaFormalParameter* self);
@@ -68,7 +68,7 @@ gboolean vala_formal_parameter_get_no_array_length (ValaFormalParameter* self);
 void vala_formal_parameter_set_no_array_length (ValaFormalParameter* self, gboolean value);
 gboolean vala_formal_parameter_get_construct_parameter (ValaFormalParameter* self);
 void vala_formal_parameter_set_construct_parameter (ValaFormalParameter* self, gboolean value);
-GType vala_formal_parameter_get_type ();
+GType vala_formal_parameter_get_type (void);
 
 G_END_DECLS
 
