@@ -19,20 +19,22 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaforstatement.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valaexpression.h>
+#include <vala/valablock.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaforstatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaForStatementPrivate {
-	ValaStatement* _body;
-	GList* initializer;
-	GList* iterator;
+	GeeList* initializer;
+	GeeList* iterator;
 	ValaExpression* _condition;
+	ValaBlock* _body;
 };
 #define VALA_FOR_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FOR_STATEMENT, ValaForStatementPrivate))
 enum  {
@@ -43,31 +45,37 @@ enum  {
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
 static gpointer vala_for_statement_parent_class = NULL;
+static ValaStatementIface* vala_for_statement_vala_statement_parent_iface = NULL;
 static void vala_for_statement_dispose (GObject * obj);
 
 
 /**
  * Creates a new for statement.
  *
- * @param cond   loop condition
- * @param body   loop body
- * @param source reference to source code
- * @return       newly created for statement
+ * @param cond             loop condition
+ * @param body             loop body
+ * @param source_reference reference to source code
+ * @return                 newly created for statement
  */
-ValaForStatement* vala_for_statement_new (ValaExpression* cond, ValaStatement* _body, ValaSourceReference* source)
+ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference)
 {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForStatement * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (_body == NULL || VALA_IS_STATEMENT (_body), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
+	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, cond), __params_it++);
-	(__params_it->name = "body", g_value_init (&__params_it->value, VALA_TYPE_STATEMENT), g_value_set_object (&__params_it->value, _body), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
+	(__params_it->name = "condition", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, condition), __params_it++);
 	self = g_object_newv (VALA_TYPE_FOR_STATEMENT, __params_it - __params, __params);
+	vala_for_statement_set_body (self, body);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -81,8 +89,8 @@ void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression*
 {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (init));
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (init)));
-	self->priv->initializer = g_list_append (self->priv->initializer, g_object_ref (init));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self));
+	gee_collection_add (GEE_COLLECTION (self->priv->initializer), init);
 }
 
 
@@ -91,10 +99,10 @@ void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression*
  *
  * @return initializer list
  */
-GList* vala_for_statement_get_initializer (ValaForStatement* self)
+GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self)
 {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return g_list_copy (self->priv->initializer);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->initializer)));
 }
 
 
@@ -107,8 +115,8 @@ void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* it
 {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (iter));
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (iter), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (iter)));
-	self->priv->iterator = g_list_append (self->priv->iterator, g_object_ref (iter));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (iter), VALA_CODE_NODE (self));
+	gee_collection_add (GEE_COLLECTION (self->priv->iterator), iter);
 }
 
 
@@ -117,47 +125,51 @@ void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* it
  *
  * @return iterator
  */
-GList* vala_for_statement_get_iterator (ValaForStatement* self)
+GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self)
 {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return g_list_copy (self->priv->iterator);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->iterator)));
 }
 
 
 static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaForStatement * self;
-	self = VALA_FOR_STATEMENT (base);
+	self = ((ValaForStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp2;
-		GList* init_expr_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->initializer;
-		for (init_expr_it = __temp2; init_expr_it != NULL; init_expr_it = init_expr_it->next) {
+		GeeList* init_expr_collection;
+		GeeIterator* init_expr_it;
+		init_expr_collection = self->priv->initializer;
+		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
+		while (gee_iterator_next (init_expr_it)) {
 			ValaExpression* init_expr;
-			init_expr = init_expr_it->data;
+			init_expr = gee_iterator_get (init_expr_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (init_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, init_expr);
+				(init_expr == NULL ? NULL : (init_expr = (g_object_unref (init_expr), NULL)));
 			}
 		}
+		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_for_statement_get_condition (self));
 	{
-		GList* __temp3;
-		GList* it_expr_it;
-		__temp3 = NULL;
-		__temp3 = self->priv->iterator;
-		for (it_expr_it = __temp3; it_expr_it != NULL; it_expr_it = it_expr_it->next) {
+		GeeList* it_expr_collection;
+		GeeIterator* it_expr_it;
+		it_expr_collection = self->priv->iterator;
+		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
+		while (gee_iterator_next (it_expr_it)) {
 			ValaExpression* it_expr;
-			it_expr = it_expr_it->data;
+			it_expr = gee_iterator_get (it_expr_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (it_expr), visitor);
 				vala_code_visitor_visit_end_full_expression (visitor, it_expr);
+				(it_expr == NULL ? NULL : (it_expr = (g_object_unref (it_expr), NULL)));
 			}
 		}
+		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_for_statement_get_body (self)), visitor);
 	vala_code_visitor_visit_for_statement (visitor, self);
@@ -167,31 +179,37 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaForStatement * self;
-	GList* iter;
-	self = VALA_FOR_STATEMENT (base);
+	self = ((ValaForStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
-	iter = NULL;
 	if (VALA_CODE_NODE (vala_for_statement_get_condition (self)) == old_node) {
-		(vala_for_statement_set_condition (self, VALA_EXPRESSION (new_node)), vala_for_statement_get_condition (self));
+		vala_for_statement_set_condition (self, VALA_EXPRESSION (new_node));
 		return;
 	}
-	for (iter = self->priv->initializer; iter != NULL; iter = iter->next) {
-		if (iter->data == old_node) {
-			GList* silbling;
-			silbling = iter->next;
-			self->priv->initializer = g_list_delete_link (self->priv->initializer, iter);
-			self->priv->initializer = g_list_insert_before (self->priv->initializer, silbling, g_object_ref (new_node));
-			return;
+	{
+		gint i;
+		i = 0;
+		for (i = 0; i < gee_collection_get_size (((GeeCollection*) self->priv->initializer)); i++) {
+			ValaExpression* __temp2;
+			gboolean __temp3;
+			__temp2 = NULL;
+			if ((__temp3 = VALA_CODE_NODE ((__temp2 = gee_list_get (((GeeList*) self->priv->initializer), i))) == old_node, (__temp2 == NULL ? NULL : (__temp2 = (g_object_unref (__temp2), NULL))), __temp3)) {
+				gee_list_set (((GeeList*) self->priv->initializer), i, VALA_EXPRESSION (new_node));
+				return;
+			}
 		}
 	}
-	for (iter = self->priv->iterator; iter != NULL; iter = iter->next) {
-		if (iter->data == old_node) {
-			GList* silbling;
-			silbling = iter->next;
-			self->priv->iterator = g_list_delete_link (self->priv->iterator, iter);
-			self->priv->iterator = g_list_insert_before (self->priv->iterator, silbling, g_object_ref (new_node));
-			return;
+	{
+		gint i;
+		i = 0;
+		for (i = 0; i < gee_collection_get_size (((GeeCollection*) self->priv->iterator)); i++) {
+			ValaExpression* __temp4;
+			gboolean __temp5;
+			__temp4 = NULL;
+			if ((__temp5 = VALA_CODE_NODE ((__temp4 = gee_list_get (((GeeList*) self->priv->iterator), i))) == old_node, (__temp4 == NULL ? NULL : (__temp4 = (g_object_unref (__temp4), NULL))), __temp5)) {
+				gee_list_set (((GeeList*) self->priv->iterator), i, VALA_EXPRESSION (new_node));
+				return;
+			}
 		}
 	}
 }
@@ -206,29 +224,30 @@ ValaExpression* vala_for_statement_get_condition (ValaForStatement* self)
 
 void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value)
 {
-	ValaExpression* __temp5;
+	ValaExpression* __temp7;
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	__temp5 = NULL;
-	self->priv->_condition = (__temp5 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp5);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_condition)));
+	__temp7 = NULL;
+	self->priv->_condition = (__temp7 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp7);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 }
 
 
-ValaStatement* vala_for_statement_get_body (ValaForStatement* self)
+ValaBlock* vala_for_statement_get_body (ValaForStatement* self)
 {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_for_statement_set_body (ValaForStatement* self, ValaStatement* value)
+void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value)
 {
-	ValaStatement* __temp8;
-	ValaStatement* __temp7;
+	ValaBlock* __temp10;
+	ValaBlock* __temp9;
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	__temp8 = NULL;
-	__temp7 = NULL;
-	self->priv->_body = (__temp8 = (__temp7 = value, (__temp7 == NULL ? NULL : g_object_ref (__temp7))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp8);
+	__temp10 = NULL;
+	__temp9 = NULL;
+	self->priv->_body = (__temp10 = (__temp9 = value, (__temp9 == NULL ? NULL : g_object_ref (__temp9))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp10);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
 }
 
 
@@ -272,13 +291,21 @@ static void vala_for_statement_class_init (ValaForStatementClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_for_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_for_statement_real_replace;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+}
+
+
+static void vala_for_statement_vala_statement_interface_init (ValaStatementIface * iface)
+{
+	vala_for_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
 static void vala_for_statement_init (ValaForStatement * self)
 {
 	self->priv = VALA_FOR_STATEMENT_GET_PRIVATE (self);
+	self->priv->initializer = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->iterator = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 }
 
 
@@ -288,22 +315,24 @@ static void vala_for_statement_dispose (GObject * obj)
 	ValaForStatementClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_FOR_STATEMENT (obj);
-	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_list_foreach (self->priv->initializer, (GFunc) g_object_unref, NULL), g_list_free (self->priv->initializer), NULL)));
-	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_list_foreach (self->priv->iterator, (GFunc) g_object_unref, NULL), g_list_free (self->priv->iterator), NULL)));
+	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_object_unref (self->priv->initializer), NULL)));
+	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_object_unref (self->priv->iterator), NULL)));
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
+	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	klass = VALA_FOR_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_FOR_STATEMENT));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_for_statement_get_type ()
+GType vala_for_statement_get_type (void)
 {
 	static GType vala_for_statement_type_id = 0;
 	if (G_UNLIKELY (vala_for_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForStatement), 0, (GInstanceInitFunc) vala_for_statement_init };
-		vala_for_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaForStatement", &g_define_type_info, 0);
+		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_for_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_for_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaForStatement", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_for_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
 	}
 	return vala_for_statement_type_id;
 }
