@@ -22,9 +22,6 @@
 
 #ifndef __VALAINSTANCECAST_H__
 #define __VALAINSTANCECAST_H__
-typedef struct _ValaInstanceCast ValaInstanceCast;
-typedef struct _ValaInstanceCastClass ValaInstanceCastClass;
-typedef struct _ValaInstanceCastPrivate ValaInstanceCastPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -42,6 +39,9 @@ G_BEGIN_DECLS
 #define VALA_IS_INSTANCE_CAST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INSTANCE_CAST))
 #define VALA_INSTANCE_CAST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INSTANCE_CAST, ValaInstanceCastClass))
 
+typedef struct _ValaInstanceCast ValaInstanceCast;
+typedef struct _ValaInstanceCastClass ValaInstanceCastClass;
+typedef struct _ValaInstanceCastPrivate ValaInstanceCastPrivate;
 
 /**
  * Represents a runtime checked object instance cast expression in the C code.
@@ -59,7 +59,7 @@ ValaDataType* vala_instance_cast_get_type_reference (ValaInstanceCast* self);
 void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaDataType* value);
 ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self);
 void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression* value);
-GType vala_instance_cast_get_type ();
+GType vala_instance_cast_get_type (void);
 
 G_END_DECLS
 
