@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaintegerliteral.h"
 #include <vala/valasourcereference.h>
@@ -50,16 +48,12 @@ static void vala_integer_literal_dispose (GObject * obj);
  */
 ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaIntegerLiteral * self;
 	g_return_val_if_fail (i != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "value", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, i), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_INTEGER_LITERAL, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_INTEGER_LITERAL, 0, NULL);
+	vala_integer_literal_set_value (self, i);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -67,7 +61,7 @@ ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaIntegerLiteral * self;
-	self = VALA_INTEGER_LITERAL (base);
+	self = ((ValaIntegerLiteral*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_integer_literal (visitor, self);
 }
@@ -76,7 +70,7 @@ static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisito
 static char* vala_integer_literal_real_to_string (ValaCodeNode* base)
 {
 	ValaIntegerLiteral * self;
-	self = VALA_INTEGER_LITERAL (base);
+	self = ((ValaIntegerLiteral*) base);
 	return g_strdup (vala_integer_literal_get_value (self));
 }
 
@@ -227,7 +221,7 @@ static void vala_integer_literal_dispose (GObject * obj)
 }
 
 
-GType vala_integer_literal_get_type ()
+GType vala_integer_literal_get_type (void)
 {
 	static GType vala_integer_literal_type_id = 0;
 	if (G_UNLIKELY (vala_integer_literal_type_id == 0)) {
