@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaliteral.h"
 #include <vala/valatypereference.h>
@@ -110,7 +108,7 @@ static void vala_literal_dispose (GObject * obj)
 }
 
 
-GType vala_literal_get_type ()
+GType vala_literal_get_type (void)
 {
 	static GType vala_literal_type_id = 0;
 	if (G_UNLIKELY (vala_literal_type_id == 0)) {
