@@ -48,7 +48,7 @@ struct _ValaLockableIface {
 
 gboolean vala_lockable_get_lock_used (ValaLockable* self);
 void vala_lockable_set_lock_used (ValaLockable* self, gboolean used);
-GType vala_lockable_get_type ();
+GType vala_lockable_get_type (void);
 
 G_END_DECLS
 
