@@ -30,7 +30,6 @@
 #include <vala/valacodecontext.h>
 #include <vala/valaexpression.h>
 #include <vala/valasourcefile.h>
-#include <vala/valanamespace.h>
 #include <vala/valaclass.h>
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
@@ -50,6 +49,7 @@
 #include <vala/valacatchclause.h>
 #include <vala/valamemberaccess.h>
 #include <vala/valainvocationexpression.h>
+#include <vala/valaobjectcreationexpression.h>
 #include <vala/valabinaryexpression.h>
 #include <vala/valaassignment.h>
 
@@ -80,7 +80,7 @@ struct _ValaMemoryManagerClass {
 };
 
 void vala_memory_manager_analyze (ValaMemoryManager* self, ValaCodeContext* context);
-GType vala_memory_manager_get_type ();
+GType vala_memory_manager_get_type (void);
 
 G_END_DECLS
 
