@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valanamedargument.h"
 #include <vala/valaexpression.h>
@@ -59,12 +57,17 @@ ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* a
 	g_return_val_if_fail (_name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (arg), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	(__params_it->name = "argument", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, arg), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
 	self = g_object_newv (VALA_TYPE_NAMED_ARGUMENT, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -72,7 +75,7 @@ ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* a
 static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaNamedArgument * self;
-	self = VALA_NAMED_ARGUMENT (base);
+	self = ((ValaNamedArgument*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_named_argument_get_argument (self)), visitor);
 	vala_code_visitor_visit_named_argument (visitor, self);
@@ -174,7 +177,7 @@ static void vala_named_argument_dispose (GObject * obj)
 }
 
 
-GType vala_named_argument_get_type ()
+GType vala_named_argument_get_type (void)
 {
 	static GType vala_named_argument_type_id = 0;
 	if (G_UNLIKELY (vala_named_argument_type_id == 0)) {
