@@ -1,6 +1,6 @@
 /* valanamespacereference.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,7 +22,6 @@
 
 #ifndef __VALANAMESPACEREFERENCE_H__
 #define __VALANAMESPACEREFERENCE_H__
-typedef struct _ValaNamespaceReferencePrivate ValaNamespaceReferencePrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,6 +39,7 @@ G_BEGIN_DECLS
 #define VALA_IS_NAMESPACE_REFERENCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_NAMESPACE_REFERENCE))
 #define VALA_NAMESPACE_REFERENCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_NAMESPACE_REFERENCE, ValaNamespaceReferenceClass))
 
+typedef struct _ValaNamespaceReferencePrivate ValaNamespaceReferencePrivate;
 
 /**
  * A reference to a namespace symbol.
@@ -52,12 +52,12 @@ struct _ValaNamespaceReferenceClass {
 	ValaCodeNodeClass parent;
 };
 
-ValaNamespaceReference* vala_namespace_reference_new (const char* _name, ValaSourceReference* source);
+ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSourceReference* source_reference);
 char* vala_namespace_reference_get_name (ValaNamespaceReference* self);
 void vala_namespace_reference_set_name (ValaNamespaceReference* self, const char* value);
 ValaSymbol* vala_namespace_reference_get_namespace_symbol (ValaNamespaceReference* self);
 void vala_namespace_reference_set_namespace_symbol (ValaNamespaceReference* self, ValaSymbol* value);
-GType vala_namespace_reference_get_type ();
+GType vala_namespace_reference_get_type (void);
 
 G_END_DECLS
 
