@@ -54,7 +54,7 @@ struct _ValaNullLiteralClass {
 };
 
 ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source);
-GType vala_null_literal_get_type ();
+GType vala_null_literal_get_type (void);
 
 G_END_DECLS
 
