@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaparenthesizedexpression.h"
 #include <vala/valasourcereference.h>
@@ -55,11 +53,16 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 	ValaParenthesizedExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
 	self = g_object_newv (VALA_TYPE_PARENTHESIZED_EXPRESSION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -67,7 +70,7 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaParenthesizedExpression * self;
-	self = VALA_PARENTHESIZED_EXPRESSION (base);
+	self = ((ValaParenthesizedExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_parenthesized_expression (visitor, self);
@@ -77,11 +80,11 @@ static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaC
 static void vala_parenthesized_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaParenthesizedExpression * self;
-	self = VALA_PARENTHESIZED_EXPRESSION (base);
+	self = ((ValaParenthesizedExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)) == old_node) {
-		(vala_parenthesized_expression_set_inner (self, VALA_EXPRESSION (new_node)), vala_parenthesized_expression_get_inner (self));
+		vala_parenthesized_expression_set_inner (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -99,7 +102,7 @@ void vala_parenthesized_expression_set_inner (ValaParenthesizedExpression* self,
 	g_return_if_fail (VALA_IS_PARENTHESIZED_EXPRESSION (self));
 	__temp1 = NULL;
 	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
@@ -159,7 +162,7 @@ static void vala_parenthesized_expression_dispose (GObject * obj)
 }
 
 
-GType vala_parenthesized_expression_get_type ()
+GType vala_parenthesized_expression_get_type (void)
 {
 	static GType vala_parenthesized_expression_type_id = 0;
 	if (G_UNLIKELY (vala_parenthesized_expression_type_id == 0)) {
