@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valapointerindirection.h"
 #include <vala/valasourcereference.h>
@@ -54,11 +52,16 @@ ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, Val
 	ValaPointerIndirection * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
-	__params = g_new0 (GParameter, 2);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, inner), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source_reference), __params_it++);
 	self = g_object_newv (VALA_TYPE_POINTER_INDIRECTION, __params_it - __params, __params);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -66,7 +69,7 @@ ValaPointerIndirection* vala_pointer_indirection_new (ValaExpression* inner, Val
 static void vala_pointer_indirection_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaPointerIndirection * self;
-	self = VALA_POINTER_INDIRECTION (base);
+	self = ((ValaPointerIndirection*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_pointer_indirection_get_inner (self)), visitor);
 	vala_code_visitor_visit_pointer_indirection (visitor, self);
@@ -76,11 +79,11 @@ static void vala_pointer_indirection_real_accept (ValaCodeNode* base, ValaCodeVi
 static void vala_pointer_indirection_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaPointerIndirection * self;
-	self = VALA_POINTER_INDIRECTION (base);
+	self = ((ValaPointerIndirection*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_pointer_indirection_get_inner (self)) == old_node) {
-		(vala_pointer_indirection_set_inner (self, VALA_EXPRESSION (new_node)), vala_pointer_indirection_get_inner (self));
+		vala_pointer_indirection_set_inner (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -98,7 +101,7 @@ void vala_pointer_indirection_set_inner (ValaPointerIndirection* self, ValaExpre
 	g_return_if_fail (VALA_IS_POINTER_INDIRECTION (self));
 	__temp1 = NULL;
 	self->priv->_inner = (__temp1 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp1);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
@@ -158,7 +161,7 @@ static void vala_pointer_indirection_dispose (GObject * obj)
 }
 
 
-GType vala_pointer_indirection_get_type ()
+GType vala_pointer_indirection_get_type (void)
 {
 	static GType vala_pointer_indirection_type_id = 0;
 	if (G_UNLIKELY (vala_pointer_indirection_type_id == 0)) {
