@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaproperty.h"
 #include <vala/valatypereference.h>
@@ -28,14 +26,11 @@
 #include <vala/valaformalparameter.h>
 #include <vala/valaproperty.h>
 #include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valasymbol.h>
-#include <vala/valadatatype.h>
-#include <vala/valanamespace.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
 struct _ValaPropertyPrivate {
-	char* _name;
 	ValaTypeReference* _type_reference;
 	ValaPropertyAccessor* _get_accessor;
 	ValaPropertyAccessor* _set_accessor;
@@ -53,7 +48,6 @@ struct _ValaPropertyPrivate {
 #define VALA_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY, ValaPropertyPrivate))
 enum  {
 	VALA_PROPERTY_DUMMY_PROPERTY,
-	VALA_PROPERTY_NAME,
 	VALA_PROPERTY_TYPE_REFERENCE,
 	VALA_PROPERTY_GET_ACCESSOR,
 	VALA_PROPERTY_SET_ACCESSOR,
@@ -96,14 +90,19 @@ ValaProperty* vala_property_new (const char* _name, ValaTypeReference* type, Val
 	g_return_val_if_fail (_get_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_get_accessor), NULL);
 	g_return_val_if_fail (_set_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_set_accessor), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 5);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
 	(__params_it->name = "type-reference", g_value_init (&__params_it->value, VALA_TYPE_TYPE_REFERENCE), g_value_set_object (&__params_it->value, type), __params_it++);
-	(__params_it->name = "get-accessor", g_value_init (&__params_it->value, VALA_TYPE_PROPERTY_ACCESSOR), g_value_set_object (&__params_it->value, _get_accessor), __params_it++);
-	(__params_it->name = "set-accessor", g_value_init (&__params_it->value, VALA_TYPE_PROPERTY_ACCESSOR), g_value_set_object (&__params_it->value, _set_accessor), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
 	self = g_object_newv (VALA_TYPE_PROPERTY, __params_it - __params, __params);
+	vala_symbol_set_name (VALA_SYMBOL (self), _name);
+	vala_property_set_get_accessor (self, _get_accessor);
+	vala_property_set_set_accessor (self, _set_accessor);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -111,7 +110,7 @@ ValaProperty* vala_property_new (const char* _name, ValaTypeReference* type, Val
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaProperty * self;
-	self = VALA_PROPERTY (base);
+	self = ((ValaProperty*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_property (visitor, self);
@@ -121,7 +120,7 @@ static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaProperty * self;
-	self = VALA_PROPERTY (base);
+	self = ((ValaProperty*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_property_get_type_reference (self)), visitor);
 	if (vala_property_get_get_accessor (self) != NULL) {
@@ -151,7 +150,7 @@ char* vala_property_get_upper_case_cname (ValaProperty* self)
 	__temp1 = NULL;
 	__temp0 = NULL;
 	__temp3 = NULL;
-	return (__temp3 = g_utf8_strup ((__temp2 = g_strdup_printf ("%s_%s", (__temp0 = vala_data_type_get_lower_case_cname ((VALA_DATA_TYPE (vala_symbol_get_node (vala_symbol_get_parent_symbol (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))), NULL)), (__temp1 = vala_namespace_camel_case_to_lower_case (vala_property_get_name (self))))), -1), (__temp2 = (g_free (__temp2), NULL)), (__temp1 = (g_free (__temp1), NULL)), (__temp0 = (g_free (__temp0), NULL)), __temp3);
+	return (__temp3 = g_utf8_strup ((__temp2 = g_strdup_printf ("%s_%s", (__temp0 = vala_symbol_get_lower_case_cname (vala_symbol_get_parent_symbol (((ValaSymbol*) self)), NULL)), (__temp1 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self)))))), -1), (__temp2 = (g_free (__temp2), NULL)), (__temp1 = (g_free (__temp1), NULL)), (__temp0 = (g_free (__temp0), NULL)), __temp3);
 }
 
 
@@ -163,28 +162,30 @@ char* vala_property_get_upper_case_cname (ValaProperty* self)
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self)
 {
 	GString* str;
+	const char* __temp5;
 	char* i;
-	ValaCCodeConstant* __temp7;
+	ValaCCodeConstant* __temp8;
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	str = g_string_new ("\"");
-	i = g_strdup (vala_property_get_name (self));
+	__temp5 = NULL;
+	i = (__temp5 = vala_symbol_get_name (((ValaSymbol*) self)), (__temp5 == NULL ? NULL : g_strdup (__temp5)));
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
-		char* __temp6;
-		const char* __temp5;
+		char* __temp7;
+		const char* __temp6;
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, c);
 		}
+		__temp7 = NULL;
 		__temp6 = NULL;
-		__temp5 = NULL;
-		i = (__temp6 = (__temp5 = g_utf8_next_char (i), (__temp5 == NULL ? NULL : g_strdup (__temp5))), (i = (g_free (i), NULL)), __temp6);
+		i = (__temp7 = (__temp6 = g_utf8_next_char (i), (__temp6 == NULL ? NULL : g_strdup (__temp6))), (i = (g_free (i), NULL)), __temp7);
 	}
 	g_string_append_c (str, '"');
-	__temp7 = NULL;
-	return (__temp7 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp7);
+	__temp8 = NULL;
+	return (__temp8 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), __temp8);
 	(str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL)));
 	(i = (g_free (i), NULL));
 }
@@ -197,17 +198,19 @@ void vala_property_process_attributes (ValaProperty* self)
 {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
 	{
-		GList* __temp8;
+		GList* a_collection;
 		GList* a_it;
-		__temp8 = NULL;
-		__temp8 = VALA_CODE_NODE (self)->attributes;
-		for (a_it = __temp8; a_it != NULL; a_it = a_it->next) {
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp9;
 			ValaAttribute* a;
-			a = a_it->data;
+			__temp9 = NULL;
+			a = (__temp9 = a_it->data, (__temp9 == NULL ? NULL : g_object_ref (__temp9)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "NoAccessorMethod") == 0) {
-					(vala_property_set_no_accessor_method (self, TRUE), vala_property_get_no_accessor_method (self));
+					vala_property_set_no_accessor_method (self, TRUE);
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -217,7 +220,7 @@ void vala_property_process_attributes (ValaProperty* self)
 static gboolean vala_property_real_get_lock_used (ValaLockable* base)
 {
 	ValaProperty * self;
-	self = VALA_PROPERTY (base);
+	self = ((ValaProperty*) base);
 	return self->priv->lock_used;
 }
 
@@ -225,7 +228,7 @@ static gboolean vala_property_real_get_lock_used (ValaLockable* base)
 static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used)
 {
 	ValaProperty * self;
-	self = VALA_PROPERTY (base);
+	self = ((ValaProperty*) base);
 	self->priv->lock_used = used;
 }
 
@@ -263,22 +266,6 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2)
 }
 
 
-char* vala_property_get_name (ValaProperty* self)
-{
-	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
-	return self->priv->_name;
-}
-
-
-void vala_property_set_name (ValaProperty* self, const char* value)
-{
-	char* __temp17;
-	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp17 = NULL;
-	self->priv->_name = (__temp17 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp17);
-}
-
-
 ValaTypeReference* vala_property_get_type_reference (ValaProperty* self)
 {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
@@ -288,10 +275,10 @@ ValaTypeReference* vala_property_get_type_reference (ValaProperty* self)
 
 void vala_property_set_type_reference (ValaProperty* self, ValaTypeReference* value)
 {
-	ValaTypeReference* __temp19;
+	ValaTypeReference* __temp18;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp19 = NULL;
-	self->priv->_type_reference = (__temp19 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp19);
+	__temp18 = NULL;
+	self->priv->_type_reference = (__temp18 = g_object_ref (value), (self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL))), __temp18);
 }
 
 
@@ -304,12 +291,12 @@ ValaPropertyAccessor* vala_property_get_get_accessor (ValaProperty* self)
 
 void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* value)
 {
-	ValaPropertyAccessor* __temp22;
 	ValaPropertyAccessor* __temp21;
+	ValaPropertyAccessor* __temp20;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp22 = NULL;
 	__temp21 = NULL;
-	self->priv->_get_accessor = (__temp22 = (__temp21 = value, (__temp21 == NULL ? NULL : g_object_ref (__temp21))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL))), __temp22);
+	__temp20 = NULL;
+	self->priv->_get_accessor = (__temp21 = (__temp20 = value, (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL))), __temp21);
 }
 
 
@@ -322,12 +309,12 @@ ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self)
 
 void vala_property_set_set_accessor (ValaProperty* self, ValaPropertyAccessor* value)
 {
-	ValaPropertyAccessor* __temp25;
 	ValaPropertyAccessor* __temp24;
+	ValaPropertyAccessor* __temp23;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp25 = NULL;
 	__temp24 = NULL;
-	self->priv->_set_accessor = (__temp25 = (__temp24 = value, (__temp24 == NULL ? NULL : g_object_ref (__temp24))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL))), __temp25);
+	__temp23 = NULL;
+	self->priv->_set_accessor = (__temp24 = (__temp23 = value, (__temp23 == NULL ? NULL : g_object_ref (__temp23))), (self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL))), __temp24);
 }
 
 
@@ -354,12 +341,12 @@ ValaFormalParameter* vala_property_get_this_parameter (ValaProperty* self)
 
 void vala_property_set_this_parameter (ValaProperty* self, ValaFormalParameter* value)
 {
-	ValaFormalParameter* __temp29;
 	ValaFormalParameter* __temp28;
+	ValaFormalParameter* __temp27;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp29 = NULL;
 	__temp28 = NULL;
-	self->priv->_this_parameter = (__temp29 = (__temp28 = value, (__temp28 == NULL ? NULL : g_object_ref (__temp28))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp29);
+	__temp27 = NULL;
+	self->priv->_this_parameter = (__temp28 = (__temp27 = value, (__temp27 == NULL ? NULL : g_object_ref (__temp27))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), __temp28);
 }
 
 
@@ -456,12 +443,12 @@ ValaProperty* vala_property_get_base_interface_property (ValaProperty* self)
 
 void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value)
 {
-	ValaProperty* __temp38;
 	ValaProperty* __temp37;
+	ValaProperty* __temp36;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	__temp38 = NULL;
 	__temp37 = NULL;
-	self->priv->_base_interface_property = (__temp38 = (__temp37 = value, (__temp37 == NULL ? NULL : g_object_ref (__temp37))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), __temp38);
+	__temp36 = NULL;
+	self->priv->_base_interface_property = (__temp37 = (__temp36 = value, (__temp36 == NULL ? NULL : g_object_ref (__temp36))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), __temp37);
 }
 
 
@@ -470,9 +457,6 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 	ValaProperty * self;
 	self = VALA_PROPERTY (object);
 	switch (property_id) {
-		case VALA_PROPERTY_NAME:
-		g_value_set_string (value, vala_property_get_name (self));
-		break;
 		case VALA_PROPERTY_TYPE_REFERENCE:
 		g_value_set_object (value, vala_property_get_type_reference (self));
 		break;
@@ -518,9 +502,6 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 	ValaProperty * self;
 	self = VALA_PROPERTY (object);
 	switch (property_id) {
-		case VALA_PROPERTY_NAME:
-		vala_property_set_name (self, g_value_get_string (value));
-		break;
 		case VALA_PROPERTY_TYPE_REFERENCE:
 		vala_property_set_type_reference (self, g_value_get_object (value));
 		break;
@@ -570,7 +551,6 @@ static void vala_property_class_init (ValaPropertyClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_property_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_real_accept_children;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_TYPE_REFERENCE, g_param_spec_object ("type-reference", "foo", "bar", VALA_TYPE_TYPE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_GET_ACCESSOR, g_param_spec_object ("get-accessor", "foo", "bar", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_SET_ACCESSOR, g_param_spec_object ("set-accessor", "foo", "bar", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -607,7 +587,6 @@ static void vala_property_dispose (GObject * obj)
 	ValaPropertyClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_PROPERTY (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
 	(self->priv->_type_reference == NULL ? NULL : (self->priv->_type_reference = (g_object_unref (self->priv->_type_reference), NULL)));
 	(self->priv->_get_accessor == NULL ? NULL : (self->priv->_get_accessor = (g_object_unref (self->priv->_get_accessor), NULL)));
 	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL)));
@@ -619,7 +598,7 @@ static void vala_property_dispose (GObject * obj)
 }
 
 
-GType vala_property_get_type ()
+GType vala_property_get_type (void)
 {
 	static GType vala_property_type_id = 0;
 	if (G_UNLIKELY (vala_property_type_id == 0)) {
