@@ -22,7 +22,6 @@
 
 #ifndef __VALAREFERENCETRANSFEREXPRESSION_H__
 #define __VALAREFERENCETRANSFEREXPRESSION_H__
-typedef struct _ValaReferenceTransferExpressionPrivate ValaReferenceTransferExpressionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_REFERENCE_TRANSFER_EXPRESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION))
 #define VALA_REFERENCE_TRANSFER_EXPRESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_REFERENCE_TRANSFER_EXPRESSION, ValaReferenceTransferExpressionClass))
 
+typedef struct _ValaReferenceTransferExpressionPrivate ValaReferenceTransferExpressionPrivate;
 
 /**
  * Represents a reference transfer expression in the source code, e.g. `#foo'.
@@ -54,7 +54,7 @@ struct _ValaReferenceTransferExpressionClass {
 ValaReferenceTransferExpression* vala_reference_transfer_expression_new (ValaExpression* inner, ValaSourceReference* source_reference);
 ValaExpression* vala_reference_transfer_expression_get_inner (ValaReferenceTransferExpression* self);
 void vala_reference_transfer_expression_set_inner (ValaReferenceTransferExpression* self, ValaExpression* value);
-GType vala_reference_transfer_expression_get_type ();
+GType vala_reference_transfer_expression_get_type (void);
 
 G_END_DECLS
 
