@@ -1,6 +1,6 @@
 /* valareturnstatement.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valareturnstatement.h"
 #include <vala/valaexpression.h>
@@ -39,6 +37,7 @@ enum  {
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node);
 static gpointer vala_return_statement_parent_class = NULL;
+static ValaStatementIface* vala_return_statement_vala_statement_parent_iface = NULL;
 static void vala_return_statement_dispose (GObject * obj);
 
 
@@ -51,16 +50,12 @@ static void vala_return_statement_dispose (GObject * obj);
  */
 ValaReturnStatement* vala_return_statement_new (ValaExpression* result, ValaSourceReference* source)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaReturnStatement * self;
 	g_return_val_if_fail (result == NULL || VALA_IS_EXPRESSION (result), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "return-expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, result), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, 0, NULL);
+	vala_return_statement_set_return_expression (self, result);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -68,7 +63,7 @@ ValaReturnStatement* vala_return_statement_new (ValaExpression* result, ValaSour
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (base);
+	self = ((ValaReturnStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_begin_return_statement (visitor, self);
 	if (vala_return_statement_get_return_expression (self) != NULL) {
@@ -82,11 +77,11 @@ static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_return_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaReturnStatement * self;
-	self = VALA_RETURN_STATEMENT (base);
+	self = ((ValaReturnStatement*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)) == old_node) {
-		(vala_return_statement_set_return_expression (self, VALA_EXPRESSION (new_node)), vala_return_statement_get_return_expression (self));
+		vala_return_statement_set_return_expression (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -107,7 +102,7 @@ void vala_return_statement_set_return_expression (ValaReturnStatement* self, Val
 	__temp1 = NULL;
 	self->priv->_return_expression = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_return_expression == NULL ? NULL : (self->priv->_return_expression = (g_object_unref (self->priv->_return_expression), NULL))), __temp2);
 	if (self->priv->_return_expression != NULL) {
-		(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_expression), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_return_expression)));
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_return_expression), VALA_CODE_NODE (self));
 	}
 }
 
@@ -149,6 +144,12 @@ static void vala_return_statement_class_init (ValaReturnStatementClass * klass)
 }
 
 
+static void vala_return_statement_vala_statement_interface_init (ValaStatementIface * iface)
+{
+	vala_return_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
+}
+
+
 static void vala_return_statement_init (ValaReturnStatement * self)
 {
 	self->priv = VALA_RETURN_STATEMENT_GET_PRIVATE (self);
@@ -168,12 +169,14 @@ static void vala_return_statement_dispose (GObject * obj)
 }
 
 
-GType vala_return_statement_get_type ()
+GType vala_return_statement_get_type (void)
 {
 	static GType vala_return_statement_type_id = 0;
 	if (G_UNLIKELY (vala_return_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_init };
-		vala_return_statement_type_id = g_type_register_static (VALA_TYPE_STATEMENT, "ValaReturnStatement", &g_define_type_info, 0);
+		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_return_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
+		vala_return_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaReturnStatement", &g_define_type_info, 0);
+		g_type_add_interface_static (vala_return_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
 	}
 	return vala_return_statement_type_id;
 }
