@@ -1,6 +1,6 @@
 /* valasourcefilecycle.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2007  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,10 +19,9 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valasourcefilecycle.h"
+#include <gee/arraylist.h>
 
 enum  {
 	VALA_SOURCE_FILE_CYCLE_DUMMY_PROPERTY
@@ -40,6 +39,7 @@ static void vala_source_file_cycle_class_init (ValaSourceFileCycleClass * klass)
 
 static void vala_source_file_cycle_init (ValaSourceFileCycle * self)
 {
+	self->files = GEE_LIST (gee_array_list_new (NULL, NULL, g_direct_equal));
 }
 
 
@@ -49,14 +49,14 @@ static void vala_source_file_cycle_dispose (GObject * obj)
 	ValaSourceFileCycleClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_SOURCE_FILE_CYCLE (obj);
-	(self->files == NULL ? NULL : (self->files = (g_list_free (self->files), NULL)));
+	(self->files == NULL ? NULL : (self->files = (g_object_unref (self->files), NULL)));
 	klass = VALA_SOURCE_FILE_CYCLE_CLASS (g_type_class_peek (VALA_TYPE_SOURCE_FILE_CYCLE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_source_file_cycle_get_type ()
+GType vala_source_file_cycle_get_type (void)
 {
 	static GType vala_source_file_cycle_type_id = 0;
 	if (G_UNLIKELY (vala_source_file_cycle_type_id == 0)) {
