@@ -19,29 +19,32 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valastruct.h"
+#include <gee/arraylist.h>
+#include <gee/list.h>
+#include <gee/readonlycollection.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
+#include <vala/valasymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valastruct.h>
+#include <vala/valascope.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
+#include <vala/valaformalparameter.h>
+#include <vala/valatypereference.h>
+#include <vala/valacreationmethod.h>
 #include <vala/valacodevisitor.h>
-#include <vala/valanamespace.h>
 #include <vala/valaattribute.h>
 #include <vala/valareport.h>
-#include <vala/valasymbol.h>
-#include <vala/valatypereference.h>
 
 struct _ValaStructPrivate {
-	GList* type_parameters;
-	GList* constants;
-	GList* fields;
-	GList* methods;
-	GList* base_types;
+	GeeList* type_parameters;
+	GeeList* constants;
+	GeeList* fields;
+	GeeList* methods;
+	GeeList* base_types;
 	char* cname;
 	char* const_cname;
 	char* dup_function;
@@ -69,9 +72,9 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type);
 static void vala_struct_set_cname (ValaStruct* self, const char* cname);
 static void vala_struct_set_const_cname (ValaStruct* self, const char* cname);
-static char* vala_struct_real_get_lower_case_cprefix (ValaDataType* base);
+static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base);
 static char* vala_struct_get_lower_case_csuffix (ValaStruct* self);
-static char* vala_struct_real_get_lower_case_cname (ValaDataType* base, const char* infix);
+static char* vala_struct_real_get_lower_case_cname (ValaSymbol* base, const char* infix);
 static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix);
 static gboolean vala_struct_real_is_reference_type (ValaDataType* base);
 static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute* a);
@@ -99,22 +102,18 @@ static void vala_struct_dispose (GObject * obj);
 /**
  * Creates a new struct.
  *
- * @param name   type name
- * @param source reference to source code
- * @return       newly created struct
+ * @param name             type name
+ * @param source_reference reference to source code
+ * @return                 newly created struct
  */
-ValaStruct* vala_struct_new (const char* _name, ValaSourceReference* source)
+ValaStruct* vala_struct_new (const char* name, ValaSourceReference* source_reference)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaStruct * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 2);
-	__params_it = __params;
-	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_STRUCT, __params_it - __params, __params);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	self = g_object_newv (VALA_TYPE_STRUCT, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -128,8 +127,9 @@ void vala_struct_add_type_parameter (ValaStruct* self, ValaTypeParameter* p)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_TYPE_PARAMETER (p));
-	self->priv->type_parameters = g_list_append (self->priv->type_parameters, g_object_ref (p));
+	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_DATA_TYPE (self);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) p)), VALA_SYMBOL (p));
 }
 
 
@@ -142,7 +142,8 @@ void vala_struct_add_constant (ValaStruct* self, ValaConstant* c)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_CONSTANT (c));
-	self->priv->constants = g_list_append (self->priv->constants, g_object_ref (c));
+	gee_collection_add (GEE_COLLECTION (self->priv->constants), c);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) c)), VALA_SYMBOL (c));
 }
 
 
@@ -155,7 +156,8 @@ void vala_struct_add_field (ValaStruct* self, ValaField* f)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_FIELD (f));
-	self->priv->fields = g_list_append (self->priv->fields, g_object_ref (f));
+	gee_collection_add (GEE_COLLECTION (self->priv->fields), f);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) f)), VALA_SYMBOL (f));
 }
 
 
@@ -164,10 +166,10 @@ void vala_struct_add_field (ValaStruct* self, ValaField* f)
  *
  * @return list of fields
  */
-GList* vala_struct_get_fields (ValaStruct* self)
+GeeCollection* vala_struct_get_fields (ValaStruct* self)
 {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return g_list_copy (self->priv->fields);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->fields)));
 }
 
 
@@ -181,7 +183,22 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m)
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_METHOD (m));
 	g_return_if_fail (m != NULL);
-	self->priv->methods = g_list_append (self->priv->methods, g_object_ref (m));
+	if (vala_method_get_instance (m)) {
+		ValaFormalParameter* __temp2;
+		ValaTypeReference* __temp1;
+		__temp2 = NULL;
+		__temp1 = NULL;
+		vala_method_set_this_parameter (m, (__temp2 = vala_formal_parameter_new ("this", (__temp1 = vala_type_reference_new ()), NULL)));
+		(__temp2 == NULL ? NULL : (__temp2 = (g_object_unref (__temp2), NULL)));
+		(__temp1 == NULL ? NULL : (__temp1 = (g_object_unref (__temp1), NULL)));
+		vala_type_reference_set_data_type (vala_formal_parameter_get_type_reference (vala_method_get_this_parameter (m)), VALA_DATA_TYPE (self));
+		vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) m)), vala_symbol_get_name (((ValaSymbol*) vala_method_get_this_parameter (m))), VALA_SYMBOL (vala_method_get_this_parameter (m)));
+	}
+	if (VALA_IS_CREATION_METHOD (m) && vala_symbol_get_name (((ValaSymbol*) m)) == NULL) {
+		vala_struct_set_default_construction_method (self, m);
+	}
+	gee_collection_add (GEE_COLLECTION (self->priv->methods), m);
+	vala_scope_add (vala_symbol_get_scope (((ValaSymbol*) self)), vala_symbol_get_name (((ValaSymbol*) m)), VALA_SYMBOL (m));
 }
 
 
@@ -190,17 +207,17 @@ void vala_struct_add_method (ValaStruct* self, ValaMethod* m)
  *
  * @return list of methods
  */
-GList* vala_struct_get_methods (ValaStruct* self)
+GeeCollection* vala_struct_get_methods (ValaStruct* self)
 {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return g_list_copy (self->priv->methods);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->methods)));
 }
 
 
 static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_struct (visitor, self);
 }
@@ -209,59 +226,67 @@ static void vala_struct_real_accept (ValaCodeNode* base, ValaCodeVisitor* visito
 static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GList* __temp2;
-		GList* p_it;
-		__temp2 = NULL;
-		__temp2 = self->priv->type_parameters;
-		for (p_it = __temp2; p_it != NULL; p_it = p_it->next) {
+		GeeList* p_collection;
+		GeeIterator* p_it;
+		p_collection = self->priv->type_parameters;
+		p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
+		while (gee_iterator_next (p_it)) {
 			ValaTypeParameter* p;
-			p = p_it->data;
+			p = gee_iterator_get (p_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
+				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 			}
 		}
+		(p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL)));
 	}
 	{
-		GList* __temp3;
-		GList* f_it;
-		__temp3 = NULL;
-		__temp3 = self->priv->fields;
-		for (f_it = __temp3; f_it != NULL; f_it = f_it->next) {
+		GeeList* f_collection;
+		GeeIterator* f_it;
+		f_collection = self->priv->fields;
+		f_it = gee_iterable_iterator (GEE_ITERABLE (f_collection));
+		while (gee_iterator_next (f_it)) {
 			ValaField* f;
-			f = f_it->data;
+			f = gee_iterator_get (f_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (f), visitor);
+				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
 			}
 		}
+		(f_it == NULL ? NULL : (f_it = (g_object_unref (f_it), NULL)));
 	}
 	{
-		GList* __temp4;
-		GList* c_it;
-		__temp4 = NULL;
-		__temp4 = self->priv->constants;
-		for (c_it = __temp4; c_it != NULL; c_it = c_it->next) {
+		GeeList* c_collection;
+		GeeIterator* c_it;
+		c_collection = self->priv->constants;
+		c_it = gee_iterable_iterator (GEE_ITERABLE (c_collection));
+		while (gee_iterator_next (c_it)) {
 			ValaConstant* c;
-			c = c_it->data;
+			c = gee_iterator_get (c_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (c), visitor);
+				(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
 			}
 		}
+		(c_it == NULL ? NULL : (c_it = (g_object_unref (c_it), NULL)));
 	}
 	{
-		GList* __temp5;
-		GList* m_it;
-		__temp5 = NULL;
-		__temp5 = self->priv->methods;
-		for (m_it = __temp5; m_it != NULL; m_it = m_it->next) {
+		GeeList* m_collection;
+		GeeIterator* m_it;
+		m_collection = self->priv->methods;
+		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
+		while (gee_iterator_next (m_it)) {
 			ValaMethod* m;
-			m = m_it->data;
+			m = gee_iterator_get (m_it);
 			{
 				vala_code_node_accept (VALA_CODE_NODE (m), visitor);
+				(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 			}
 		}
+		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
 	}
 }
 
@@ -269,111 +294,111 @@ static void vala_struct_real_accept_children (ValaCodeNode* base, ValaCodeVisito
 static char* vala_struct_real_get_cname (ValaDataType* base, gboolean const_type)
 {
 	ValaStruct * self;
-	const char* __temp10;
-	self = VALA_STRUCT (base);
+	const char* __temp8;
+	self = ((ValaStruct*) base);
 	if (const_type && self->priv->const_cname != NULL) {
-		const char* __temp6;
-		__temp6 = NULL;
-		return (__temp6 = self->priv->const_cname, (__temp6 == NULL ? NULL : g_strdup (__temp6)));
+		const char* __temp4;
+		__temp4 = NULL;
+		return (__temp4 = self->priv->const_cname, (__temp4 == NULL ? NULL : g_strdup (__temp4)));
 	}
 	if (self->priv->cname == NULL) {
-		char* __temp9;
-		char* __temp8;
-		__temp9 = NULL;
-		__temp8 = NULL;
-		self->priv->cname = (__temp9 = g_strdup_printf ("%s%s", (__temp8 = vala_namespace_get_cprefix (VALA_DATA_TYPE (self)->namespace)), vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp9);
-		(__temp8 = (g_free (__temp8), NULL));
+		char* __temp7;
+		char* __temp6;
+		__temp7 = NULL;
+		__temp6 = NULL;
+		self->priv->cname = (__temp7 = g_strdup_printf ("%s%s", (__temp6 = vala_symbol_get_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp7);
+		(__temp6 = (g_free (__temp6), NULL));
 	}
-	__temp10 = NULL;
-	return (__temp10 = self->priv->cname, (__temp10 == NULL ? NULL : g_strdup (__temp10)));
+	__temp8 = NULL;
+	return (__temp8 = self->priv->cname, (__temp8 == NULL ? NULL : g_strdup (__temp8)));
 }
 
 
 static void vala_struct_set_cname (ValaStruct* self, const char* cname)
 {
-	char* __temp12;
+	char* __temp10;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
-	__temp12 = NULL;
-	self->priv->cname = (__temp12 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp12);
+	__temp10 = NULL;
+	self->priv->cname = (__temp10 = g_strdup (cname), (self->priv->cname = (g_free (self->priv->cname), NULL)), __temp10);
 }
 
 
 static void vala_struct_set_const_cname (ValaStruct* self, const char* cname)
 {
-	char* __temp13;
+	char* __temp11;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (cname != NULL);
-	__temp13 = NULL;
-	self->priv->const_cname = (__temp13 = g_strdup (cname), (self->priv->const_cname = (g_free (self->priv->const_cname), NULL)), __temp13);
+	__temp11 = NULL;
+	self->priv->const_cname = (__temp11 = g_strdup (cname), (self->priv->const_cname = (g_free (self->priv->const_cname), NULL)), __temp11);
 }
 
 
-static char* vala_struct_real_get_lower_case_cprefix (ValaDataType* base)
+static char* vala_struct_real_get_lower_case_cprefix (ValaSymbol* base)
 {
 	ValaStruct * self;
-	const char* __temp16;
-	self = VALA_STRUCT (base);
+	const char* __temp14;
+	self = ((ValaStruct*) base);
 	if (self->priv->lower_case_cprefix == NULL) {
-		char* __temp15;
-		char* __temp14;
-		__temp15 = NULL;
-		__temp14 = NULL;
-		self->priv->lower_case_cprefix = (__temp15 = g_strdup_printf ("%s_", (__temp14 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp15);
-		(__temp14 = (g_free (__temp14), NULL));
+		char* __temp13;
+		char* __temp12;
+		__temp13 = NULL;
+		__temp12 = NULL;
+		self->priv->lower_case_cprefix = (__temp13 = g_strdup_printf ("%s_", (__temp12 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), NULL))), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp13);
+		(__temp12 = (g_free (__temp12), NULL));
 	}
-	__temp16 = NULL;
-	return (__temp16 = self->priv->lower_case_cprefix, (__temp16 == NULL ? NULL : g_strdup (__temp16)));
+	__temp14 = NULL;
+	return (__temp14 = self->priv->lower_case_cprefix, (__temp14 == NULL ? NULL : g_strdup (__temp14)));
 }
 
 
 static char* vala_struct_get_lower_case_csuffix (ValaStruct* self)
 {
-	const char* __temp19;
+	const char* __temp17;
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
 	if (self->priv->lower_case_csuffix == NULL) {
-		char* __temp18;
-		__temp18 = NULL;
-		self->priv->lower_case_csuffix = (__temp18 = vala_namespace_camel_case_to_lower_case (vala_data_type_get_name (VALA_DATA_TYPE (self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp18);
+		char* __temp16;
+		__temp16 = NULL;
+		self->priv->lower_case_csuffix = (__temp16 = vala_symbol_camel_case_to_lower_case (vala_symbol_get_name (((ValaSymbol*) self))), (self->priv->lower_case_csuffix = (g_free (self->priv->lower_case_csuffix), NULL)), __temp16);
 	}
-	__temp19 = NULL;
-	return (__temp19 = self->priv->lower_case_csuffix, (__temp19 == NULL ? NULL : g_strdup (__temp19)));
+	__temp17 = NULL;
+	return (__temp17 = self->priv->lower_case_csuffix, (__temp17 == NULL ? NULL : g_strdup (__temp17)));
 }
 
 
-static char* vala_struct_real_get_lower_case_cname (ValaDataType* base, const char* infix)
+static char* vala_struct_real_get_lower_case_cname (ValaSymbol* base, const char* infix)
 {
 	ValaStruct * self;
-	char* __temp22;
+	char* __temp20;
+	char* __temp19;
 	char* __temp21;
-	char* __temp23;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (infix == NULL) {
 		infix = "";
 	}
-	__temp22 = NULL;
+	__temp20 = NULL;
+	__temp19 = NULL;
 	__temp21 = NULL;
-	__temp23 = NULL;
-	return (__temp23 = g_strdup_printf ("%s%s%s", (__temp21 = vala_namespace_get_lower_case_cprefix (VALA_DATA_TYPE (self)->namespace)), infix, (__temp22 = vala_struct_get_lower_case_csuffix (self))), (__temp22 = (g_free (__temp22), NULL)), (__temp21 = (g_free (__temp21), NULL)), __temp23);
+	return (__temp21 = g_strdup_printf ("%s%s%s", (__temp19 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (((ValaSymbol*) self)))), infix, (__temp20 = vala_struct_get_lower_case_csuffix (self))), (__temp20 = (g_free (__temp20), NULL)), (__temp19 = (g_free (__temp19), NULL)), __temp21);
 }
 
 
 static char* vala_struct_real_get_upper_case_cname (ValaDataType* base, const char* infix)
 {
 	ValaStruct * self;
-	char* __temp25;
-	char* __temp26;
-	self = VALA_STRUCT (base);
-	__temp25 = NULL;
-	__temp26 = NULL;
-	return (__temp26 = g_utf8_strup ((__temp25 = vala_data_type_get_lower_case_cname (VALA_DATA_TYPE (self), infix)), -1), (__temp25 = (g_free (__temp25), NULL)), __temp26);
+	char* __temp23;
+	char* __temp24;
+	self = ((ValaStruct*) base);
+	__temp23 = NULL;
+	__temp24 = NULL;
+	return (__temp24 = g_utf8_strup ((__temp23 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self), infix)), -1), (__temp23 = (g_free (__temp23), NULL)), __temp24);
 }
 
 
 static gboolean vala_struct_real_is_reference_type (ValaDataType* base)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	return self->priv->reference_type;
 }
 
@@ -431,70 +456,72 @@ static void vala_struct_process_ccode_attribute (ValaStruct* self, ValaAttribute
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
-		char* __temp32;
-		__temp32 = NULL;
-		vala_struct_set_cname (self, (__temp32 = vala_attribute_get_string (a, "cname")));
-		(__temp32 = (g_free (__temp32), NULL));
+		char* __temp30;
+		__temp30 = NULL;
+		vala_struct_set_cname (self, (__temp30 = vala_attribute_get_string (a, "cname")));
+		(__temp30 = (g_free (__temp30), NULL));
 	}
 	if (vala_attribute_has_argument (a, "const_cname")) {
-		char* __temp33;
-		__temp33 = NULL;
-		vala_struct_set_const_cname (self, (__temp33 = vala_attribute_get_string (a, "const_cname")));
-		(__temp33 = (g_free (__temp33), NULL));
+		char* __temp31;
+		__temp31 = NULL;
+		vala_struct_set_const_cname (self, (__temp31 = vala_attribute_get_string (a, "const_cname")));
+		(__temp31 = (g_free (__temp31), NULL));
 	}
 	if (vala_attribute_has_argument (a, "cprefix")) {
-		char* __temp34;
-		__temp34 = NULL;
-		self->priv->lower_case_cprefix = (__temp34 = vala_attribute_get_string (a, "cprefix"), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp34);
+		char* __temp32;
+		__temp32 = NULL;
+		self->priv->lower_case_cprefix = (__temp32 = vala_attribute_get_string (a, "cprefix"), (self->priv->lower_case_cprefix = (g_free (self->priv->lower_case_cprefix), NULL)), __temp32);
 	}
 	if (vala_attribute_has_argument (a, "cheader_filename")) {
 		char* val;
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
-			char** __temp35;
+			char** filename_collection;
 			char** filename_it;
-			__temp35 = NULL;
-			__temp35 = g_strsplit (val, ",", 0);
-			for (filename_it = __temp35; *filename_it != NULL; filename_it = filename_it + 1) {
+			filename_collection = g_strsplit (val, ",", 0);
+			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
+				const char* __temp33;
 				char* filename;
-				filename = *filename_it;
+				__temp33 = NULL;
+				filename = (__temp33 = *filename_it, (__temp33 == NULL ? NULL : g_strdup (__temp33)));
 				{
 					vala_data_type_add_cheader_filename (VALA_DATA_TYPE (self), filename);
+					(filename = (g_free (filename), NULL));
 				}
 			}
-			(__temp35 = (g_free (__temp35), NULL));
+			(filename_collection = (g_strfreev (filename_collection), NULL));
 		}
 		(val = (g_free (val), NULL));
 	}
 	if (vala_attribute_has_argument (a, "type_id")) {
-		char* __temp36;
-		__temp36 = NULL;
-		vala_struct_set_type_id (self, (__temp36 = vala_attribute_get_string (a, "type_id")));
-		(__temp36 = (g_free (__temp36), NULL));
+		char* __temp34;
+		__temp34 = NULL;
+		vala_struct_set_type_id (self, (__temp34 = vala_attribute_get_string (a, "type_id")));
+		(__temp34 = (g_free (__temp34), NULL));
 	}
 	if (vala_attribute_has_argument (a, "marshaller_type_name")) {
-		char* __temp37;
-		__temp37 = NULL;
-		vala_struct_set_marshaller_type_name (self, (__temp37 = vala_attribute_get_string (a, "marshaller_type_name")));
-		(__temp37 = (g_free (__temp37), NULL));
+		char* __temp35;
+		__temp35 = NULL;
+		vala_struct_set_marshaller_type_name (self, (__temp35 = vala_attribute_get_string (a, "marshaller_type_name")));
+		(__temp35 = (g_free (__temp35), NULL));
 	}
 	if (vala_attribute_has_argument (a, "get_value_function")) {
-		char* __temp38;
-		__temp38 = NULL;
-		vala_struct_set_get_value_function (self, (__temp38 = vala_attribute_get_string (a, "get_value_function")));
-		(__temp38 = (g_free (__temp38), NULL));
+		char* __temp36;
+		__temp36 = NULL;
+		vala_struct_set_get_value_function (self, (__temp36 = vala_attribute_get_string (a, "get_value_function")));
+		(__temp36 = (g_free (__temp36), NULL));
 	}
 	if (vala_attribute_has_argument (a, "set_value_function")) {
-		char* __temp39;
-		__temp39 = NULL;
-		vala_struct_set_set_value_function (self, (__temp39 = vala_attribute_get_string (a, "set_value_function")));
-		(__temp39 = (g_free (__temp39), NULL));
+		char* __temp37;
+		__temp37 = NULL;
+		vala_struct_set_set_value_function (self, (__temp37 = vala_attribute_get_string (a, "set_value_function")));
+		(__temp37 = (g_free (__temp37), NULL));
 	}
 	if (vala_attribute_has_argument (a, "default_value")) {
-		char* __temp40;
-		__temp40 = NULL;
-		vala_struct_set_default_value (self, (__temp40 = vala_attribute_get_string (a, "default_value")));
-		(__temp40 = (g_free (__temp40), NULL));
+		char* __temp38;
+		__temp38 = NULL;
+		vala_struct_set_default_value (self, (__temp38 = vala_attribute_get_string (a, "default_value")));
+		(__temp38 = (g_free (__temp38), NULL));
 	}
 }
 
@@ -505,16 +532,16 @@ static void vala_struct_process_ref_type_attribute (ValaStruct* self, ValaAttrib
 	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	self->priv->reference_type = TRUE;
 	if (vala_attribute_has_argument (a, "dup_function")) {
-		char* __temp41;
-		__temp41 = NULL;
-		vala_struct_set_dup_function (self, (__temp41 = vala_attribute_get_string (a, "dup_function")));
-		(__temp41 = (g_free (__temp41), NULL));
+		char* __temp39;
+		__temp39 = NULL;
+		vala_struct_set_dup_function (self, (__temp39 = vala_attribute_get_string (a, "dup_function")));
+		(__temp39 = (g_free (__temp39), NULL));
 	}
 	if (vala_attribute_has_argument (a, "free_function")) {
-		char* __temp42;
-		__temp42 = NULL;
-		vala_struct_set_free_function (self, (__temp42 = vala_attribute_get_string (a, "free_function")));
-		(__temp42 = (g_free (__temp42), NULL));
+		char* __temp40;
+		__temp40 = NULL;
+		vala_struct_set_free_function (self, (__temp40 = vala_attribute_get_string (a, "free_function")));
+		(__temp40 = (g_free (__temp40), NULL));
 	}
 }
 
@@ -548,13 +575,14 @@ void vala_struct_process_attributes (ValaStruct* self)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	{
-		GList* __temp43;
+		GList* a_collection;
 		GList* a_it;
-		__temp43 = NULL;
-		__temp43 = VALA_CODE_NODE (self)->attributes;
-		for (a_it = __temp43; a_it != NULL; a_it = a_it->next) {
+		a_collection = ((ValaCodeNode*) self)->attributes;
+		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
+			ValaAttribute* __temp41;
 			ValaAttribute* a;
-			a = a_it->data;
+			__temp41 = NULL;
+			a = (__temp41 = a_it->data, (__temp41 == NULL ? NULL : g_object_ref (__temp41)));
 			{
 				if (g_utf8_collate (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_struct_process_ccode_attribute (self, a);
@@ -571,6 +599,7 @@ void vala_struct_process_attributes (ValaStruct* self)
 						}
 					}
 				}
+				(a == NULL ? NULL : (a = (g_object_unref (a), NULL)));
 			}
 		}
 	}
@@ -580,7 +609,7 @@ void vala_struct_process_attributes (ValaStruct* self)
 static gboolean vala_struct_real_is_reference_counting (ValaDataType* base)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	return FALSE;
 }
 
@@ -588,29 +617,29 @@ static gboolean vala_struct_real_is_reference_counting (ValaDataType* base)
 static char* vala_struct_real_get_dup_function (ValaDataType* base)
 {
 	ValaStruct * self;
-	const char* __temp47;
-	self = VALA_STRUCT (base);
+	const char* __temp45;
+	self = ((ValaStruct*) base);
 	if (self->priv->dup_function == NULL) {
-		char* __temp46;
-		char* __temp45;
-		__temp46 = NULL;
-		__temp45 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp46 = g_strdup_printf ("The type `%s` doesn't contain a copy function", (__temp45 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-		(__temp46 = (g_free (__temp46), NULL));
-		(__temp45 = (g_free (__temp45), NULL));
+		char* __temp44;
+		char* __temp43;
+		__temp44 = NULL;
+		__temp43 = NULL;
+		vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp44 = g_strdup_printf ("The type `%s` doesn't contain a copy function", (__temp43 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+		(__temp44 = (g_free (__temp44), NULL));
+		(__temp43 = (g_free (__temp43), NULL));
 	}
-	__temp47 = NULL;
-	return (__temp47 = self->priv->dup_function, (__temp47 == NULL ? NULL : g_strdup (__temp47)));
+	__temp45 = NULL;
+	return (__temp45 = self->priv->dup_function, (__temp45 == NULL ? NULL : g_strdup (__temp45)));
 }
 
 
 void vala_struct_set_dup_function (ValaStruct* self, const char* name)
 {
-	char* __temp49;
+	char* __temp47;
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (name != NULL);
-	__temp49 = NULL;
-	self->priv->dup_function = (__temp49 = g_strdup (name), (self->priv->dup_function = (g_free (self->priv->dup_function), NULL)), __temp49);
+	__temp47 = NULL;
+	self->priv->dup_function = (__temp47 = g_strdup (name), (self->priv->dup_function = (g_free (self->priv->dup_function), NULL)), __temp47);
 }
 
 
@@ -618,15 +647,24 @@ static char* vala_struct_real_get_free_function (ValaDataType* base)
 {
 	ValaStruct * self;
 	const char* __temp52;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (self->priv->free_function == NULL) {
-		char* __temp51;
-		char* __temp50;
-		__temp51 = NULL;
-		__temp50 = NULL;
-		vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp51 = g_strdup_printf ("The type `%s` doesn't contain a free function", (__temp50 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
-		(__temp51 = (g_free (__temp51), NULL));
-		(__temp50 = (g_free (__temp50), NULL));
+		if (vala_struct_get_default_construction_method (self) != NULL) {
+			char* __temp49;
+			char* __temp48;
+			__temp49 = NULL;
+			__temp48 = NULL;
+			self->priv->free_function = (__temp49 = g_strconcat ((__temp48 = vala_symbol_get_lower_case_cprefix (VALA_SYMBOL (self))), "free", NULL), (self->priv->free_function = (g_free (self->priv->free_function), NULL)), __temp49);
+			(__temp48 = (g_free (__temp48), NULL));
+		} else {
+			char* __temp51;
+			char* __temp50;
+			__temp51 = NULL;
+			__temp50 = NULL;
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp51 = g_strdup_printf ("The type `%s` doesn't contain a free function", (__temp50 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
+			(__temp51 = (g_free (__temp51), NULL));
+			(__temp50 = (g_free (__temp50), NULL));
+		}
 	}
 	__temp52 = NULL;
 	return (__temp52 = self->priv->free_function, (__temp52 == NULL ? NULL : g_strdup (__temp52)));
@@ -647,7 +685,7 @@ static char* vala_struct_real_get_type_id (ValaDataType* base)
 {
 	ValaStruct * self;
 	const char* __temp58;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (self->priv->type_id == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			char* __temp55;
@@ -658,7 +696,7 @@ static char* vala_struct_real_get_type_id (ValaDataType* base)
 			char* __temp56;
 			__temp57 = NULL;
 			__temp56 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp57 = g_strdup_printf ("The type `%s` doesn't declare a type id", (__temp56 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp57 = g_strdup_printf ("The type `%s` doesn't declare a type id", (__temp56 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 			(__temp57 = (g_free (__temp57), NULL));
 			(__temp56 = (g_free (__temp56), NULL));
 		}
@@ -682,7 +720,7 @@ static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base)
 {
 	ValaStruct * self;
 	const char* __temp64;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (self->priv->marshaller_type_name == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			char* __temp61;
@@ -693,7 +731,7 @@ static char* vala_struct_real_get_marshaller_type_name (ValaDataType* base)
 			char* __temp62;
 			__temp63 = NULL;
 			__temp62 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp63 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (__temp62 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp63 = g_strdup_printf ("The type `%s` doesn't declare a marshaller type name", (__temp62 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 			(__temp63 = (g_free (__temp63), NULL));
 			(__temp62 = (g_free (__temp62), NULL));
 		}
@@ -716,7 +754,7 @@ static void vala_struct_set_marshaller_type_name (ValaStruct* self, const char*
 static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (self->priv->get_value_function == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			return g_strdup ("g_value_get_pointer");
@@ -725,7 +763,7 @@ static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 			char* __temp68;
 			__temp69 = NULL;
 			__temp68 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp69 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (__temp68 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp69 = g_strdup_printf ("The value type `%s` doesn't declare a GValue get function", (__temp68 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 			(__temp69 = (g_free (__temp69), NULL));
 			(__temp68 = (g_free (__temp68), NULL));
 			return NULL;
@@ -741,7 +779,7 @@ static char* vala_struct_real_get_get_value_function (ValaDataType* base)
 static char* vala_struct_real_get_set_value_function (ValaDataType* base)
 {
 	ValaStruct * self;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	if (self->priv->set_value_function == NULL) {
 		if (vala_data_type_is_reference_type (VALA_DATA_TYPE (self))) {
 			return g_strdup ("g_value_set_pointer");
@@ -750,7 +788,7 @@ static char* vala_struct_real_get_set_value_function (ValaDataType* base)
 			char* __temp74;
 			__temp75 = NULL;
 			__temp74 = NULL;
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (__temp75 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (__temp74 = vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (self)))))));
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), (__temp75 = g_strdup_printf ("The value type `%s` doesn't declare a GValue set function", (__temp74 = vala_symbol_get_full_name (VALA_SYMBOL (self))))));
 			(__temp75 = (g_free (__temp75), NULL));
 			(__temp74 = (g_free (__temp74), NULL));
 			return NULL;
@@ -787,7 +825,7 @@ static char* vala_struct_real_get_default_value (ValaDataType* base)
 {
 	ValaStruct * self;
 	const char* __temp81;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	__temp81 = NULL;
 	return (__temp81 = self->priv->default_value, (__temp81 == NULL ? NULL : g_strdup (__temp81)));
 }
@@ -812,7 +850,7 @@ void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type)
 {
 	g_return_if_fail (VALA_IS_STRUCT (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (type));
-	self->priv->base_types = g_list_append (self->priv->base_types, g_object_ref (type));
+	gee_collection_add (GEE_COLLECTION (self->priv->base_types), type);
 }
 
 
@@ -821,10 +859,10 @@ void vala_struct_add_base_type (ValaStruct* self, ValaTypeReference* type)
  *
  * @return list of base types
  */
-GList* vala_struct_get_base_types (ValaStruct* self)
+GeeCollection* vala_struct_get_base_types (ValaStruct* self)
 {
 	g_return_val_if_fail (VALA_IS_STRUCT (self), NULL);
-	return g_list_copy (self->priv->base_types);
+	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->base_types)));
 }
 
 
@@ -832,24 +870,27 @@ static gint vala_struct_real_get_type_parameter_index (ValaDataType* base, const
 {
 	ValaStruct * self;
 	gint i;
-	self = VALA_STRUCT (base);
+	self = ((ValaStruct*) base);
 	g_return_val_if_fail (name != NULL, 0);
 	i = 0;
 	{
-		GList* __temp86;
-		GList* p_it;
-		__temp86 = NULL;
-		__temp86 = self->priv->type_parameters;
-		for (p_it = __temp86; p_it != NULL; p_it = p_it->next) {
+		GeeList* p_collection;
+		GeeIterator* p_it;
+		p_collection = self->priv->type_parameters;
+		p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
+		while (gee_iterator_next (p_it)) {
 			ValaTypeParameter* p;
-			p = p_it->data;
+			p = gee_iterator_get (p_it);
 			{
-				if (g_utf8_collate (vala_type_parameter_get_name (p), name) == 0) {
-					return (i);
+				if (g_utf8_collate (vala_symbol_get_name (((ValaSymbol*) p)), name) == 0) {
+					gint __temp85;
+					return (__temp85 = (i), (p == NULL ? NULL : (p = (g_object_unref (p), NULL))), (p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL))), __temp85);
 				}
 				i++;
+				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 			}
 		}
+		(p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL)));
 	}
 	return -1;
 }
@@ -864,12 +905,12 @@ ValaMethod* vala_struct_get_default_construction_method (ValaStruct* self)
 
 void vala_struct_set_default_construction_method (ValaStruct* self, ValaMethod* value)
 {
-	ValaMethod* __temp90;
 	ValaMethod* __temp89;
+	ValaMethod* __temp88;
 	g_return_if_fail (VALA_IS_STRUCT (self));
-	__temp90 = NULL;
 	__temp89 = NULL;
-	self->priv->_default_construction_method = (__temp90 = (__temp89 = value, (__temp89 == NULL ? NULL : g_object_ref (__temp89))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp90);
+	__temp88 = NULL;
+	self->priv->_default_construction_method = (__temp89 = (__temp88 = value, (__temp88 == NULL ? NULL : g_object_ref (__temp88))), (self->priv->_default_construction_method == NULL ? NULL : (self->priv->_default_construction_method = (g_object_unref (self->priv->_default_construction_method), NULL))), __temp89);
 }
 
 
@@ -907,8 +948,8 @@ static void vala_struct_class_init (ValaStructClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_struct_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_struct_real_accept_children;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_struct_real_get_cname;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cprefix = vala_struct_real_get_lower_case_cprefix;
-	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_struct_real_get_lower_case_cname;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cprefix = vala_struct_real_get_lower_case_cprefix;
+	VALA_SYMBOL_CLASS (klass)->get_lower_case_cname = vala_struct_real_get_lower_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_upper_case_cname = vala_struct_real_get_upper_case_cname;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_type = vala_struct_real_is_reference_type;
 	VALA_DATA_TYPE_CLASS (klass)->is_reference_counting = vala_struct_real_is_reference_counting;
@@ -927,6 +968,11 @@ static void vala_struct_class_init (ValaStructClass * klass)
 static void vala_struct_init (ValaStruct * self)
 {
 	self->priv = VALA_STRUCT_GET_PRIVATE (self);
+	self->priv->type_parameters = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->constants = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->fields = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->base_types = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
 	self->priv->default_value = NULL;
 }
 
@@ -937,11 +983,11 @@ static void vala_struct_dispose (GObject * obj)
 	ValaStructClass * klass;
 	GObjectClass * parent_class;
 	self = VALA_STRUCT (obj);
-	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_list_foreach (self->priv->type_parameters, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_parameters), NULL)));
-	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_list_foreach (self->priv->constants, (GFunc) g_object_unref, NULL), g_list_free (self->priv->constants), NULL)));
-	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_list_foreach (self->priv->fields, (GFunc) g_object_unref, NULL), g_list_free (self->priv->fields), NULL)));
-	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_list_foreach (self->priv->methods, (GFunc) g_object_unref, NULL), g_list_free (self->priv->methods), NULL)));
-	(self->priv->base_types == NULL ? NULL : (self->priv->base_types = (g_list_foreach (self->priv->base_types, (GFunc) g_object_unref, NULL), g_list_free (self->priv->base_types), NULL)));
+	(self->priv->type_parameters == NULL ? NULL : (self->priv->type_parameters = (g_object_unref (self->priv->type_parameters), NULL)));
+	(self->priv->constants == NULL ? NULL : (self->priv->constants = (g_object_unref (self->priv->constants), NULL)));
+	(self->priv->fields == NULL ? NULL : (self->priv->fields = (g_object_unref (self->priv->fields), NULL)));
+	(self->priv->methods == NULL ? NULL : (self->priv->methods = (g_object_unref (self->priv->methods), NULL)));
+	(self->priv->base_types == NULL ? NULL : (self->priv->base_types = (g_object_unref (self->priv->base_types), NULL)));
 	(self->priv->cname = (g_free (self->priv->cname), NULL));
 	(self->priv->const_cname = (g_free (self->priv->const_cname), NULL));
 	(self->priv->dup_function = (g_free (self->priv->dup_function), NULL));
@@ -960,7 +1006,7 @@ static void vala_struct_dispose (GObject * obj)
 }
 
 
-GType vala_struct_get_type ()
+GType vala_struct_get_type (void)
 {
 	static GType vala_struct_type_id = 0;
 	if (G_UNLIKELY (vala_struct_type_id == 0)) {
