@@ -22,10 +22,10 @@
 
 #ifndef __VALASWITCHSECTION_H__
 #define __VALASWITCHSECTION_H__
-typedef struct _ValaSwitchSectionPrivate ValaSwitchSectionPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -38,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_SWITCH_SECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_SECTION))
 #define VALA_SWITCH_SECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionClass))
 
+typedef struct _ValaSwitchSectionPrivate ValaSwitchSectionPrivate;
 
 /**
  * Represents a switch section in the source code.
@@ -50,13 +51,13 @@ struct _ValaSwitchSectionClass {
 	ValaCodeNodeClass parent;
 };
 
-ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source);
+ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label);
-GList* vala_switch_section_get_labels (ValaSwitchSection* self);
+GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self);
 gboolean vala_switch_section_has_default_label (ValaSwitchSection* self);
 void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt);
-GList* vala_switch_section_get_statements (ValaSwitchSection* self);
-GType vala_switch_section_get_type ();
+GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self);
+GType vala_switch_section_get_type (void);
 
 G_END_DECLS
 
