@@ -22,7 +22,6 @@
 
 #ifndef __VALATYPECHECK_H__
 #define __VALATYPECHECK_H__
-typedef struct _ValaTypeCheckPrivate ValaTypeCheckPrivate;
 
 #include <glib.h>
 #include <glib-object.h>
@@ -39,6 +38,7 @@ G_BEGIN_DECLS
 #define VALA_IS_TYPE_CHECK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPE_CHECK))
 #define VALA_TYPE_CHECK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPE_CHECK, ValaTypeCheckClass))
 
+typedef struct _ValaTypeCheckPrivate ValaTypeCheckPrivate;
 
 /**
  * Represents a type check (`is') expression in the source code.
@@ -56,7 +56,7 @@ ValaExpression* vala_type_check_get_expression (ValaTypeCheck* self);
 void vala_type_check_set_expression (ValaTypeCheck* self, ValaExpression* value);
 ValaTypeReference* vala_type_check_get_type_reference (ValaTypeCheck* self);
 void vala_type_check_set_type_reference (ValaTypeCheck* self, ValaTypeReference* value);
-GType vala_type_check_get_type ();
+GType vala_type_check_get_type (void);
 
 G_END_DECLS
 
