@@ -24,10 +24,11 @@
  * 	Jürg Billeter <j@bitron.ch>
  *	Raffaele Sandrini <rasa@gmx.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valatypereference.h"
+#include <gee/arraylist.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valadatatype.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valasourcereference.h>
@@ -54,7 +55,7 @@ struct _ValaTypeReferencePrivate {
 	gint _pointer_level;
 	gboolean _is_ref;
 	gboolean _is_weak;
-	GList* type_argument_list;
+	GeeArrayList* type_argument_list;
 };
 #define VALA_TYPE_REFERENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPE_REFERENCE, ValaTypeReferencePrivate))
 enum  {
@@ -79,14 +80,10 @@ static gpointer vala_type_reference_parent_class = NULL;
 static void vala_type_reference_dispose (GObject * obj);
 
 
-ValaTypeReference* vala_type_reference_new ()
+ValaTypeReference* vala_type_reference_new (void)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaTypeReference * self;
-	__params = g_new0 (GParameter, 0);
-	__params_it = __params;
-	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, 0, NULL);
 	return self;
 }
 
@@ -101,17 +98,13 @@ ValaTypeReference* vala_type_reference_new ()
  */
 ValaTypeReference* vala_type_reference_new_from_name (const char* ns, const char* type, ValaSourceReference* source)
 {
-	GParameter * __params;
-	GParameter * __params_it;
 	ValaTypeReference * self;
 	g_return_val_if_fail (type != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
-	__params_it = __params;
-	(__params_it->name = "namespace-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, ns), __params_it++);
-	(__params_it->name = "type-name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, type), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
-	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, __params_it - __params, __params);
+	self = g_object_newv (VALA_TYPE_TYPE_REFERENCE, 0, NULL);
+	vala_type_reference_set_namespace_name (self, ns);
+	vala_type_reference_set_type_name (self, type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
 }
 
@@ -127,7 +120,7 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 {
 	char* ns;
 	char* type_name;
-	gpointer __temp6;
+	gpointer __temp5;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
 	ns = NULL;
 	type_name = NULL;
@@ -146,40 +139,42 @@ ValaTypeReference* vala_type_reference_new_from_expression (ValaExpression* expr
 				__temp1 = NULL;
 				simple = (__temp1 = VALA_MEMBER_ACCESS (vala_member_access_get_inner (ma)), (__temp1 == NULL ? NULL : g_object_ref (__temp1)));
 				__temp2 = NULL;
-				type_ref = (__temp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp2);
+				type_ref = (__temp2 = vala_type_reference_new_from_name (vala_member_access_get_member_name (simple), vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp2);
 				(simple == NULL ? NULL : (simple = (g_object_unref (simple), NULL)));
 			}
 		} else {
 			ValaTypeReference* __temp3;
 			__temp3 = NULL;
-			type_ref = (__temp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (VALA_CODE_NODE (ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp3);
+			type_ref = (__temp3 = vala_type_reference_new_from_name (NULL, vala_member_access_get_member_name (ma), vala_code_node_get_source_reference (((ValaCodeNode*) ma))), (type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL))), __temp3);
 		}
 		if (type_ref != NULL) {
-			GList* type_args;
-			ValaTypeReference* __temp5;
+			GeeCollection* type_args;
+			ValaTypeReference* __temp4;
 			type_args = vala_member_access_get_type_arguments (ma);
 			{
-				GList* __temp4;
-				GList* arg_it;
-				__temp4 = NULL;
-				__temp4 = type_args;
-				for (arg_it = __temp4; arg_it != NULL; arg_it = arg_it->next) {
+				GeeCollection* arg_collection;
+				GeeIterator* arg_it;
+				arg_collection = type_args;
+				arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+				while (gee_iterator_next (arg_it)) {
 					ValaTypeReference* arg;
-					arg = arg_it->data;
+					arg = gee_iterator_get (arg_it);
 					{
 						vala_type_reference_add_type_argument (type_ref, arg);
+						(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 					}
 				}
+				(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 			}
-			__temp5 = NULL;
-			return (__temp5 = type_ref, (type_args == NULL ? NULL : (type_args = (g_list_free (type_args), NULL))), __temp5);
-			(type_args == NULL ? NULL : (type_args = (g_list_free (type_args), NULL)));
+			__temp4 = NULL;
+			return (__temp4 = type_ref, (type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp4);
+			(type_args == NULL ? NULL : (type_args = (g_object_unref (type_args), NULL)));
 		}
 		(type_ref == NULL ? NULL : (type_ref = (g_object_unref (type_ref), NULL)));
 		(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	}
-	vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (expr)), "Type reference must be simple name or member access expression");
-	return VALA_TYPE_REFERENCE ((__temp6 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp6));
+	vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) expr)), "Type reference must be simple name or member access expression");
+	return VALA_TYPE_REFERENCE ((__temp5 = NULL, (ns = (g_free (ns), NULL)), (type_name = (g_free (type_name), NULL)), __temp5));
 	(ns = (g_free (ns), NULL));
 	(type_name = (g_free (type_name), NULL));
 }
@@ -194,7 +189,7 @@ void vala_type_reference_add_type_argument (ValaTypeReference* self, ValaTypeRef
 {
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (arg));
-	self->priv->type_argument_list = g_list_append (self->priv->type_argument_list, g_object_ref (arg));
+	gee_collection_add (GEE_COLLECTION (self->priv->type_argument_list), arg);
 }
 
 
@@ -203,10 +198,10 @@ void vala_type_reference_add_type_argument (ValaTypeReference* self, ValaTypeRef
  *
  * @return type argument list
  */
-GList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
+GeeList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
 {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
-	return g_list_copy (self->priv->type_argument_list);
+	return GEE_LIST (gee_read_only_list_new (g_object_ref, g_object_unref, GEE_LIST (self->priv->type_argument_list)));
 }
 
 
@@ -215,29 +210,31 @@ GList* vala_type_reference_get_type_arguments (ValaTypeReference* self)
  */
 void vala_type_reference_remove_all_type_arguments (ValaTypeReference* self)
 {
-	GList* __temp8;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp8 = NULL;
-	self->priv->type_argument_list = (__temp8 = NULL, (self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_list_foreach (self->priv->type_argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_argument_list), NULL))), __temp8);
+	gee_collection_clear (GEE_COLLECTION (self->priv->type_argument_list));
 }
 
 
 static void vala_type_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaTypeReference * self;
-	self = VALA_TYPE_REFERENCE (base);
+	self = ((ValaTypeReference*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	{
-		GList* __temp9;
-		GList* type_arg_it;
-		__temp9 = NULL;
-		__temp9 = self->priv->type_argument_list;
-		for (type_arg_it = __temp9; type_arg_it != NULL; type_arg_it = type_arg_it->next) {
-			ValaTypeReference* type_arg;
-			type_arg = type_arg_it->data;
-			{
-				vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
+	if (gee_collection_get_size (((GeeCollection*) (GEE_LIST (self->priv->type_argument_list)))) > 0) {
+		{
+			GeeArrayList* type_arg_collection;
+			GeeIterator* type_arg_it;
+			type_arg_collection = self->priv->type_argument_list;
+			type_arg_it = gee_iterable_iterator (GEE_ITERABLE (type_arg_collection));
+			while (gee_iterator_next (type_arg_it)) {
+				ValaTypeReference* type_arg;
+				type_arg = gee_iterator_get (type_arg_it);
+				{
+					vala_code_node_accept (VALA_CODE_NODE (type_arg), visitor);
+					(type_arg == NULL ? NULL : (type_arg = (g_object_unref (type_arg), NULL)));
+				}
 			}
+			(type_arg_it == NULL ? NULL : (type_arg_it = (g_object_unref (type_arg_it), NULL)));
 		}
 	}
 	vala_code_visitor_visit_type_reference (visitor, self);
@@ -264,38 +261,38 @@ char* vala_type_reference_get_cname (ValaTypeReference* self, gboolean var_type,
 	ptr = NULL;
 	arr = NULL;
 	if (vala_type_reference_get_type_parameter (self) != NULL || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self))) {
-		char* __temp12;
-		__temp12 = NULL;
-		ptr = (__temp12 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp12);
+		char* __temp9;
+		__temp9 = NULL;
+		ptr = (__temp9 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp9);
 	} else {
 		if ((vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && !vala_type_reference_get_is_ref (self) && !vala_type_reference_get_is_out (self)) || (!vala_data_type_is_reference_type (vala_type_reference_get_data_type (self)) && (vala_type_reference_get_is_ref (self) || vala_type_reference_get_is_out (self)))) {
-			char* __temp13;
-			__temp13 = NULL;
-			ptr = (__temp13 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp13);
+			char* __temp10;
+			__temp10 = NULL;
+			ptr = (__temp10 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp10);
 		} else {
-			char* __temp14;
-			__temp14 = NULL;
-			ptr = (__temp14 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), __temp14);
+			char* __temp11;
+			__temp11 = NULL;
+			ptr = (__temp11 = g_strdup ("**"), (ptr = (g_free (ptr), NULL)), __temp11);
 		}
 	}
 	if (vala_type_reference_get_data_type (self) != NULL) {
-		char* __temp15;
-		char* __temp16;
-		char* __temp17;
-		__temp15 = NULL;
-		__temp16 = NULL;
-		__temp17 = NULL;
-		return (__temp17 = (__temp16 = g_strconcat ((__temp15 = vala_data_type_get_cname (vala_type_reference_get_data_type (self), const_type)), ptr, arr, NULL, NULL), (__temp15 = (g_free (__temp15), NULL)), __temp16), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp17);
+		char* __temp12;
+		char* __temp13;
+		char* __temp14;
+		__temp12 = NULL;
+		__temp13 = NULL;
+		__temp14 = NULL;
+		return (__temp14 = (__temp13 = g_strconcat ((__temp12 = vala_data_type_get_cname (vala_type_reference_get_data_type (self), const_type)), ptr, arr, NULL, NULL), (__temp12 = (g_free (__temp12), NULL)), __temp13), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp14);
 	} else {
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
-			char* __temp18;
-			__temp18 = NULL;
-			return (__temp18 = g_strconcat ("gpointer", ptr, arr, NULL, NULL), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp18);
+			char* __temp15;
+			__temp15 = NULL;
+			return (__temp15 = g_strconcat ("gpointer", ptr, arr, NULL, NULL), (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp15);
 		} else {
-			gpointer __temp19;
+			gpointer __temp16;
 			/* raise error */
-			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), "unresolved type reference");
-			return (__temp19 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp19);
+			vala_report_error (vala_code_node_get_source_reference (((ValaCodeNode*) self)), "unresolved type reference");
+			return (__temp16 = NULL, (ptr = (g_free (ptr), NULL)), (arr = (g_free (arr), NULL)), __temp16);
 		}
 	}
 	(ptr = (g_free (ptr), NULL));
@@ -313,39 +310,39 @@ char* vala_type_reference_get_const_cname (ValaTypeReference* self)
 {
 	char* ptr;
 	ValaDataType* t;
-	char* __temp26;
-	char* __temp27;
-	char* __temp28;
+	char* __temp23;
+	char* __temp24;
+	char* __temp25;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	ptr = NULL;
 	t = NULL;
 	/* FIXME: dirty hack to make constant arrays possible */
 	if (VALA_IS_ARRAY (vala_type_reference_get_data_type (self))) {
-		ValaDataType* __temp21;
-		ValaDataType* __temp20;
-		__temp21 = NULL;
-		__temp20 = NULL;
-		t = (__temp21 = (__temp20 = vala_array_get_element_type ((VALA_ARRAY (vala_type_reference_get_data_type (self)))), (__temp20 == NULL ? NULL : g_object_ref (__temp20))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp21);
+		ValaDataType* __temp18;
+		ValaDataType* __temp17;
+		__temp18 = NULL;
+		__temp17 = NULL;
+		t = (__temp18 = (__temp17 = vala_array_get_element_type ((VALA_ARRAY (vala_type_reference_get_data_type (self)))), (__temp17 == NULL ? NULL : g_object_ref (__temp17))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp18);
 	} else {
-		ValaDataType* __temp23;
-		ValaDataType* __temp22;
-		__temp23 = NULL;
-		__temp22 = NULL;
-		t = (__temp23 = (__temp22 = vala_type_reference_get_data_type (self), (__temp22 == NULL ? NULL : g_object_ref (__temp22))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp23);
+		ValaDataType* __temp20;
+		ValaDataType* __temp19;
+		__temp20 = NULL;
+		__temp19 = NULL;
+		t = (__temp20 = (__temp19 = vala_type_reference_get_data_type (self), (__temp19 == NULL ? NULL : g_object_ref (__temp19))), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp20);
 	}
 	if (!vala_data_type_is_reference_type (t)) {
-		char* __temp24;
-		__temp24 = NULL;
-		ptr = (__temp24 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp24);
+		char* __temp21;
+		__temp21 = NULL;
+		ptr = (__temp21 = g_strdup (""), (ptr = (g_free (ptr), NULL)), __temp21);
 	} else {
-		char* __temp25;
-		__temp25 = NULL;
-		ptr = (__temp25 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp25);
+		char* __temp22;
+		__temp22 = NULL;
+		ptr = (__temp22 = g_strdup ("*"), (ptr = (g_free (ptr), NULL)), __temp22);
 	}
-	__temp26 = NULL;
-	__temp27 = NULL;
-	__temp28 = NULL;
-	return (__temp28 = (__temp27 = g_strdup_printf ("const %s%s", (__temp26 = vala_data_type_get_cname (t, FALSE)), ptr), (__temp26 = (g_free (__temp26), NULL)), __temp27), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp28);
+	__temp23 = NULL;
+	__temp24 = NULL;
+	__temp25 = NULL;
+	return (__temp25 = (__temp24 = g_strdup_printf ("const %s%s", (__temp23 = vala_data_type_get_cname (t, FALSE)), ptr), (__temp23 = (g_free (__temp23), NULL)), __temp24), (ptr = (g_free (ptr), NULL)), (t == NULL ? NULL : (t = (g_object_unref (t), NULL))), __temp25);
 	(ptr = (g_free (ptr), NULL));
 	(t == NULL ? NULL : (t = (g_object_unref (t), NULL)));
 }
@@ -361,10 +358,12 @@ char* vala_type_reference_to_string (ValaTypeReference* self)
 {
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	if (vala_type_reference_get_data_type (self) != NULL) {
-		return vala_symbol_get_full_name (vala_code_node_get_symbol (VALA_CODE_NODE (vala_type_reference_get_data_type (self))));
+		return vala_symbol_get_full_name (VALA_SYMBOL (vala_type_reference_get_data_type (self)));
 	} else {
 		if (vala_type_reference_get_type_parameter (self) != NULL) {
-			return g_strdup (vala_type_parameter_get_name (vala_type_reference_get_type_parameter (self)));
+			const char* __temp27;
+			__temp27 = NULL;
+			return (__temp27 = vala_symbol_get_name (((ValaSymbol*) vala_type_reference_get_type_parameter (self))), (__temp27 == NULL ? NULL : g_strdup (__temp27)));
 		} else {
 			return g_strdup ("null");
 		}
@@ -382,32 +381,37 @@ ValaTypeReference* vala_type_reference_copy (ValaTypeReference* self)
 	ValaTypeReference* result;
 	g_return_val_if_fail (VALA_IS_TYPE_REFERENCE (self), NULL);
 	result = vala_type_reference_new ();
-	(vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self))), vala_code_node_get_source_reference (VALA_CODE_NODE (result)));
-	(vala_type_reference_set_transfers_ownership (result, vala_type_reference_get_transfers_ownership (self)), vala_type_reference_get_transfers_ownership (result));
-	(vala_type_reference_set_takes_ownership (result, vala_type_reference_get_takes_ownership (self)), vala_type_reference_get_takes_ownership (result));
-	(vala_type_reference_set_is_out (result, vala_type_reference_get_is_out (self)), vala_type_reference_get_is_out (result));
-	(vala_type_reference_set_non_null (result, vala_type_reference_get_non_null (self)), vala_type_reference_get_non_null (result));
-	(vala_type_reference_set_data_type (result, vala_type_reference_get_data_type (self)), vala_type_reference_get_data_type (result));
-	(vala_type_reference_set_type_parameter (result, vala_type_reference_get_type_parameter (self)), vala_type_reference_get_type_parameter (result));
-	(vala_type_reference_set_floating_reference (result, vala_type_reference_get_floating_reference (self)), vala_type_reference_get_floating_reference (result));
-	(vala_type_reference_set_namespace_name (result, vala_type_reference_get_namespace_name (self)), vala_type_reference_get_namespace_name (result));
-	(vala_type_reference_set_type_name (result, vala_type_reference_get_type_name (self)), vala_type_reference_get_type_name (result));
-	(vala_type_reference_set_array_rank (result, vala_type_reference_get_array_rank (self)), vala_type_reference_get_array_rank (result));
-	(vala_type_reference_set_pointer_level (result, vala_type_reference_get_pointer_level (self)), vala_type_reference_get_pointer_level (result));
-	(vala_type_reference_set_is_ref (result, vala_type_reference_get_is_ref (self)), vala_type_reference_get_is_ref (result));
-	(vala_type_reference_set_is_weak (result, vala_type_reference_get_is_weak (self)), vala_type_reference_get_is_weak (result));
+	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (((ValaCodeNode*) self)));
+	vala_type_reference_set_transfers_ownership (result, vala_type_reference_get_transfers_ownership (self));
+	vala_type_reference_set_takes_ownership (result, vala_type_reference_get_takes_ownership (self));
+	vala_type_reference_set_is_out (result, vala_type_reference_get_is_out (self));
+	vala_type_reference_set_non_null (result, vala_type_reference_get_non_null (self));
+	vala_type_reference_set_data_type (result, vala_type_reference_get_data_type (self));
+	vala_type_reference_set_type_parameter (result, vala_type_reference_get_type_parameter (self));
+	vala_type_reference_set_floating_reference (result, vala_type_reference_get_floating_reference (self));
+	vala_type_reference_set_namespace_name (result, vala_type_reference_get_namespace_name (self));
+	vala_type_reference_set_type_name (result, vala_type_reference_get_type_name (self));
+	vala_type_reference_set_array_rank (result, vala_type_reference_get_array_rank (self));
+	vala_type_reference_set_pointer_level (result, vala_type_reference_get_pointer_level (self));
+	vala_type_reference_set_is_ref (result, vala_type_reference_get_is_ref (self));
+	vala_type_reference_set_is_weak (result, vala_type_reference_get_is_weak (self));
 	{
-		GList* __temp32;
-		GList* arg_it;
-		__temp32 = NULL;
-		__temp32 = self->priv->type_argument_list;
-		for (arg_it = __temp32; arg_it != NULL; arg_it = arg_it->next) {
+		GeeArrayList* arg_collection;
+		GeeIterator* arg_it;
+		arg_collection = self->priv->type_argument_list;
+		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
+		while (gee_iterator_next (arg_it)) {
 			ValaTypeReference* arg;
-			arg = arg_it->data;
+			arg = gee_iterator_get (arg_it);
 			{
-				result->priv->type_argument_list = g_list_append (result->priv->type_argument_list, vala_type_reference_copy (arg));
+				ValaTypeReference* __temp30;
+				__temp30 = NULL;
+				gee_collection_add (GEE_COLLECTION (result->priv->type_argument_list), (__temp30 = vala_type_reference_copy (arg)));
+				(__temp30 = (g_object_unref (__temp30), NULL));
+				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
+		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return result;
 	(result == NULL ? NULL : (result = (g_object_unref (result), NULL)));
@@ -593,12 +597,12 @@ ValaTypeParameter* vala_type_reference_get_type_parameter (ValaTypeReference* se
 
 void vala_type_reference_set_type_parameter (ValaTypeReference* self, ValaTypeParameter* value)
 {
-	ValaTypeParameter* __temp61;
-	ValaTypeParameter* __temp60;
+	ValaTypeParameter* __temp59;
+	ValaTypeParameter* __temp58;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp61 = NULL;
-	__temp60 = NULL;
-	self->priv->_type_parameter = (__temp61 = (__temp60 = value, (__temp60 == NULL ? NULL : g_object_ref (__temp60))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), __temp61);
+	__temp59 = NULL;
+	__temp58 = NULL;
+	self->priv->_type_parameter = (__temp59 = (__temp58 = value, (__temp58 == NULL ? NULL : g_object_ref (__temp58))), (self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL))), __temp59);
 }
 
 
@@ -625,12 +629,12 @@ char* vala_type_reference_get_namespace_name (ValaTypeReference* self)
 
 void vala_type_reference_set_namespace_name (ValaTypeReference* self, const char* value)
 {
-	char* __temp65;
-	const char* __temp64;
+	char* __temp63;
+	const char* __temp62;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp65 = NULL;
-	__temp64 = NULL;
-	self->priv->_namespace_name = (__temp65 = (__temp64 = value, (__temp64 == NULL ? NULL : g_strdup (__temp64))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), __temp65);
+	__temp63 = NULL;
+	__temp62 = NULL;
+	self->priv->_namespace_name = (__temp63 = (__temp62 = value, (__temp62 == NULL ? NULL : g_strdup (__temp62))), (self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL)), __temp63);
 }
 
 
@@ -643,12 +647,12 @@ char* vala_type_reference_get_type_name (ValaTypeReference* self)
 
 void vala_type_reference_set_type_name (ValaTypeReference* self, const char* value)
 {
-	char* __temp68;
-	const char* __temp67;
+	char* __temp66;
+	const char* __temp65;
 	g_return_if_fail (VALA_IS_TYPE_REFERENCE (self));
-	__temp68 = NULL;
-	__temp67 = NULL;
-	self->priv->_type_name = (__temp68 = (__temp67 = value, (__temp67 == NULL ? NULL : g_strdup (__temp67))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp68);
+	__temp66 = NULL;
+	__temp65 = NULL;
+	self->priv->_type_name = (__temp66 = (__temp65 = value, (__temp65 == NULL ? NULL : g_strdup (__temp65))), (self->priv->_type_name = (g_free (self->priv->_type_name), NULL)), __temp66);
 }
 
 
@@ -838,6 +842,7 @@ static void vala_type_reference_class_init (ValaTypeReferenceClass * klass)
 static void vala_type_reference_init (ValaTypeReference * self)
 {
 	self->priv = VALA_TYPE_REFERENCE_GET_PRIVATE (self);
+	self->priv->type_argument_list = gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal);
 }
 
 
@@ -850,14 +855,14 @@ static void vala_type_reference_dispose (GObject * obj)
 	(self->priv->_type_parameter == NULL ? NULL : (self->priv->_type_parameter = (g_object_unref (self->priv->_type_parameter), NULL)));
 	(self->priv->_namespace_name = (g_free (self->priv->_namespace_name), NULL));
 	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
-	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_list_foreach (self->priv->type_argument_list, (GFunc) g_object_unref, NULL), g_list_free (self->priv->type_argument_list), NULL)));
+	(self->priv->type_argument_list == NULL ? NULL : (self->priv->type_argument_list = (g_object_unref (self->priv->type_argument_list), NULL)));
 	klass = VALA_TYPE_REFERENCE_CLASS (g_type_class_peek (VALA_TYPE_TYPE_REFERENCE));
 	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
 	parent_class->dispose (obj);
 }
 
 
-GType vala_type_reference_get_type ()
+GType vala_type_reference_get_type (void)
 {
 	static GType vala_type_reference_type_id = 0;
 	if (G_UNLIKELY (vala_type_reference_type_id == 0)) {
