@@ -19,8 +19,6 @@
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
  */
-#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
-#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))
 
 #include "valaunaryexpression.h"
 #include <vala/valasourcereference.h>
@@ -57,12 +55,17 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 	ValaUnaryExpression * self;
 	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
-	__params = g_new0 (GParameter, 3);
+	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "operator", g_value_init (&__params_it->value, G_TYPE_INT), g_value_set_int (&__params_it->value, op), __params_it++);
 	(__params_it->name = "inner", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, _inner), __params_it++);
-	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
 	self = g_object_newv (VALA_TYPE_UNARY_EXPRESSION, __params_it - __params, __params);
+	vala_unary_expression_set_operator (self, op);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -70,7 +73,7 @@ ValaUnaryExpression* vala_unary_expression_new (ValaUnaryOperator op, ValaExpres
 static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
 {
 	ValaUnaryExpression * self;
-	self = VALA_UNARY_EXPRESSION (base);
+	self = ((ValaUnaryExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_unary_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_unary_expression (visitor, self);
@@ -80,11 +83,11 @@ static void vala_unary_expression_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_unary_expression_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
 {
 	ValaUnaryExpression * self;
-	self = VALA_UNARY_EXPRESSION (base);
+	self = ((ValaUnaryExpression*) base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_unary_expression_get_inner (self)) == old_node) {
-		(vala_unary_expression_set_inner (self, VALA_EXPRESSION (new_node)), vala_unary_expression_get_inner (self));
+		vala_unary_expression_set_inner (self, VALA_EXPRESSION (new_node));
 	}
 }
 
@@ -116,7 +119,7 @@ void vala_unary_expression_set_inner (ValaUnaryExpression* self, ValaExpression*
 	g_return_if_fail (VALA_IS_UNARY_EXPRESSION (self));
 	__temp2 = NULL;
 	self->priv->_inner = (__temp2 = g_object_ref (value), (self->priv->_inner == NULL ? NULL : (self->priv->_inner = (g_object_unref (self->priv->_inner), NULL))), __temp2);
-	(vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self)), vala_code_node_get_parent_node (VALA_CODE_NODE (self->priv->_inner)));
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_inner), VALA_CODE_NODE (self));
 }
 
 
@@ -183,7 +186,7 @@ static void vala_unary_expression_dispose (GObject * obj)
 }
 
 
-GType vala_unary_expression_get_type ()
+GType vala_unary_expression_get_type (void)
 {
 	static GType vala_unary_expression_type_id = 0;
 	if (G_UNLIKELY (vala_unary_expression_type_id == 0)) {
