@@ -69,7 +69,7 @@ ValaUnaryOperator vala_unary_expression_get_operator (ValaUnaryExpression* self)
 void vala_unary_expression_set_operator (ValaUnaryExpression* self, ValaUnaryOperator value);
 ValaExpression* vala_unary_expression_get_inner (ValaUnaryExpression* self);
 void vala_unary_expression_set_inner (ValaUnaryExpression* self, ValaExpression* value);
-GType vala_unary_expression_get_type ();
+GType vala_unary_expression_get_type (void);
 
 G_END_DECLS
 
