@@ -72,7 +72,7 @@ struct _ValaGIdlParserClass {
 };
 
 void vala_gidl_parser_parse (ValaGIdlParser* self, ValaCodeContext* context);
-GType vala_gidl_parser_get_type ();
+GType vala_gidl_parser_get_type (void);
 
 G_END_DECLS
 
